@@ -54,9 +54,6 @@ class BeginToken extends SimpleToken {
         type == TokenType.STRING_INTERPOLATION_EXPRESSION);
   }
 
-  @override
-  Token copy() => new BeginToken(type, offset, copyComments(precedingComments));
-
   @override
   Token? get endGroup => endToken;
 
@@ -83,25 +80,6 @@ class CommentToken extends StringToken {
    */
   CommentToken(TokenType type, String value, int offset)
       : super(type, value, offset);
-
-  @override
-  CommentToken copy() => new CommentToken(type, _value, offset);
-
-  /**
-   * Remove this comment token from the list.
-   *
-   * This is used when we decide to interpret the comment as syntax.
-   */
-  void remove() {
-    Token? previous = this.previous;
-    if (previous != null) {
-      previous.setNextWithoutSettingPrevious(next);
-      next?.previous = previous;
-    } else {
-      assert(parent!.precedingComments == this);
-      parent!.precedingComments = next as CommentToken?;
-    }
-  }
 }
 
 /**
@@ -114,9 +92,6 @@ class DocumentationCommentToken extends CommentToken {
    */
   DocumentationCommentToken(TokenType type, String value, int offset)
       : super(type, value, offset);
-
-  @override
-  CommentToken copy() => new DocumentationCommentToken(type, _value, offset);
 }
 
 enum KeywordStyle {
@@ -144,6 +119,10 @@ class Keyword extends TokenType {
   static const Keyword ASYNC =
       const Keyword("async", "ASYNC", KeywordStyle.pseudo);
 
+  static const Keyword AUGMENT = const Keyword(
+      "augment", "AUGMENT", KeywordStyle.builtIn,
+      isModifier: true);
+
   static const Keyword AWAIT =
       const Keyword("await", "AWAIT", KeywordStyle.pseudo);
 
@@ -218,7 +197,7 @@ class Keyword extends TokenType {
   static const Keyword FOR = const Keyword("for", "FOR", KeywordStyle.reserved);
 
   static const Keyword FUNCTION =
-      const Keyword("Function", "FUNCTION", KeywordStyle.pseudo);
+      const Keyword("Function", "FUNCTION", KeywordStyle.builtIn);
 
   static const Keyword GET = const Keyword("get", "GET", KeywordStyle.builtIn);
 
@@ -345,6 +324,7 @@ class Keyword extends TokenType {
     AS,
     ASSERT,
     ASYNC,
+    AUGMENT,
     AWAIT,
     BREAK,
     CASE,
@@ -476,10 +456,6 @@ class KeywordToken extends SimpleToken {
   KeywordToken(this.keyword, int offset, [CommentToken? precedingComment])
       : super(keyword, offset, precedingComment);
 
-  @override
-  Token copy() =>
-      new KeywordToken(keyword, offset, copyComments(precedingComments));
-
   @override
   bool get isIdentifier => keyword.isPseudo || keyword.isBuiltIn;
 
@@ -510,10 +486,6 @@ class LanguageVersionToken extends CommentToken {
 
   LanguageVersionToken.from(String text, int offset, this.major, this.minor)
       : super(TokenType.SINGLE_LINE_COMMENT, text, offset);
-
-  @override
-  LanguageVersionToken copy() =>
-      new LanguageVersionToken.from(lexeme, offset, major, minor);
 }
 
 /**
@@ -628,25 +600,6 @@ class SimpleToken implements Token {
   @override
   String? get stringValue => type.stringValue;
 
-  @override
-  Token copy() =>
-      new SimpleToken(type, offset, copyComments(precedingComments));
-
-  @override
-  CommentToken? copyComments(CommentToken? token) {
-    if (token == null) {
-      return null;
-    }
-    CommentToken head = token.copy();
-    Token tail = head;
-    token = token.next as CommentToken?;
-    while (token != null) {
-      tail = tail.setNext(token.copy());
-      token = token.next as CommentToken?;
-    }
-    return head;
-  }
-
   @override
   bool matchesAny(List<TokenType> types) {
     for (TokenType type in types) {
@@ -713,10 +666,6 @@ class StringToken extends SimpleToken {
   @override
   String get lexeme => _value;
 
-  @override
-  Token copy() =>
-      new StringToken(type, _value, offset, copyComments(precedingComments));
-
   @override
   String value() => _value;
 }
@@ -734,8 +683,7 @@ class SyntheticBeginToken extends BeginToken {
       : super(type, offset, precedingComment);
 
   @override
-  Token copy() =>
-      new SyntheticBeginToken(type, offset, copyComments(precedingComments));
+  Token? beforeSynthetic;
 
   @override
   bool get isSynthetic => true;
@@ -755,10 +703,10 @@ class SyntheticKeywordToken extends KeywordToken {
   SyntheticKeywordToken(Keyword keyword, int offset) : super(keyword, offset);
 
   @override
-  int get length => 0;
+  Token? beforeSynthetic;
 
   @override
-  Token copy() => new SyntheticKeywordToken(keyword, offset);
+  int get length => 0;
 }
 
 /**
@@ -783,9 +731,6 @@ class SyntheticStringToken extends StringToken {
 
   @override
   int get length => _length ?? super.length;
-
-  @override
-  Token copy() => new SyntheticStringToken(type, _value, offset, _length);
 }
 
 /**
@@ -802,9 +747,6 @@ class SyntheticToken extends SimpleToken {
 
   @override
   int get length => 0;
-
-  @override
-  Token copy() => new SyntheticToken(type, offset);
 }
 
 /// A token used to replace another token in the stream, while still keeping the
@@ -828,9 +770,6 @@ class ReplacementToken extends SyntheticToken {
 
   @override
   int get length => 0;
-
-  @override
-  Token copy() => new ReplacementToken(type, replacedToken);
 }
 
 /**
@@ -843,7 +782,7 @@ abstract class Token implements SyntacticEntity {
   /**
    * Initialize a newly created token to have the given [type] and [offset].
    */
-  factory Token(TokenType type, int offset, [CommentToken? preceedingComment]) =
+  factory Token(TokenType type, int offset, [CommentToken? precedingComment]) =
       SimpleToken;
 
   /**
@@ -1030,18 +969,6 @@ abstract class Token implements SyntacticEntity {
    */
   TokenType get type;
 
-  /**
-   * Return a newly created token that is a copy of this tokens
-   * including any [preceedingComment] tokens,
-   * but that is not a part of any token stream.
-   */
-  Token copy();
-
-  /**
-   * Copy a linked list of comment tokens identical to the given comment tokens.
-   */
-  CommentToken? copyComments(CommentToken? token);
-
   /**
    * Return `true` if this token has any one of the given [types].
    */
@@ -1085,7 +1012,8 @@ abstract class Token implements SyntacticEntity {
    * Return the token with the smallest offset, or `null` if all of the
    * tokens are `null`.
    */
-  static Token? lexicallyFirst([Token? t1, Token? t2, Token? t3, Token? t4]) {
+  static Token? lexicallyFirst(
+      [Token? t1, Token? t2, Token? t3, Token? t4, Token? t5]) {
     Token? result = t1;
     if (result == null || t2 != null && t2.offset < result.offset) {
       result = t2;
@@ -1096,6 +1024,9 @@ abstract class Token implements SyntacticEntity {
     if (result == null || t4 != null && t4.offset < result.offset) {
       result = t4;
     }
+    if (result == null || t5 != null && t5.offset < result.offset) {
+      result = t5;
+    }
     return result;
   }
 }
