@@ -5,23 +5,16 @@
 import 'package:_fe_analyzer_shared/src/scanner/token.dart';
 import 'package:analyzer/dart/analysis/features.dart';
 import 'package:analyzer/dart/ast/ast.dart';
-import 'package:analyzer/dart/ast/ast_factory.dart';
 import 'package:analyzer/dart/element/element.dart';
 import 'package:analyzer/dart/element/type.dart';
+import 'package:analyzer/source/line_info.dart';
 import 'package:analyzer/src/dart/ast/ast.dart';
 import 'package:analyzer/src/generated/utilities_dart.dart';
 
 /// The instance of [AstFactoryImpl].
 final AstFactoryImpl astFactory = AstFactoryImpl();
 
-/// Concrete implementation of [AstFactory] based on the standard AST
-/// implementation.
-class AstFactoryImpl extends AstFactory {
-  @override
-  AdjacentStringsImpl adjacentStrings(List<StringLiteral> strings) =>
-      AdjacentStringsImpl(strings);
-
-  @override
+class AstFactoryImpl {
   AnnotationImpl annotation(
           {required Token atSign,
           required Identifier name,
@@ -37,98 +30,29 @@ class AstFactoryImpl extends AstFactory {
           constructorName as SimpleIdentifierImpl?,
           arguments as ArgumentListImpl?);
 
-  @override
-  ArgumentListImpl argumentList(Token leftParenthesis,
-          List<Expression> arguments, Token rightParenthesis) =>
-      ArgumentListImpl(leftParenthesis, arguments, rightParenthesis);
-
-  @override
-  AsExpressionImpl asExpression(
-          Expression expression, Token asOperator, TypeAnnotation type) =>
-      AsExpressionImpl(
-          expression as ExpressionImpl, asOperator, type as TypeAnnotationImpl);
-
-  @override
-  AssertInitializerImpl assertInitializer(
-          Token assertKeyword,
-          Token leftParenthesis,
-          Expression condition,
-          Token? comma,
-          Expression? message,
-          Token rightParenthesis) =>
-      AssertInitializerImpl(
-          assertKeyword,
-          leftParenthesis,
-          condition as ExpressionImpl,
-          comma,
-          message as ExpressionImpl?,
-          rightParenthesis);
-
-  @override
-  AssertStatementImpl assertStatement(
-          Token assertKeyword,
-          Token leftParenthesis,
-          Expression condition,
-          Token? comma,
-          Expression? message,
-          Token rightParenthesis,
-          Token semicolon) =>
-      AssertStatementImpl(
-          assertKeyword,
-          leftParenthesis,
-          condition as ExpressionImpl,
-          comma,
-          message as ExpressionImpl?,
-          rightParenthesis,
-          semicolon);
-
-  @override
-  AssignmentExpressionImpl assignmentExpression(
-          Expression leftHandSide, Token operator, Expression rightHandSide) =>
-      AssignmentExpressionImpl(leftHandSide as ExpressionImpl, operator,
-          rightHandSide as ExpressionImpl);
-
-  @override
-  AwaitExpressionImpl awaitExpression(
-          Token awaitKeyword, Expression expression) =>
-      AwaitExpressionImpl(awaitKeyword, expression as ExpressionImpl);
-
-  @override
-  BinaryExpressionImpl binaryExpression(
-          Expression leftOperand, Token operator, Expression rightOperand) =>
-      BinaryExpressionImpl(leftOperand as ExpressionImpl, operator,
-          rightOperand as ExpressionImpl);
-
-  @override
   BlockImpl block(
           Token leftBracket, List<Statement> statements, Token rightBracket) =>
       BlockImpl(leftBracket, statements, rightBracket);
 
-  @override
   CommentImpl blockComment(List<Token> tokens) =>
       CommentImpl.createBlockComment(tokens);
 
-  @override
   BlockFunctionBodyImpl blockFunctionBody(
           Token? keyword, Token? star, Block block) =>
       BlockFunctionBodyImpl(keyword, star, block as BlockImpl);
 
-  @override
   BooleanLiteralImpl booleanLiteral(Token literal, bool value) =>
       BooleanLiteralImpl(literal, value);
 
-  @override
   BreakStatementImpl breakStatement(
           Token breakKeyword, SimpleIdentifier? label, Token semicolon) =>
       BreakStatementImpl(
           breakKeyword, label as SimpleIdentifierImpl?, semicolon);
 
-  @override
   CascadeExpressionImpl cascadeExpression(
           Expression target, List<Expression> cascadeSections) =>
       CascadeExpressionImpl(target as ExpressionImpl, cascadeSections);
 
-  @override
   CatchClauseImpl catchClause(
           Token? onKeyword,
           TypeAnnotation? exceptionType,
@@ -150,12 +74,12 @@ class AstFactoryImpl extends AstFactory {
           rightParenthesis,
           body as BlockImpl);
 
-  @override
   ClassDeclarationImpl classDeclaration(
           Comment? comment,
           List<Annotation>? metadata,
           Token? abstractKeyword,
           Token? macroKeyword,
+          Token? augmentKeyword,
           Token classKeyword,
           SimpleIdentifier name,
           TypeParameterList? typeParameters,
@@ -170,6 +94,7 @@ class AstFactoryImpl extends AstFactory {
           metadata,
           abstractKeyword,
           macroKeyword,
+          augmentKeyword,
           classKeyword,
           name as SimpleIdentifierImpl,
           typeParameters as TypeParameterListImpl?,
@@ -180,7 +105,6 @@ class AstFactoryImpl extends AstFactory {
           members,
           rightBracket);
 
-  @override
   ClassTypeAliasImpl classTypeAlias(
           Comment? comment,
           List<Annotation>? metadata,
@@ -190,6 +114,7 @@ class AstFactoryImpl extends AstFactory {
           Token equals,
           Token? abstractKeyword,
           Token? macroKeyword,
+          Token? augmentKeyword,
           NamedType superclass,
           WithClause withClause,
           ImplementsClause? implementsClause,
@@ -203,29 +128,32 @@ class AstFactoryImpl extends AstFactory {
           equals,
           abstractKeyword,
           macroKeyword,
+          augmentKeyword,
           superclass as NamedTypeImpl,
           withClause as WithClauseImpl,
           implementsClause as ImplementsClauseImpl?,
           semicolon);
 
-  @override
   CommentReferenceImpl commentReference(
           Token? newKeyword, CommentReferableExpression expression) =>
       CommentReferenceImpl(
           newKeyword, expression as CommentReferableExpressionImpl);
 
-  @override
   CompilationUnitImpl compilationUnit(
           {required Token beginToken,
           ScriptTag? scriptTag,
           List<Directive>? directives,
           List<CompilationUnitMember>? declarations,
           required Token endToken,
-          required FeatureSet featureSet}) =>
+          required FeatureSet featureSet,
+          // TODO(dantup): LineInfo should be made required and non-nullable
+          //   when breaking API changes can be made. Callers that do not
+          //   provide lineInfos may have offsets incorrectly mapped to line/col
+          //   for LSP.
+          LineInfo? lineInfo}) =>
       CompilationUnitImpl(beginToken, scriptTag as ScriptTagImpl?, directives,
-          declarations, endToken, featureSet);
+          declarations, endToken, featureSet, lineInfo ?? LineInfo([0]));
 
-  @override
   ConditionalExpressionImpl conditionalExpression(
           Expression condition,
           Token question,
@@ -239,7 +167,6 @@ class AstFactoryImpl extends AstFactory {
           colon,
           elseExpression as ExpressionImpl);
 
-  @override
   ConfigurationImpl configuration(
           Token ifKeyword,
           Token leftParenthesis,
@@ -257,7 +184,6 @@ class AstFactoryImpl extends AstFactory {
           rightParenthesis,
           libraryUri as StringLiteralImpl);
 
-  @override
   ConstructorDeclarationImpl constructorDeclaration(
           Comment? comment,
           List<Annotation>? metadata,
@@ -287,7 +213,6 @@ class AstFactoryImpl extends AstFactory {
           redirectedConstructor as ConstructorNameImpl?,
           body as FunctionBodyImpl);
 
-  @override
   ConstructorFieldInitializerImpl constructorFieldInitializer(
           Token? thisKeyword,
           Token? period,
@@ -301,24 +226,20 @@ class AstFactoryImpl extends AstFactory {
           equals,
           expression as ExpressionImpl);
 
-  @override
   ConstructorNameImpl constructorName(
           NamedType type, Token? period, SimpleIdentifier? name) =>
       ConstructorNameImpl(
           type as NamedTypeImpl, period, name as SimpleIdentifierImpl?);
 
-  @override
   ConstructorReferenceImpl constructorReference(
           {required ConstructorName constructorName}) =>
       ConstructorReferenceImpl(constructorName as ConstructorNameImpl);
 
-  @override
   ContinueStatementImpl continueStatement(
           Token continueKeyword, SimpleIdentifier? label, Token semicolon) =>
       ContinueStatementImpl(
           continueKeyword, label as SimpleIdentifierImpl?, semicolon);
 
-  @override
   DeclaredIdentifierImpl declaredIdentifier(
           Comment? comment,
           List<Annotation>? metadata,
@@ -328,7 +249,6 @@ class AstFactoryImpl extends AstFactory {
       DeclaredIdentifierImpl(comment as CommentImpl?, metadata, keyword,
           type as TypeAnnotationImpl?, identifier as SimpleIdentifierImpl);
 
-  @override
   DefaultFormalParameterImpl defaultFormalParameter(
           NormalFormalParameter parameter,
           ParameterKind kind,
@@ -337,13 +257,11 @@ class AstFactoryImpl extends AstFactory {
       DefaultFormalParameterImpl(parameter as NormalFormalParameterImpl, kind,
           separator, defaultValue as ExpressionImpl?);
 
-  @override
   CommentImpl documentationComment(List<Token> tokens,
           [List<CommentReference>? references]) =>
       CommentImpl.createDocumentationCommentWithReferences(
           tokens, references ?? <CommentReference>[]);
 
-  @override
   DoStatementImpl doStatement(
           Token doKeyword,
           Statement body,
@@ -361,34 +279,31 @@ class AstFactoryImpl extends AstFactory {
           rightParenthesis,
           semicolon);
 
-  @override
   DottedNameImpl dottedName(List<SimpleIdentifier> components) =>
       DottedNameImpl(components);
 
-  @override
   DoubleLiteralImpl doubleLiteral(Token literal, double value) =>
       DoubleLiteralImpl(literal, value);
 
-  @override
   EmptyFunctionBodyImpl emptyFunctionBody(Token semicolon) =>
       EmptyFunctionBodyImpl(semicolon);
 
-  @override
   EmptyStatementImpl emptyStatement(Token semicolon) =>
       EmptyStatementImpl(semicolon);
 
-  @override
   CommentImpl endOfLineComment(List<Token> tokens) =>
       CommentImpl.createEndOfLineComment(tokens);
 
-  @override
   EnumConstantDeclarationImpl enumConstantDeclaration(Comment? comment,
           List<Annotation>? metadata, SimpleIdentifier name) =>
       EnumConstantDeclarationImpl(
-          comment as CommentImpl?, metadata, name as SimpleIdentifierImpl);
+        documentationComment: comment as CommentImpl?,
+        metadata: metadata,
+        name: name as SimpleIdentifierImpl,
+        arguments: null,
+      );
 
   @Deprecated('Use enumDeclaration2() instead')
-  @override
   EnumDeclarationImpl enumDeclaration(
           Comment? comment,
           List<Annotation>? metadata,
@@ -407,10 +322,10 @@ class AstFactoryImpl extends AstFactory {
           implementsClause: null,
           leftBracket: leftBracket,
           constants: constants,
+          semicolon: null,
           members: [],
           rightBracket: rightBracket);
 
-  @override
   EnumDeclarationImpl enumDeclaration2({
     required Comment? comment,
     required List<Annotation>? metadata,
@@ -422,6 +337,7 @@ class AstFactoryImpl extends AstFactory {
     required Token leftBracket,
     required List<EnumConstantDeclaration> constants,
     required List<ClassMember> members,
+    required Token? semicolon,
     required Token rightBracket,
   }) {
     return EnumDeclarationImpl(
@@ -434,12 +350,12 @@ class AstFactoryImpl extends AstFactory {
       implementsClause as ImplementsClauseImpl?,
       leftBracket,
       constants,
+      semicolon,
       members,
       rightBracket,
     );
   }
 
-  @override
   ExportDirectiveImpl exportDirective(
           Comment? comment,
           List<Annotation>? metadata,
@@ -457,13 +373,11 @@ class AstFactoryImpl extends AstFactory {
           combinators,
           semicolon);
 
-  @override
   ExpressionFunctionBodyImpl expressionFunctionBody(Token? keyword,
           Token functionDefinition, Expression expression, Token? semicolon) =>
       ExpressionFunctionBodyImpl(keyword, null, functionDefinition,
           expression as ExpressionImpl, semicolon);
 
-  @override
   ExpressionFunctionBodyImpl expressionFunctionBody2({
     Token? keyword,
     Token? star,
@@ -474,16 +388,13 @@ class AstFactoryImpl extends AstFactory {
       ExpressionFunctionBodyImpl(keyword, star, functionDefinition,
           expression as ExpressionImpl, semicolon);
 
-  @override
   ExpressionStatementImpl expressionStatement(
           Expression expression, Token? semicolon) =>
       ExpressionStatementImpl(expression as ExpressionImpl, semicolon);
 
-  @override
   ExtendsClauseImpl extendsClause(Token extendsKeyword, NamedType superclass) =>
       ExtendsClauseImpl(extendsKeyword, superclass as NamedTypeImpl);
 
-  @override
   ExtensionDeclarationImpl extensionDeclaration(
           {Comment? comment,
           List<Annotation>? metadata,
@@ -513,7 +424,6 @@ class AstFactoryImpl extends AstFactory {
           members,
           rightBracket);
 
-  @override
   ExtensionOverrideImpl extensionOverride(
           {required Identifier extensionName,
           TypeArgumentList? typeArguments,
@@ -523,11 +433,11 @@ class AstFactoryImpl extends AstFactory {
           typeArguments as TypeArgumentListImpl?,
           argumentList as ArgumentListImpl);
 
-  @override
   FieldDeclarationImpl fieldDeclaration2(
           {Comment? comment,
           List<Annotation>? metadata,
           Token? abstractKeyword,
+          Token? augmentKeyword,
           Token? covariantKeyword,
           Token? externalKeyword,
           Token? staticKeyword,
@@ -537,13 +447,13 @@ class AstFactoryImpl extends AstFactory {
           comment as CommentImpl?,
           metadata,
           abstractKeyword,
+          augmentKeyword,
           covariantKeyword,
           externalKeyword,
           staticKeyword,
           fieldList as VariableDeclarationListImpl,
           semicolon);
 
-  @override
   FieldFormalParameterImpl fieldFormalParameter2(
           {Comment? comment,
           List<Annotation>? metadata,
@@ -571,7 +481,6 @@ class AstFactoryImpl extends AstFactory {
           parameters as FormalParameterListImpl?,
           question);
 
-  @override
   ForEachPartsWithDeclarationImpl forEachPartsWithDeclaration(
           {required DeclaredIdentifier loopVariable,
           required Token inKeyword,
@@ -579,7 +488,6 @@ class AstFactoryImpl extends AstFactory {
       ForEachPartsWithDeclarationImpl(loopVariable as DeclaredIdentifierImpl,
           inKeyword, iterable as ExpressionImpl);
 
-  @override
   ForEachPartsWithIdentifierImpl forEachPartsWithIdentifier(
           {required SimpleIdentifier identifier,
           required Token inKeyword,
@@ -587,7 +495,6 @@ class AstFactoryImpl extends AstFactory {
       ForEachPartsWithIdentifierImpl(identifier as SimpleIdentifierImpl,
           inKeyword, iterable as ExpressionImpl);
 
-  @override
   ForElementImpl forElement(
           {Token? awaitKeyword,
           required Token forKeyword,
@@ -603,7 +510,6 @@ class AstFactoryImpl extends AstFactory {
           rightParenthesis,
           body as CollectionElementImpl);
 
-  @override
   FormalParameterListImpl formalParameterList(
           Token leftParenthesis,
           List<FormalParameter> parameters,
@@ -613,7 +519,6 @@ class AstFactoryImpl extends AstFactory {
       FormalParameterListImpl(leftParenthesis, parameters, leftDelimiter,
           rightDelimiter, rightParenthesis);
 
-  @override
   ForPartsWithDeclarationsImpl forPartsWithDeclarations(
           {required VariableDeclarationList variables,
           required Token leftSeparator,
@@ -627,7 +532,6 @@ class AstFactoryImpl extends AstFactory {
           rightSeparator,
           updaters);
 
-  @override
   ForPartsWithExpressionImpl forPartsWithExpression(
           {Expression? initialization,
           required Token leftSeparator,
@@ -641,7 +545,6 @@ class AstFactoryImpl extends AstFactory {
           rightSeparator,
           updaters);
 
-  @override
   ForStatementImpl forStatement(
       {Token? awaitKeyword,
       required Token forKeyword,
@@ -658,10 +561,10 @@ class AstFactoryImpl extends AstFactory {
         body as StatementImpl);
   }
 
-  @override
   FunctionDeclarationImpl functionDeclaration(
           Comment? comment,
           List<Annotation>? metadata,
+          Token? augmentKeyword,
           Token? externalKeyword,
           TypeAnnotation? returnType,
           Token? propertyKeyword,
@@ -670,25 +573,23 @@ class AstFactoryImpl extends AstFactory {
       FunctionDeclarationImpl(
           comment as CommentImpl?,
           metadata,
+          augmentKeyword,
           externalKeyword,
           returnType as TypeAnnotationImpl?,
           propertyKeyword,
           name as SimpleIdentifierImpl,
           functionExpression as FunctionExpressionImpl);
 
-  @override
   FunctionDeclarationStatementImpl functionDeclarationStatement(
           FunctionDeclaration functionDeclaration) =>
       FunctionDeclarationStatementImpl(
           functionDeclaration as FunctionDeclarationImpl);
 
-  @override
   FunctionExpressionImpl functionExpression(TypeParameterList? typeParameters,
           FormalParameterList? parameters, FunctionBody body) =>
       FunctionExpressionImpl(typeParameters as TypeParameterListImpl?,
           parameters as FormalParameterListImpl?, body as FunctionBodyImpl);
 
-  @override
   FunctionExpressionInvocationImpl functionExpressionInvocation(
           Expression function,
           TypeArgumentList? typeArguments,
@@ -698,13 +599,11 @@ class AstFactoryImpl extends AstFactory {
           typeArguments as TypeArgumentListImpl?,
           argumentList as ArgumentListImpl);
 
-  @override
   FunctionReferenceImpl functionReference(
           {required Expression function, TypeArgumentList? typeArguments}) =>
       FunctionReferenceImpl(function as ExpressionImpl,
           typeArguments: typeArguments as TypeArgumentListImpl?);
 
-  @override
   FunctionTypeAliasImpl functionTypeAlias(
           Comment? comment,
           List<Annotation>? metadata,
@@ -724,7 +623,6 @@ class AstFactoryImpl extends AstFactory {
           parameters as FormalParameterListImpl,
           semicolon);
 
-  @override
   FunctionTypedFormalParameterImpl functionTypedFormalParameter2(
           {Comment? comment,
           List<Annotation>? metadata,
@@ -746,7 +644,6 @@ class AstFactoryImpl extends AstFactory {
           parameters as FormalParameterListImpl,
           question);
 
-  @override
   GenericFunctionTypeImpl genericFunctionType(
           TypeAnnotation? returnType,
           Token functionKeyword,
@@ -760,7 +657,6 @@ class AstFactoryImpl extends AstFactory {
           parameters as FormalParameterListImpl,
           question: question);
 
-  @override
   GenericTypeAliasImpl genericTypeAlias(
           Comment? comment,
           List<Annotation>? metadata,
@@ -780,18 +676,15 @@ class AstFactoryImpl extends AstFactory {
           type as TypeAnnotationImpl,
           semicolon);
 
-  @override
   HideClauseImpl hideClause(
           {required Token hideKeyword,
           required List<ShowHideClauseElement> elements}) =>
       HideClauseImpl(hideKeyword, elements);
 
-  @override
   HideCombinatorImpl hideCombinator(
           Token keyword, List<SimpleIdentifier> hiddenNames) =>
       HideCombinatorImpl(keyword, hiddenNames);
 
-  @override
   IfElementImpl ifElement(
           {required Token ifKeyword,
           required Token leftParenthesis,
@@ -809,7 +702,6 @@ class AstFactoryImpl extends AstFactory {
           elseKeyword,
           elseElement as CollectionElementImpl?);
 
-  @override
   IfStatementImpl ifStatement(
           Token ifKeyword,
           Token leftParenthesis,
@@ -827,12 +719,10 @@ class AstFactoryImpl extends AstFactory {
           elseKeyword,
           elseStatement as StatementImpl?);
 
-  @override
   ImplementsClauseImpl implementsClause(
           Token implementsKeyword, List<NamedType> interfaces) =>
       ImplementsClauseImpl(implementsKeyword, interfaces);
 
-  @override
   ImplicitCallReferenceImpl implicitCallReference({
     required Expression expression,
     required MethodElement staticElement,
@@ -844,7 +734,6 @@ class AstFactoryImpl extends AstFactory {
           typeArguments: typeArguments as TypeArgumentListImpl?,
           typeArgumentTypes: typeArgumentTypes);
 
-  @override
   ImportDirectiveImpl importDirective(
           Comment? comment,
           List<Annotation>? metadata,
@@ -855,11 +744,13 @@ class AstFactoryImpl extends AstFactory {
           Token? asKeyword,
           SimpleIdentifier? prefix,
           List<Combinator>? combinators,
-          Token semicolon) =>
+          Token semicolon,
+          {Token? augmentKeyword}) =>
       ImportDirectiveImpl(
           comment as CommentImpl?,
           metadata,
           keyword,
+          augmentKeyword,
           libraryUri as StringLiteralImpl,
           configurations,
           deferredKeyword,
@@ -868,7 +759,6 @@ class AstFactoryImpl extends AstFactory {
           combinators,
           semicolon);
 
-  @override
   IndexExpressionImpl indexExpressionForCascade2(
           {required Token period,
           Token? question,
@@ -878,7 +768,6 @@ class AstFactoryImpl extends AstFactory {
       IndexExpressionImpl.forCascade(
           period, question, leftBracket, index as ExpressionImpl, rightBracket);
 
-  @override
   IndexExpressionImpl indexExpressionForTarget2(
           {required Expression target,
           Token? question,
@@ -888,7 +777,6 @@ class AstFactoryImpl extends AstFactory {
       IndexExpressionImpl.forTarget(target as ExpressionImpl, question,
           leftBracket, index as ExpressionImpl, rightBracket);
 
-  @override
   InstanceCreationExpressionImpl instanceCreationExpression(Token? keyword,
           ConstructorName constructorName, ArgumentList argumentList,
           {TypeArgumentList? typeArguments}) =>
@@ -898,36 +786,29 @@ class AstFactoryImpl extends AstFactory {
           argumentList as ArgumentListImpl,
           typeArguments: typeArguments as TypeArgumentListImpl?);
 
-  @override
   IntegerLiteralImpl integerLiteral(Token literal, int? value) =>
       IntegerLiteralImpl(literal, value);
 
-  @override
   InterpolationExpressionImpl interpolationExpression(
           Token leftBracket, Expression expression, Token? rightBracket) =>
       InterpolationExpressionImpl(
           leftBracket, expression as ExpressionImpl, rightBracket);
 
-  @override
   InterpolationStringImpl interpolationString(Token contents, String value) =>
       InterpolationStringImpl(contents, value);
 
-  @override
   IsExpressionImpl isExpression(Expression expression, Token isOperator,
           Token? notOperator, TypeAnnotation type) =>
       IsExpressionImpl(expression as ExpressionImpl, isOperator, notOperator,
           type as TypeAnnotationImpl);
 
-  @override
   LabelImpl label(SimpleIdentifier label, Token colon) =>
       LabelImpl(label as SimpleIdentifierImpl, colon);
 
-  @override
   LabeledStatementImpl labeledStatement(
           List<Label> labels, Statement statement) =>
       LabeledStatementImpl(labels, statement as StatementImpl);
 
-  @override
   LibraryDirectiveImpl libraryDirective(
           Comment? comment,
           List<Annotation>? metadata,
@@ -937,11 +818,9 @@ class AstFactoryImpl extends AstFactory {
       LibraryDirectiveImpl(comment as CommentImpl?, metadata, libraryKeyword,
           name as LibraryIdentifierImpl, semicolon);
 
-  @override
   LibraryIdentifierImpl libraryIdentifier(List<SimpleIdentifier> components) =>
       LibraryIdentifierImpl(components);
 
-  @override
   ListLiteralImpl listLiteral(
       Token? constKeyword,
       TypeArgumentList? typeArguments,
@@ -964,13 +843,11 @@ class AstFactoryImpl extends AstFactory {
         rightBracket);
   }
 
-  @override
   MapLiteralEntryImpl mapLiteralEntry(
           Expression key, Token separator, Expression value) =>
       MapLiteralEntryImpl(
           key as ExpressionImpl, separator, value as ExpressionImpl);
 
-  @override
   MethodDeclarationImpl methodDeclaration(
           Comment? comment,
           List<Annotation>? metadata,
@@ -996,7 +873,6 @@ class AstFactoryImpl extends AstFactory {
           parameters as FormalParameterListImpl?,
           body as FunctionBodyImpl);
 
-  @override
   MethodInvocationImpl methodInvocation(
           Expression? target,
           Token? operator,
@@ -1010,10 +886,10 @@ class AstFactoryImpl extends AstFactory {
           typeArguments as TypeArgumentListImpl?,
           argumentList as ArgumentListImpl);
 
-  @override
   MixinDeclarationImpl mixinDeclaration(
           Comment? comment,
           List<Annotation>? metadata,
+          Token? augmentKeyword,
           Token mixinKeyword,
           SimpleIdentifier name,
           TypeParameterList? typeParameters,
@@ -1025,6 +901,7 @@ class AstFactoryImpl extends AstFactory {
       MixinDeclarationImpl(
           comment as CommentImpl?,
           metadata,
+          augmentKeyword,
           mixinKeyword,
           name as SimpleIdentifierImpl,
           typeParameters as TypeParameterListImpl?,
@@ -1034,11 +911,9 @@ class AstFactoryImpl extends AstFactory {
           members,
           rightBracket);
 
-  @override
   NamedExpressionImpl namedExpression(Label name, Expression expression) =>
       NamedExpressionImpl(name as LabelImpl, expression as ExpressionImpl);
 
-  @override
   NamedTypeImpl namedType({
     required Identifier name,
     TypeArgumentList? typeArguments,
@@ -1048,41 +923,33 @@ class AstFactoryImpl extends AstFactory {
           name as IdentifierImpl, typeArguments as TypeArgumentListImpl?,
           question: question);
 
-  @override
   NativeClauseImpl nativeClause(Token nativeKeyword, StringLiteral? name) =>
       NativeClauseImpl(nativeKeyword, name as StringLiteralImpl?);
 
-  @override
   NativeFunctionBodyImpl nativeFunctionBody(
           Token nativeKeyword, StringLiteral? stringLiteral, Token semicolon) =>
       NativeFunctionBodyImpl(
           nativeKeyword, stringLiteral as StringLiteralImpl?, semicolon);
 
-  @override
   NodeListImpl<E> nodeList<E extends AstNode>(AstNode owner) =>
       NodeListImpl<E>(owner as AstNodeImpl);
 
-  @override
   NullLiteralImpl nullLiteral(Token literal) => NullLiteralImpl(literal);
 
-  @override
   OnClauseImpl onClause(
           Token onKeyword, List<NamedType> superclassConstraints) =>
       OnClauseImpl(onKeyword, superclassConstraints);
 
-  @override
   ParenthesizedExpressionImpl parenthesizedExpression(Token leftParenthesis,
           Expression expression, Token rightParenthesis) =>
       ParenthesizedExpressionImpl(
           leftParenthesis, expression as ExpressionImpl, rightParenthesis);
 
-  @override
   PartDirectiveImpl partDirective(Comment? comment, List<Annotation>? metadata,
           Token partKeyword, StringLiteral partUri, Token semicolon) =>
       PartDirectiveImpl(comment as CommentImpl?, metadata, partKeyword,
           partUri as StringLiteralImpl, semicolon);
 
-  @override
   PartOfDirectiveImpl partOfDirective(
           Comment? comment,
           List<Annotation>? metadata,
@@ -1100,27 +967,22 @@ class AstFactoryImpl extends AstFactory {
           libraryName as LibraryIdentifierImpl?,
           semicolon);
 
-  @override
   PostfixExpressionImpl postfixExpression(Expression operand, Token operator) =>
       PostfixExpressionImpl(operand as ExpressionImpl, operator);
 
-  @override
   PrefixedIdentifierImpl prefixedIdentifier(
           SimpleIdentifier prefix, Token period, SimpleIdentifier identifier) =>
       PrefixedIdentifierImpl(prefix as SimpleIdentifierImpl, period,
           identifier as SimpleIdentifierImpl);
 
-  @override
   PrefixExpressionImpl prefixExpression(Token operator, Expression operand) =>
       PrefixExpressionImpl(operator, operand as ExpressionImpl);
 
-  @override
   PropertyAccessImpl propertyAccess(
           Expression? target, Token operator, SimpleIdentifier propertyName) =>
       PropertyAccessImpl(target as ExpressionImpl?, operator,
           propertyName as SimpleIdentifierImpl);
 
-  @override
   RedirectingConstructorInvocationImpl redirectingConstructorInvocation(
           Token thisKeyword,
           Token? period,
@@ -1132,20 +994,16 @@ class AstFactoryImpl extends AstFactory {
           constructorName as SimpleIdentifierImpl?,
           argumentList as ArgumentListImpl);
 
-  @override
   RethrowExpressionImpl rethrowExpression(Token rethrowKeyword) =>
       RethrowExpressionImpl(rethrowKeyword);
 
-  @override
   ReturnStatementImpl returnStatement(
           Token returnKeyword, Expression? expression, Token semicolon) =>
       ReturnStatementImpl(
           returnKeyword, expression as ExpressionImpl?, semicolon);
 
-  @override
   ScriptTagImpl scriptTag(Token scriptTag) => ScriptTagImpl(scriptTag);
 
-  @override
   SetOrMapLiteralImpl setOrMapLiteral(
           {Token? constKeyword,
           TypeArgumentList? typeArguments,
@@ -1155,23 +1013,19 @@ class AstFactoryImpl extends AstFactory {
       SetOrMapLiteralImpl(constKeyword, typeArguments as TypeArgumentListImpl?,
           leftBracket, elements, rightBracket);
 
-  @override
   ShowClauseImpl showClause(
           {required Token showKeyword,
           required List<ShowHideClauseElement> elements}) =>
       ShowClauseImpl(showKeyword, elements);
 
-  @override
   ShowCombinatorImpl showCombinator(
           Token keyword, List<SimpleIdentifier> shownNames) =>
       ShowCombinatorImpl(keyword, shownNames);
 
-  @override
   ShowHideElementImpl showHideElement(
           {required Token? modifier, required SimpleIdentifier name}) =>
       ShowHideElementImpl(modifier, name);
 
-  @override
   SimpleFormalParameterImpl simpleFormalParameter2(
           {Comment? comment,
           List<Annotation>? metadata,
@@ -1189,7 +1043,6 @@ class AstFactoryImpl extends AstFactory {
           type as TypeAnnotationImpl?,
           identifier as SimpleIdentifierImpl?);
 
-  @override
   SimpleIdentifierImpl simpleIdentifier(Token token,
       {bool isDeclaration = false}) {
     if (isDeclaration) {
@@ -1198,21 +1051,17 @@ class AstFactoryImpl extends AstFactory {
     return SimpleIdentifierImpl(token);
   }
 
-  @override
   SimpleStringLiteralImpl simpleStringLiteral(Token literal, String value) =>
       SimpleStringLiteralImpl(literal, value);
 
-  @override
   SpreadElementImpl spreadElement(
           {required Token spreadOperator, required Expression expression}) =>
       SpreadElementImpl(spreadOperator, expression as ExpressionImpl);
 
-  @override
   StringInterpolationImpl stringInterpolation(
           List<InterpolationElement> elements) =>
       StringInterpolationImpl(elements);
 
-  @override
   SuperConstructorInvocationImpl superConstructorInvocation(
           Token superKeyword,
           Token? period,
@@ -1224,11 +1073,9 @@ class AstFactoryImpl extends AstFactory {
           constructorName as SimpleIdentifierImpl?,
           argumentList as ArgumentListImpl);
 
-  @override
   SuperExpressionImpl superExpression(Token superKeyword) =>
       SuperExpressionImpl(superKeyword);
 
-  @override
   SuperFormalParameterImpl superFormalParameter(
           {Comment? comment,
           List<Annotation>? metadata,
@@ -1256,18 +1103,15 @@ class AstFactoryImpl extends AstFactory {
           parameters as FormalParameterListImpl?,
           question);
 
-  @override
   SwitchCaseImpl switchCase(List<Label> labels, Token keyword,
           Expression expression, Token colon, List<Statement> statements) =>
       SwitchCaseImpl(
           labels, keyword, expression as ExpressionImpl, colon, statements);
 
-  @override
   SwitchDefaultImpl switchDefault(List<Label> labels, Token keyword,
           Token colon, List<Statement> statements) =>
       SwitchDefaultImpl(labels, keyword, colon, statements);
 
-  @override
   SwitchStatementImpl switchStatement(
           Token switchKeyword,
           Token leftParenthesis,
@@ -1285,20 +1129,16 @@ class AstFactoryImpl extends AstFactory {
           members,
           rightBracket);
 
-  @override
   SymbolLiteralImpl symbolLiteral(Token poundSign, List<Token> components) =>
       SymbolLiteralImpl(poundSign, components);
 
-  @override
   ThisExpressionImpl thisExpression(Token thisKeyword) =>
       ThisExpressionImpl(thisKeyword);
 
-  @override
   ThrowExpressionImpl throwExpression(
           Token throwKeyword, Expression expression) =>
       ThrowExpressionImpl(throwKeyword, expression as ExpressionImpl);
 
-  @override
   TopLevelVariableDeclarationImpl topLevelVariableDeclaration(
           Comment? comment,
           List<Annotation>? metadata,
@@ -1312,7 +1152,6 @@ class AstFactoryImpl extends AstFactory {
           variableList as VariableDeclarationListImpl,
           semicolon);
 
-  @override
   TryStatementImpl tryStatement(
           Token tryKeyword,
           Block body,
@@ -1322,16 +1161,13 @@ class AstFactoryImpl extends AstFactory {
       TryStatementImpl(tryKeyword, body as BlockImpl, catchClauses,
           finallyKeyword, finallyBlock as BlockImpl?);
 
-  @override
   TypeArgumentListImpl typeArgumentList(Token leftBracket,
           List<TypeAnnotation> arguments, Token rightBracket) =>
       TypeArgumentListImpl(leftBracket, arguments, rightBracket);
 
-  @override
   TypeLiteralImpl typeLiteral({required NamedType typeName}) =>
       TypeLiteralImpl(typeName as NamedTypeImpl);
 
-  @override
   TypeParameterImpl typeParameter(
           Comment? comment,
           List<Annotation>? metadata,
@@ -1360,18 +1196,15 @@ class AstFactoryImpl extends AstFactory {
           bound as TypeAnnotationImpl?)
         ..varianceKeyword = varianceKeyword;
 
-  @override
   TypeParameterListImpl typeParameterList(Token leftBracket,
           List<TypeParameter> typeParameters, Token rightBracket) =>
       TypeParameterListImpl(leftBracket, typeParameters, rightBracket);
 
-  @override
   VariableDeclarationImpl variableDeclaration(
           SimpleIdentifier name, Token? equals, Expression? initializer) =>
       VariableDeclarationImpl(
           name as SimpleIdentifierImpl, equals, initializer as ExpressionImpl?);
 
-  @override
   VariableDeclarationListImpl variableDeclarationList(
           Comment? comment,
           List<Annotation>? metadata,
@@ -1381,7 +1214,6 @@ class AstFactoryImpl extends AstFactory {
       VariableDeclarationListImpl(comment as CommentImpl?, metadata, null,
           keyword, type as TypeAnnotationImpl?, variables);
 
-  @override
   VariableDeclarationListImpl variableDeclarationList2(
       {Comment? comment,
       List<Annotation>? metadata,
@@ -1393,23 +1225,19 @@ class AstFactoryImpl extends AstFactory {
         lateKeyword, keyword, type as TypeAnnotationImpl?, variables);
   }
 
-  @override
   VariableDeclarationStatementImpl variableDeclarationStatement(
           VariableDeclarationList variableList, Token semicolon) =>
       VariableDeclarationStatementImpl(
           variableList as VariableDeclarationListImpl, semicolon);
 
-  @override
   WhileStatementImpl whileStatement(Token whileKeyword, Token leftParenthesis,
           Expression condition, Token rightParenthesis, Statement body) =>
       WhileStatementImpl(whileKeyword, leftParenthesis,
           condition as ExpressionImpl, rightParenthesis, body as StatementImpl);
 
-  @override
   WithClauseImpl withClause(Token withKeyword, List<NamedType> mixinTypes) =>
       WithClauseImpl(withKeyword, mixinTypes);
 
-  @override
   YieldStatementImpl yieldStatement(Token yieldKeyword, Token? star,
           Expression expression, Token semicolon) =>
       YieldStatementImpl(
