@@ -8,6 +8,7 @@ import 'package:analyzer/dart/ast/visitor.dart';
 import 'package:analyzer/dart/element/element.dart';
 import 'package:analyzer/src/dart/ast/ast.dart';
 import 'package:analyzer/src/dart/ast/ast_factory.dart';
+import 'package:analyzer/src/dart/ast/invokes_super_self.dart';
 import 'package:analyzer/src/dart/ast/token.dart';
 import 'package:analyzer/src/dart/element/element.dart';
 import 'package:analyzer/src/dart/element/type.dart';
@@ -66,7 +67,7 @@ class ElementBuilder extends ThrowingAstVisitor<void> {
     _libraryElement.exports = _exports;
 
     if (!_hasCoreImport) {
-      var dartCore = _linker.elementFactory.libraryOfUri2('dart:core');
+      final dartCore = _linker.elementFactory.dartCoreElement;
       _imports.add(
         ImportElementImpl(-1)
           ..importedLibrary = dartCore
@@ -98,6 +99,7 @@ class ElementBuilder extends ThrowingAstVisitor<void> {
 
     var element = ClassElementImpl(name, nameNode.offset);
     element.isAbstract = node.isAbstract;
+    element.isMacro = node.macroKeyword != null;
     element.metadata = _buildAnnotations(node.metadata);
     _setCodeRange(element, node);
     _setDocumentation(element, node);
@@ -106,7 +108,7 @@ class ElementBuilder extends ThrowingAstVisitor<void> {
     _linker.elementNodes[element] = node;
 
     var reference = _enclosingContext.addClass(name, element);
-    _libraryBuilder.localScope.declare(name, reference);
+    _libraryBuilder.declare(name, reference);
 
     var holder = _EnclosingContext(reference, element);
     _withEnclosing(holder, () {
@@ -130,6 +132,7 @@ class ElementBuilder extends ThrowingAstVisitor<void> {
 
     var element = ClassElementImpl(name, nameNode.offset);
     element.isAbstract = node.isAbstract;
+    element.isMacro = node.macroKeyword != null;
     element.isMixinApplication = true;
     element.metadata = _buildAnnotations(node.metadata);
     _setCodeRange(element, node);
@@ -139,7 +142,7 @@ class ElementBuilder extends ThrowingAstVisitor<void> {
     _linker.elementNodes[element] = node;
 
     var reference = _enclosingContext.addClass(name, element);
-    _libraryBuilder.localScope.declare(name, reference);
+    _libraryBuilder.declare(name, reference);
 
     var holder = _EnclosingContext(reference, element);
     _withEnclosing(holder, () {
@@ -150,7 +153,7 @@ class ElementBuilder extends ThrowingAstVisitor<void> {
       }
     });
 
-    node.superclass2.accept(this);
+    node.superclass.accept(this);
     node.withClause.accept(this);
     node.implementsClause?.accept(this);
   }
@@ -184,7 +187,7 @@ class ElementBuilder extends ThrowingAstVisitor<void> {
     node.declaredElement = element;
     _linker.elementNodes[element] = node;
 
-    var reference = _enclosingContext.addConstructor(name, element);
+    var reference = _enclosingContext.addConstructor(element);
     _buildExecutableElementChildren(
       reference: reference,
       element: element,
@@ -212,7 +215,7 @@ class ElementBuilder extends ThrowingAstVisitor<void> {
     _linker.elementNodes[element] = node;
 
     var reference = _enclosingContext.addEnum(name, element);
-    _libraryBuilder.localScope.declare(name, reference);
+    _libraryBuilder.declare(name, reference);
 
     var holder = _EnclosingContext(
       reference,
@@ -220,42 +223,6 @@ class ElementBuilder extends ThrowingAstVisitor<void> {
       hasConstConstructor: true,
     );
 
-    // Build the 'index' field.
-    var indexField = ConstFieldElementImpl('index', -1)
-      ..isSynthetic = true
-      ..isFinal = true;
-    holder.addNonSyntheticField(indexField);
-
-    var constructorIndexParameter = FieldFormalParameterElementImpl(
-      name: 'index',
-      nameOffset: -1,
-      parameterKind: ParameterKind.REQUIRED,
-    )..field = indexField;
-
-    var constructorNameParameter = ParameterElementImpl(
-      name: 'name',
-      nameOffset: -1,
-      parameterKind: ParameterKind.REQUIRED,
-    );
-
-    var constructorName = '_';
-    if (node.constants.any((c) => c.name.name == '_')) {
-      constructorName = '_1';
-    }
-
-    var constructorReference =
-        reference.getChild('@constructor').getChild(constructorName);
-    var constructor = ConstructorElementImpl(constructorName, -1)
-      ..isConst = true
-      ..isSynthetic = true
-      ..parameters = [
-        constructorIndexParameter,
-        constructorNameParameter,
-      ]
-      ..reference = constructorReference;
-    constructorReference.element = constructor;
-    element.constructors = [constructor];
-
     // Build fields for all enum constants.
     var constants = node.constants;
     var valuesElements = <Expression>[];
@@ -264,6 +231,7 @@ class ElementBuilder extends ThrowingAstVisitor<void> {
       var name = constant.name.name;
       var field = ConstFieldElementImpl(name, constant.name.offset)
         ..hasImplicitType = true
+        ..hasInitializer = true
         ..isConst = true
         ..isEnumConstant = true
         ..isStatic = true
@@ -274,6 +242,10 @@ class ElementBuilder extends ThrowingAstVisitor<void> {
         _unitElement,
         constant.metadata,
       );
+
+      var constructorSelector = constant.arguments?.constructorSelector;
+      var constructorName = constructorSelector?.name.name;
+
       var initializer = astFactory.instanceCreationExpression(
         null,
         astFactory.constructorName(
@@ -281,25 +253,21 @@ class ElementBuilder extends ThrowingAstVisitor<void> {
             name: astFactory.simpleIdentifier(
               StringToken(TokenType.STRING, element.name, -1),
             ),
+            typeArguments: constant.arguments?.typeArguments,
           ),
-          Tokens.period(),
-          astFactory.simpleIdentifier(
-            StringToken(TokenType.STRING, constructorName, -1),
-          ),
+          constructorName != null ? Tokens.period() : null,
+          constructorName != null
+              ? astFactory.simpleIdentifier(
+                  StringToken(TokenType.STRING, constructorName, -1),
+                )
+              : null,
         ),
-        astFactory.argumentList(
-          Tokens.openParenthesis(),
-          [
-            astFactory.integerLiteral(
-              StringToken(TokenType.STRING, '$i', 0),
-              i,
-            ),
-            astFactory.simpleStringLiteral(
-              StringToken(TokenType.STRING, "'$name'", 0),
-              name,
-            ),
+        ArgumentListImpl(
+          leftParenthesis: Tokens.openParenthesis(),
+          arguments: [
+            ...?constant.arguments?.argumentList.arguments,
           ],
-          Tokens.closeParenthesis(),
+          rightParenthesis: Tokens.closeParenthesis(),
         ),
       );
 
@@ -374,48 +342,54 @@ class ElementBuilder extends ThrowingAstVisitor<void> {
       holder.addNonSyntheticField(valuesField);
     }
 
-    // TODO(scheglov) implement
-    // node.extendsClause?.accept(this);
-    // node.withClause?.accept(this);
-    // node.implementsClause?.accept(this);
+    node.withClause?.accept(this);
+    node.implementsClause?.accept(this);
 
     _withEnclosing(holder, () {
       node.typeParameters?.accept(this);
       _visitPropertyFirst<FieldDeclaration>(node.members);
     });
 
-    MethodElementImpl? syntheticToStringMethod;
-    if (holder.getMethod('toString').element == null) {
-      syntheticToStringMethod = MethodElementImpl('toString', -1)
-        ..isSynthetic = true;
-      holder.addMethod(name, syntheticToStringMethod);
+    var needsImplicitConstructor = !holder.constructors.any(
+      (e) => e.name.isEmpty || e.isGenerative,
+    );
+
+    if (needsImplicitConstructor) {
+      holder.addConstructor(
+        ConstructorElementImpl('', -1)
+          ..isConst = true
+          ..isSynthetic = true,
+      );
     }
 
     _libraryBuilder.implicitEnumNodes.add(
       ImplicitEnumNodes(
         element: element,
-        indexField: indexField,
         valuesTypeNode: valuesTypeNode,
         valuesField: valuesField,
-        constructorIndexParameter: constructorIndexParameter,
-        constructorNameParameter: constructorNameParameter,
-        syntheticToStringMethod: syntheticToStringMethod,
       ),
     );
 
-    element.typeParameters = holder.typeParameters;
     element.accessors = holder.propertyAccessors;
+    element.constructors = holder.constructors;
     element.fields = holder.properties.whereType<FieldElementImpl>().toList();
     element.methods = holder.methods;
+    element.typeParameters = holder.typeParameters;
 
-    // TODO(scheglov) resolve field formals
+    _resolveConstructorFieldFormals(element);
   }
 
   @override
   void visitExportDirective(covariant ExportDirectiveImpl node) {
     var element = ExportElementImpl(node.keyword.offset);
     element.combinators = _buildCombinators(node.combinators);
-    element.exportedLibrary = _selectLibrary(node);
+
+    try {
+      element.exportedLibrary = _selectLibrary(node);
+    } on ArgumentError {
+      // TODO(scheglov) Remove this when using `ExportDirectiveState`.
+    }
+
     element.metadata = _buildAnnotations(node.metadata);
     element.uri = node.uri.stringValue;
 
@@ -425,7 +399,7 @@ class ElementBuilder extends ThrowingAstVisitor<void> {
 
   @override
   void visitExtendsClause(ExtendsClause node) {
-    node.superclass2.accept(this);
+    node.superclass.accept(this);
   }
 
   @override
@@ -442,11 +416,11 @@ class ElementBuilder extends ThrowingAstVisitor<void> {
     node.declaredElement = element;
     _linker.elementNodes[element] = node;
 
-    var refName = name ?? 'extension-${_nextUnnamedExtensionId++}';
+    var refName = name ?? '${_nextUnnamedExtensionId++}';
     var reference = _enclosingContext.addExtension(refName, element);
 
     if (name != null) {
-      _libraryBuilder.localScope.declare(name, reference);
+      _libraryBuilder.declare(name, reference);
     }
 
     var holder = _EnclosingContext(reference, element);
@@ -587,6 +561,7 @@ class ElementBuilder extends ThrowingAstVisitor<void> {
     if (node.isGetter) {
       var element = PropertyAccessorElementImpl(name, nameOffset);
       element.isGetter = true;
+      element.isStatic = true;
 
       reference = _enclosingContext.addGetter(name, element);
       executableElement = element;
@@ -595,6 +570,7 @@ class ElementBuilder extends ThrowingAstVisitor<void> {
     } else if (node.isSetter) {
       var element = PropertyAccessorElementImpl(name, nameOffset);
       element.isSetter = true;
+      element.isStatic = true;
 
       reference = _enclosingContext.addSetter(name, element);
       executableElement = element;
@@ -602,6 +578,7 @@ class ElementBuilder extends ThrowingAstVisitor<void> {
       _buildSyntheticVariable(name: name, accessorElement: element);
     } else {
       var element = FunctionElementImpl(name, nameOffset);
+      element.isStatic = true;
       reference = _enclosingContext.addFunction(name, element);
       executableElement = element;
     }
@@ -624,11 +601,10 @@ class ElementBuilder extends ThrowingAstVisitor<void> {
       typeParameters: functionExpression.typeParameters,
     );
 
-    var localScope = _libraryBuilder.localScope;
     if (node.isSetter) {
-      localScope.declare('$name=', reference);
+      _libraryBuilder.declare('$name=', reference);
     } else {
-      localScope.declare(name, reference);
+      _libraryBuilder.declare(name, reference);
     }
 
     _buildType(node.returnType);
@@ -649,7 +625,7 @@ class ElementBuilder extends ThrowingAstVisitor<void> {
     _linker.elementNodes[element] = node;
 
     var reference = _enclosingContext.addTypeAlias(name, element);
-    _libraryBuilder.localScope.declare(name, reference);
+    _libraryBuilder.declare(name, reference);
 
     var holder = _EnclosingContext(reference, element);
     _withEnclosing(holder, () {
@@ -757,7 +733,7 @@ class ElementBuilder extends ThrowingAstVisitor<void> {
     _linker.elementNodes[element] = node;
 
     var reference = _enclosingContext.addTypeAlias(name, element);
-    _libraryBuilder.localScope.declare(name, reference);
+    _libraryBuilder.declare(name, reference);
 
     var holder = _EnclosingContext(reference, element);
     _withEnclosing(holder, () {
@@ -776,7 +752,7 @@ class ElementBuilder extends ThrowingAstVisitor<void> {
 
   @override
   void visitImplementsClause(ImplementsClause node) {
-    node.interfaces2.accept(this);
+    node.interfaces.accept(this);
   }
 
   @override
@@ -785,7 +761,13 @@ class ElementBuilder extends ThrowingAstVisitor<void> {
 
     var element = ImportElementImpl(node.keyword.offset);
     element.combinators = _buildCombinators(node.combinators);
-    element.importedLibrary = _selectLibrary(node);
+
+    try {
+      element.importedLibrary = _selectLibrary(node);
+    } on ArgumentError {
+      // TODO(scheglov) Remove this when using `ImportDirectiveState`.
+    }
+
     element.isDeferred = node.deferredKeyword != null;
     element.metadata = _buildAnnotations(node.metadata);
     element.uri = uriStr;
@@ -836,6 +818,14 @@ class ElementBuilder extends ThrowingAstVisitor<void> {
       element.isGetter = true;
       element.isStatic = node.isStatic;
 
+      // `class Enum {}` in `dart:core` declares `int get index` as abstract.
+      // But the specification says that practically a different class
+      // implementing `Enum` is used as a superclass, so `index` should be
+      // considered to have non-abstract implementation.
+      if (_enclosingContext.isDartCoreEnum && name == 'index') {
+        element.isAbstract = false;
+      }
+
       reference = _enclosingContext.addGetter(name, element);
       executableElement = element;
 
@@ -866,6 +856,7 @@ class ElementBuilder extends ThrowingAstVisitor<void> {
       executableElement = element;
     }
     executableElement.hasImplicitReturnType = node.returnType == null;
+    executableElement.invokesSuperSelf = node.invokesSuperSelf;
     executableElement.isAsynchronous = node.body.isAsynchronous;
     executableElement.isExternal =
         node.externalKeyword != null || node.body is NativeFunctionBody;
@@ -901,7 +892,7 @@ class ElementBuilder extends ThrowingAstVisitor<void> {
     _linker.elementNodes[element] = node;
 
     var reference = _enclosingContext.addMixin(name, element);
-    _libraryBuilder.localScope.declare(name, reference);
+    _libraryBuilder.declare(name, reference);
 
     var holder = _EnclosingContext(reference, element);
     _withEnclosing(holder, () {
@@ -924,7 +915,7 @@ class ElementBuilder extends ThrowingAstVisitor<void> {
 
   @override
   void visitOnClause(OnClause node) {
-    node.superclassConstraints2.accept(this);
+    node.superclassConstraints.accept(this);
   }
 
   @override
@@ -1078,15 +1069,13 @@ class ElementBuilder extends ThrowingAstVisitor<void> {
       var getter = element.getter;
       if (getter is PropertyAccessorElementImpl) {
         _enclosingContext.addGetter(name, getter);
-        var localScope = _libraryBuilder.localScope;
-        localScope.declare(name, getter.reference!);
+        _libraryBuilder.declare(name, getter.reference!);
       }
 
       var setter = element.setter;
       if (setter is PropertyAccessorElementImpl) {
         _enclosingContext.addSetter(name, setter);
-        var localScope = _libraryBuilder.localScope;
-        localScope.declare('$name=', setter.reference!);
+        _libraryBuilder.declare('$name=', setter.reference!);
       }
     }
 
@@ -1121,7 +1110,7 @@ class ElementBuilder extends ThrowingAstVisitor<void> {
 
   @override
   void visitWithClause(WithClause node) {
-    node.mixinTypes2.accept(this);
+    node.mixinTypes.accept(this);
   }
 
   List<ElementAnnotation> _buildAnnotations(List<Annotation> nodeList) {
@@ -1139,29 +1128,19 @@ class ElementBuilder extends ThrowingAstVisitor<void> {
     _withEnclosing(holder, () {
       _visitPropertyFirst<FieldDeclaration>(node.members);
     });
-    element.accessors = holder.propertyAccessors;
-    element.fields = holder.properties.whereType<FieldElement>().toList();
-    element.methods = holder.methods;
 
-    if (holder.constructors.isEmpty) {
+    if (node is ClassDeclaration && holder.constructors.isEmpty) {
       holder.addConstructor(
-        '',
         ConstructorElementImpl('', -1)..isSynthetic = true,
       );
     }
 
-    var constructors = holder.constructors;
-    element.constructors = constructors;
+    element.accessors = holder.propertyAccessors;
+    element.constructors = holder.constructors;
+    element.fields = holder.properties.whereType<FieldElement>().toList();
+    element.methods = holder.methods;
 
-    // We have all fields and constructors.
-    // Now we can resolve field formal parameters.
-    for (var constructor in constructors) {
-      for (var parameter in constructor.parameters) {
-        if (parameter is FieldFormalParameterElementImpl) {
-          parameter.field = element.getField(parameter.name);
-        }
-      }
-    }
+    _resolveConstructorFieldFormals(element);
   }
 
   void _buildExecutableElementChildren({
@@ -1227,6 +1206,16 @@ class ElementBuilder extends ThrowingAstVisitor<void> {
     node?.accept(this);
   }
 
+  void _resolveConstructorFieldFormals(AbstractClassElementImpl element) {
+    for (var constructor in element.constructors) {
+      for (var parameter in constructor.parameters) {
+        if (parameter is FieldFormalParameterElementImpl) {
+          parameter.field = element.getField(parameter.name);
+        }
+      }
+    }
+  }
+
   Uri? _selectAbsoluteUri(NamespaceDirective directive) {
     var relativeUriStr = _selectRelativeUri(
       directive.configurations,
@@ -1254,7 +1243,7 @@ class ElementBuilder extends ThrowingAstVisitor<void> {
     if (uri == null) {
       return null;
     } else {
-      return _linker.elementFactory.libraryOfUri('$uri');
+      return _linker.elementFactory.libraryOfUri(uri);
     }
   }
 
@@ -1395,14 +1384,19 @@ class _EnclosingContext {
     this.hasConstConstructor = false,
   });
 
+  bool get isDartCoreEnum {
+    final element = this.element;
+    return element is ClassElementImpl && element.isDartCoreEnum;
+  }
+
   Reference addClass(String name, ClassElementImpl element) {
     classes.add(element);
     return _bindReference('@class', name, element);
   }
 
-  Reference addConstructor(String name, ConstructorElementImpl element) {
+  Reference addConstructor(ConstructorElementImpl element) {
     constructors.add(element);
-    return _bindReference('@constructor', name, element);
+    return _bindReference('@constructor', element.name, element);
   }
 
   Reference addEnum(String name, EnumElementImpl element) {
