@@ -11,7 +11,8 @@ main() {
   defineReflectiveSuite(() {
     defineReflectiveTests(DeprecatedMemberUse_BasicWorkspaceTest);
     defineReflectiveTests(
-        DeprecatedMemberUse_BasicWorkspace_WithNullSafetyTest);
+      DeprecatedMemberUse_BasicWorkspace_WithoutNullSafetyTest,
+    );
     defineReflectiveTests(DeprecatedMemberUse_BazelWorkspaceTest);
     defineReflectiveTests(DeprecatedMemberUse_GnWorkspaceTest);
     defineReflectiveTests(DeprecatedMemberUse_PackageBuildWorkspaceTest);
@@ -29,11 +30,15 @@ main() {
 }
 
 @reflectiveTest
-class DeprecatedMemberUse_BasicWorkspace_WithNullSafetyTest
+class DeprecatedMemberUse_BasicWorkspace_WithoutNullSafetyTest
     extends PubPackageResolutionTest
+    with WithoutNullSafetyMixin, DeprecatedMemberUse_BasicWorkspaceTestCases {}
+
+@reflectiveTest
+class DeprecatedMemberUse_BasicWorkspaceTest extends PubPackageResolutionTest
     with DeprecatedMemberUse_BasicWorkspaceTestCases {
   test_instanceCreation_namedParameter_fromLegacy() async {
-    newFile('$workspaceRootPath/aaa/lib/a.dart', content: r'''
+    newFile('$workspaceRootPath/aaa/lib/a.dart', r'''
 class A {
   A({@deprecated int a}) {}
 }
@@ -52,7 +57,7 @@ void f() {
   }
 
   test_methodInvocation_namedParameter_ofFunction_fromLegacy() async {
-    newFile('$workspaceRootPath/aaa/lib/a.dart', content: r'''
+    newFile('$workspaceRootPath/aaa/lib/a.dart', r'''
 void foo({@deprecated int a}) {}
 ''');
 
@@ -69,7 +74,7 @@ void f() {
   }
 
   test_methodInvocation_namedParameter_ofMethod_fromLegacy() async {
-    newFile('$workspaceRootPath/aaa/lib/a.dart', content: r'''
+    newFile('$workspaceRootPath/aaa/lib/a.dart', r'''
 class A {
   void foo({@deprecated int a}) {}
 }
@@ -88,7 +93,7 @@ void f(A a) {
   }
 
   test_superConstructorInvocation_namedParameter_fromLegacy() async {
-    newFile('$workspaceRootPath/aaa/lib/a.dart', content: r'''
+    newFile('$workspaceRootPath/aaa/lib/a.dart', r'''
 class A {
   A({@deprecated int a}) {}
 }
@@ -107,10 +112,6 @@ class B extends A {
   }
 }
 
-@reflectiveTest
-class DeprecatedMemberUse_BasicWorkspaceTest extends PubPackageResolutionTest
-    with WithoutNullSafetyMixin, DeprecatedMemberUse_BasicWorkspaceTestCases {}
-
 mixin DeprecatedMemberUse_BasicWorkspaceTestCases on PubPackageResolutionTest {
   @override
   void setUp() {
@@ -123,7 +124,7 @@ mixin DeprecatedMemberUse_BasicWorkspaceTestCases on PubPackageResolutionTest {
   }
 
   test_export() async {
-    newFile('$workspaceRootPath/aaa/lib/a.dart', content: r'''
+    newFile('$workspaceRootPath/aaa/lib/a.dart', r'''
 @deprecated
 library a;
 ''');
@@ -136,7 +137,7 @@ export 'package:aaa/a.dart';
   }
 
   test_field_inDeprecatedConstructor() async {
-    newFile('$workspaceRootPath/aaa/lib/a.dart', content: r'''
+    newFile('$workspaceRootPath/aaa/lib/a.dart', r'''
 class A {
   @deprecated
   int x = 0;
@@ -157,7 +158,7 @@ class B extends A {
   }
 
   test_fieldGet_implicitGetter() async {
-    newFile('$workspaceRootPath/aaa/lib/a.dart', content: r'''
+    newFile('$workspaceRootPath/aaa/lib/a.dart', r'''
 class A {
   @deprecated
   int foo = 0;
@@ -176,7 +177,7 @@ void f(A a) {
   }
 
   test_fieldSet_implicitSetter() async {
-    newFile('$workspaceRootPath/aaa/lib/a.dart', content: r'''
+    newFile('$workspaceRootPath/aaa/lib/a.dart', r'''
 class A {
   @deprecated
   int foo = 0;
@@ -195,7 +196,7 @@ void f(A a) {
   }
 
   test_import() async {
-    newFile('$workspaceRootPath/aaa/lib/a.dart', content: r'''
+    newFile('$workspaceRootPath/aaa/lib/a.dart', r'''
 @deprecated
 library a;
 ''');
@@ -210,7 +211,7 @@ import 'package:aaa/a.dart';
   }
 
   test_method_inDeprecatedConstructor() async {
-    newFile('$workspaceRootPath/aaa/lib/a.dart', content: r'''
+    newFile('$workspaceRootPath/aaa/lib/a.dart', r'''
 class A {
   @deprecated
   void foo() {}
@@ -230,7 +231,7 @@ class B extends A {
   }
 
   test_methodInvocation() async {
-    newFile('$workspaceRootPath/aaa/lib/a.dart', content: r'''
+    newFile('$workspaceRootPath/aaa/lib/a.dart', r'''
 class A {
   @deprecated
   void foo() {}
@@ -249,7 +250,7 @@ void f(A a) {
   }
 
   test_methodInvocation_withMessage() async {
-    newFile('$workspaceRootPath/aaa/lib/a.dart', content: r'''
+    newFile('$workspaceRootPath/aaa/lib/a.dart', r'''
 class A {
   @Deprecated('0.9')
   void foo() {}
@@ -268,7 +269,7 @@ void f(A a) {
   }
 
   test_parameter_named_ofFunction() async {
-    newFile('$workspaceRootPath/aaa/lib/a.dart', content: r'''
+    newFile('$workspaceRootPath/aaa/lib/a.dart', r'''
 void foo({@deprecated int a}) {}
 ''');
 
@@ -284,7 +285,7 @@ void f() {
   }
 
   test_parameter_named_ofMethod() async {
-    newFile('$workspaceRootPath/aaa/lib/a.dart', content: r'''
+    newFile('$workspaceRootPath/aaa/lib/a.dart', r'''
 class A {
   void foo({@deprecated int a}) {}
 }
@@ -302,7 +303,7 @@ void f(A a) {
   }
 
   test_setterInvocation() async {
-    newFile('$workspaceRootPath/aaa/lib/a.dart', content: r'''
+    newFile('$workspaceRootPath/aaa/lib/a.dart', r'''
 class A {
   @deprecated
   set foo(int _) {}
@@ -331,7 +332,7 @@ void f(A a) {
 class DeprecatedMemberUse_BazelWorkspaceTest
     extends BazelWorkspaceResolutionTest {
   test_dart() async {
-    newFile('$workspaceRootPath/foo/bar/lib/a.dart', content: r'''
+    newFile('$workspaceRootPath/foo/bar/lib/a.dart', r'''
 @deprecated
 class A {}
 ''');
@@ -346,7 +347,7 @@ void f(A a) {}
   }
 
   test_thirdPartyDart() async {
-    newFile('$workspaceThirdPartyDartPath/aaa/lib/a.dart', content: r'''
+    newFile('$workspaceThirdPartyDartPath/aaa/lib/a.dart', r'''
 @deprecated
 class A {}
 ''');
@@ -385,17 +386,17 @@ class DeprecatedMemberUse_GnWorkspaceTest extends ContextResolutionTest {
 
   test_differentPackage() async {
     newPubspecYamlFile('$workspaceRootPath/my', '');
-    newFile('$workspaceRootPath/my/BUILD.gn');
+    newFile('$workspaceRootPath/my/BUILD.gn', '');
 
     newPubspecYamlFile('$workspaceRootPath/aaa', '');
-    newFile('$workspaceRootPath/aaa/BUILD.gn');
+    newFile('$workspaceRootPath/aaa/BUILD.gn', '');
 
     _writeWorkspacePackagesFile({
       'aaa': '$workspaceRootPath/aaa/lib',
       'my': myPackageLibPath,
     });
 
-    newFile('$workspaceRootPath/aaa/lib/a.dart', content: r'''
+    newFile('$workspaceRootPath/aaa/lib/a.dart', r'''
 @deprecated
 class A {}
 ''');
@@ -411,13 +412,13 @@ void f(A a) {}
 
   test_samePackage() async {
     newPubspecYamlFile('$workspaceRootPath/my', '');
-    newFile('$workspaceRootPath/my/BUILD.gn');
+    newFile('$workspaceRootPath/my/BUILD.gn', '');
 
     _writeWorkspacePackagesFile({
       'my': myPackageLibPath,
     });
 
-    newFile('$myPackageLibPath/a.dart', content: r'''
+    newFile('$myPackageLibPath/a.dart', r'''
 @deprecated
 class A {}
 ''');
@@ -447,7 +448,7 @@ void f(A a) {}
 
     var buildDir = 'out/debug-x87_128';
     var genPath = '$workspaceRootPath/$buildDir/dartlang/gen';
-    newFile('$genPath/foo_package_config.json', content: '''{
+    newFile('$genPath/foo_package_config.json', '''{
   "configVersion": 2,
   "packages": [ ${packages.join(', ')} ]
 }''');
@@ -488,7 +489,7 @@ void f(A a) {}
         ..add(name: 'aaa', rootPath: '$workspaceRootPath/aaa'),
     );
 
-    newFile('$workspaceRootPath/aaa/lib/a.dart', content: r'''
+    newFile('$workspaceRootPath/aaa/lib/a.dart', r'''
 @deprecated
 class A {}
 ''');
@@ -596,7 +597,7 @@ class A {
   }
 
   test_class() async {
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 @deprecated
 class A {}
 ''');
@@ -626,7 +627,7 @@ f(A a) {
   }
 
   test_export() async {
-    newFile('$testPackageLibPath/deprecated_library.dart', content: r'''
+    newFile('$testPackageLibPath/deprecated_library.dart', r'''
 @deprecated
 library deprecated_library;
 class A {}
@@ -712,7 +713,7 @@ f(A a) {
   }
 
   test_hideCombinator() async {
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 @deprecated
 class A {}
 ''');
@@ -724,7 +725,7 @@ import 'a.dart' hide A;
   }
 
   test_import() async {
-    newFile('$testPackageLibPath/deprecated_library.dart', content: r'''
+    newFile('$testPackageLibPath/deprecated_library.dart', r'''
 @deprecated
 library deprecated_library;
 class A {}
@@ -1234,7 +1235,7 @@ f(A a) {
   }
 
   test_showCombinator() async {
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 @deprecated
 class A {}
 ''');
@@ -1558,7 +1559,7 @@ void f() {
 class DeprecatedMemberUseFromSamePackage_BazelWorkspaceTest
     extends BazelWorkspaceResolutionTest {
   test_it() async {
-    newFile('$myPackageLibPath/a.dart', content: r'''
+    newFile('$myPackageLibPath/a.dart', r'''
 @deprecated
 class A {}
 ''');
@@ -1601,7 +1602,7 @@ void f(A a) {}
     newPubspecYamlFile(testPackageRootPath, 'name: test');
     _createTestPackageBuildMarker();
 
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 @deprecated
 class A {}
 ''');
@@ -1638,7 +1639,7 @@ class _PackageBuildWorkspaceBase extends PubPackageResolutionTest {
   }) {
     newFile(
       '$testPackageGeneratedPath/$packageName/lib/$pathInLib',
-      content: content,
+      content,
     );
   }
 }
