@@ -16,14 +16,12 @@ main() {
 @reflectiveTest
 class ImportOfNonLibraryTest extends PubPackageResolutionTest {
   test_deferred() async {
-    newFile('$testPackageLibPath/lib1.dart', content: '''
+    newFile('$testPackageLibPath/lib1.dart', '''
 part of lib;
-class A {}
 ''');
     await assertErrorsInCode('''
 library lib;
 import 'lib1.dart' deferred as p;
-var a = new p.A();
 ''', [
       error(CompileTimeErrorCode.IMPORT_OF_NON_LIBRARY, 20, 11,
           messageContains: ["library 'lib1.dart' "]),
@@ -31,14 +29,12 @@ var a = new p.A();
   }
 
   test_part() async {
-    newFile('$testPackageLibPath/part.dart', content: r'''
+    newFile('$testPackageLibPath/part.dart', r'''
 part of lib;
-class A{}
 ''');
     await assertErrorsInCode(r'''
 library lib;
 import 'part.dart';
-A a = A();
 ''', [
       error(CompileTimeErrorCode.IMPORT_OF_NON_LIBRARY, 20, 11,
           messageContains: ["library 'part.dart' "]),
