@@ -24,7 +24,7 @@ class NonNullOptOutTest extends PubPackageResolutionTest {
   }
 
   test_assignment_indexExpression() async {
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 class A {
   void operator[]=(int a, int b) {}
 }
@@ -38,22 +38,44 @@ main(A a) {
 }
 ''');
 
-    assertAssignment(
-      findNode.assignment(' = null;'),
-      readElement: null,
-      readType: null,
-      writeElement: elementMatcher(
-        _import_a.method('[]='),
-        isLegacy: true,
-      ),
-      writeType: 'int*',
-      operatorElement: null,
-      type: 'Null*',
-    );
+    var assignment = findNode.assignment(' = null;');
+    assertResolvedNodeText(assignment, r'''
+AssignmentExpression
+  leftHandSide: IndexExpression
+    target: SimpleIdentifier
+      token: a
+      staticElement: self::@function::main::@parameter::a
+      staticType: A*
+    leftBracket: [
+    index: NullLiteral
+      literal: null
+      parameter: ParameterMember
+        base: package:test/a.dart::@class::A::@method::[]=::@parameter::a
+        isLegacy: true
+      staticType: Null*
+    rightBracket: ]
+    staticElement: <null>
+    staticType: null
+  operator: =
+  rightHandSide: NullLiteral
+    literal: null
+    parameter: ParameterMember
+      base: package:test/a.dart::@class::A::@method::[]=::@parameter::b
+      isLegacy: true
+    staticType: Null*
+  readElement: <null>
+  readType: null
+  writeElement: MethodMember
+    base: package:test/a.dart::@class::A::@method::[]=
+    isLegacy: true
+  writeType: int*
+  staticElement: <null>
+  staticType: Null*
+''');
   }
 
   test_assignment_prefixedIdentifier_instanceTarget_class_field() async {
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 class A {
   int foo = 0;
 }
@@ -66,22 +88,42 @@ main(A a) {
   a.foo = 0;
 }
 ''');
-    assertAssignment(
-      findNode.assignment('foo ='),
-      readElement: null,
-      readType: null,
-      writeElement: elementMatcher(
-        _import_a.setter('foo'),
-        isLegacy: true,
-      ),
-      writeType: 'int*',
-      operatorElement: null,
-      type: 'int*',
-    );
+
+    var assignment = findNode.assignment('foo =');
+    assertResolvedNodeText(assignment, r'''
+AssignmentExpression
+  leftHandSide: PrefixedIdentifier
+    prefix: SimpleIdentifier
+      token: a
+      staticElement: self::@function::main::@parameter::a
+      staticType: A*
+    period: .
+    identifier: SimpleIdentifier
+      token: foo
+      staticElement: <null>
+      staticType: null
+    staticElement: <null>
+    staticType: null
+  operator: =
+  rightHandSide: IntegerLiteral
+    literal: 0
+    parameter: ParameterMember
+      base: package:test/a.dart::@class::A::@setter::foo::@parameter::_foo
+      isLegacy: true
+    staticType: int*
+  readElement: <null>
+  readType: null
+  writeElement: PropertyAccessorMember
+    base: package:test/a.dart::@class::A::@setter::foo
+    isLegacy: true
+  writeType: int*
+  staticElement: <null>
+  staticType: int*
+''');
   }
 
   test_assignment_prefixedIdentifier_instanceTarget_extension_setter() async {
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 class A {}
 extension E on A {
   void set foo(int _) {}
@@ -95,22 +137,42 @@ main(A a) {
   a.foo = 0;
 }
 ''');
-    assertAssignment(
-      findNode.assignment('foo ='),
-      readElement: null,
-      readType: null,
-      writeElement: elementMatcher(
-        _import_a.setter('foo'),
-        isLegacy: true,
-      ),
-      writeType: 'int*',
-      operatorElement: null,
-      type: 'int*',
-    );
+
+    var assignment = findNode.assignment('foo =');
+    assertResolvedNodeText(assignment, r'''
+AssignmentExpression
+  leftHandSide: PrefixedIdentifier
+    prefix: SimpleIdentifier
+      token: a
+      staticElement: self::@function::main::@parameter::a
+      staticType: A*
+    period: .
+    identifier: SimpleIdentifier
+      token: foo
+      staticElement: <null>
+      staticType: null
+    staticElement: <null>
+    staticType: null
+  operator: =
+  rightHandSide: IntegerLiteral
+    literal: 0
+    parameter: ParameterMember
+      base: package:test/a.dart::@extension::E::@setter::foo::@parameter::_
+      isLegacy: true
+    staticType: int*
+  readElement: <null>
+  readType: null
+  writeElement: PropertyAccessorMember
+    base: package:test/a.dart::@extension::E::@setter::foo
+    isLegacy: true
+  writeType: int*
+  staticElement: <null>
+  staticType: int*
+''');
   }
 
   test_assignment_prefixedIdentifier_staticTarget_class_field() async {
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 class A {
   static int foo = 0;
 }
@@ -123,22 +185,42 @@ main() {
   A.foo = 0;
 }
 ''');
-    assertAssignment(
-      findNode.assignment('foo ='),
-      readElement: null,
-      readType: null,
-      writeElement: elementMatcher(
-        _import_a.setter('foo'),
-        isLegacy: true,
-      ),
-      writeType: 'int*',
-      operatorElement: null,
-      type: 'int*',
-    );
+
+    var assignment = findNode.assignment('foo =');
+    assertResolvedNodeText(assignment, r'''
+AssignmentExpression
+  leftHandSide: PrefixedIdentifier
+    prefix: SimpleIdentifier
+      token: A
+      staticElement: package:test/a.dart::@class::A
+      staticType: null
+    period: .
+    identifier: SimpleIdentifier
+      token: foo
+      staticElement: <null>
+      staticType: null
+    staticElement: <null>
+    staticType: null
+  operator: =
+  rightHandSide: IntegerLiteral
+    literal: 0
+    parameter: ParameterMember
+      base: package:test/a.dart::@class::A::@setter::foo::@parameter::_foo
+      isLegacy: true
+    staticType: int*
+  readElement: <null>
+  readType: null
+  writeElement: PropertyAccessorMember
+    base: package:test/a.dart::@class::A::@setter::foo
+    isLegacy: true
+  writeType: int*
+  staticElement: <null>
+  staticType: int*
+''');
   }
 
   test_assignment_prefixedIdentifier_staticTarget_extension_field() async {
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 extension E on int {
   static int foo = 0;
 }
@@ -151,22 +233,42 @@ main() {
   E.foo = 0;
 }
 ''');
-    assertAssignment(
-      findNode.assignment('foo ='),
-      readElement: null,
-      readType: null,
-      writeElement: elementMatcher(
-        _import_a.setter('foo'),
-        isLegacy: true,
-      ),
-      writeType: 'int*',
-      operatorElement: null,
-      type: 'int*',
-    );
+
+    var assignment = findNode.assignment('foo =');
+    assertResolvedNodeText(assignment, r'''
+AssignmentExpression
+  leftHandSide: PrefixedIdentifier
+    prefix: SimpleIdentifier
+      token: E
+      staticElement: package:test/a.dart::@extension::E
+      staticType: null
+    period: .
+    identifier: SimpleIdentifier
+      token: foo
+      staticElement: <null>
+      staticType: null
+    staticElement: <null>
+    staticType: null
+  operator: =
+  rightHandSide: IntegerLiteral
+    literal: 0
+    parameter: ParameterMember
+      base: package:test/a.dart::@extension::E::@setter::foo::@parameter::_foo
+      isLegacy: true
+    staticType: int*
+  readElement: <null>
+  readType: null
+  writeElement: PropertyAccessorMember
+    base: package:test/a.dart::@extension::E::@setter::foo
+    isLegacy: true
+  writeType: int*
+  staticElement: <null>
+  staticType: int*
+''');
   }
 
   test_assignment_prefixedIdentifier_topLevelVariable() async {
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 int foo = 0;
 ''');
     await assertNoErrorsInCode(r'''
@@ -177,22 +279,42 @@ main() {
   p.foo = 0;
 }
 ''');
-    assertAssignment(
-      findNode.assignment('foo ='),
-      readElement: null,
-      readType: null,
-      writeElement: elementMatcher(
-        _import_a.topSet('foo'),
-        isLegacy: true,
-      ),
-      writeType: 'int*',
-      operatorElement: null,
-      type: 'int*',
-    );
+
+    var assignment = findNode.assignment('foo =');
+    assertResolvedNodeText(assignment, r'''
+AssignmentExpression
+  leftHandSide: PrefixedIdentifier
+    prefix: SimpleIdentifier
+      token: p
+      staticElement: self::@prefix::p
+      staticType: null
+    period: .
+    identifier: SimpleIdentifier
+      token: foo
+      staticElement: <null>
+      staticType: null
+    staticElement: <null>
+    staticType: null
+  operator: =
+  rightHandSide: IntegerLiteral
+    literal: 0
+    parameter: ParameterMember
+      base: package:test/a.dart::@setter::foo::@parameter::_foo
+      isLegacy: true
+    staticType: int*
+  readElement: <null>
+  readType: null
+  writeElement: PropertyAccessorMember
+    base: package:test/a.dart::@setter::foo
+    isLegacy: true
+  writeType: int*
+  staticElement: <null>
+  staticType: int*
+''');
   }
 
   test_assignment_propertyAccess_class_field() async {
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 class A {
   int foo = 0;
 }
@@ -205,22 +327,52 @@ main() {
   A().foo = 0;
 }
 ''');
-    assertAssignment(
-      findNode.assignment('foo ='),
-      readElement: null,
-      readType: null,
-      writeElement: elementMatcher(
-        _import_a.setter('foo'),
-        isLegacy: true,
-      ),
-      writeType: 'int*',
-      operatorElement: null,
-      type: 'int*',
-    );
+
+    var assignment = findNode.assignment('foo =');
+    assertResolvedNodeText(assignment, r'''
+AssignmentExpression
+  leftHandSide: PropertyAccess
+    target: InstanceCreationExpression
+      constructorName: ConstructorName
+        type: NamedType
+          name: SimpleIdentifier
+            token: A
+            staticElement: package:test/a.dart::@class::A
+            staticType: null
+          type: A*
+        staticElement: ConstructorMember
+          base: package:test/a.dart::@class::A::@constructor::•
+          isLegacy: true
+      argumentList: ArgumentList
+        leftParenthesis: (
+        rightParenthesis: )
+      staticType: A*
+    operator: .
+    propertyName: SimpleIdentifier
+      token: foo
+      staticElement: <null>
+      staticType: null
+    staticType: null
+  operator: =
+  rightHandSide: IntegerLiteral
+    literal: 0
+    parameter: ParameterMember
+      base: package:test/a.dart::@class::A::@setter::foo::@parameter::_foo
+      isLegacy: true
+    staticType: int*
+  readElement: <null>
+  readType: null
+  writeElement: PropertyAccessorMember
+    base: package:test/a.dart::@class::A::@setter::foo
+    isLegacy: true
+  writeType: int*
+  staticElement: <null>
+  staticType: int*
+''');
   }
 
   test_assignment_propertyAccess_extension_setter() async {
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 class A {}
 extension E on A {
   void set foo(int a) {}
@@ -234,22 +386,52 @@ main() {
   A().foo = 0;
 }
 ''');
-    assertAssignment(
-      findNode.assignment('foo ='),
-      readElement: null,
-      readType: null,
-      writeElement: elementMatcher(
-        _import_a.setter('foo'),
-        isLegacy: true,
-      ),
-      writeType: 'int*',
-      operatorElement: null,
-      type: 'int*',
-    );
+
+    var assignment = findNode.assignment('foo =');
+    assertResolvedNodeText(assignment, r'''
+AssignmentExpression
+  leftHandSide: PropertyAccess
+    target: InstanceCreationExpression
+      constructorName: ConstructorName
+        type: NamedType
+          name: SimpleIdentifier
+            token: A
+            staticElement: package:test/a.dart::@class::A
+            staticType: null
+          type: A*
+        staticElement: ConstructorMember
+          base: package:test/a.dart::@class::A::@constructor::•
+          isLegacy: true
+      argumentList: ArgumentList
+        leftParenthesis: (
+        rightParenthesis: )
+      staticType: A*
+    operator: .
+    propertyName: SimpleIdentifier
+      token: foo
+      staticElement: <null>
+      staticType: null
+    staticType: null
+  operator: =
+  rightHandSide: IntegerLiteral
+    literal: 0
+    parameter: ParameterMember
+      base: package:test/a.dart::@extension::E::@setter::foo::@parameter::a
+      isLegacy: true
+    staticType: int*
+  readElement: <null>
+  readType: null
+  writeElement: PropertyAccessorMember
+    base: package:test/a.dart::@extension::E::@setter::foo
+    isLegacy: true
+  writeType: int*
+  staticElement: <null>
+  staticType: int*
+''');
   }
 
   test_assignment_propertyAccess_extensionOverride_setter() async {
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 class A {}
 extension E on A {
   void set foo(int a) {}
@@ -263,22 +445,53 @@ main(A a) {
   E(a).foo = 0;
 }
 ''');
-    assertAssignment(
-      findNode.assignment('foo ='),
-      readElement: null,
-      readType: null,
-      writeElement: elementMatcher(
-        _import_a.setter('foo'),
-        isLegacy: true,
-      ),
-      writeType: 'int*',
-      operatorElement: null,
-      type: 'int*',
-    );
+
+    var assignment = findNode.assignment('foo =');
+    assertResolvedNodeText(assignment, r'''
+AssignmentExpression
+  leftHandSide: PropertyAccess
+    target: ExtensionOverride
+      extensionName: SimpleIdentifier
+        token: E
+        staticElement: package:test/a.dart::@extension::E
+        staticType: null
+      argumentList: ArgumentList
+        leftParenthesis: (
+        arguments
+          SimpleIdentifier
+            token: a
+            parameter: <null>
+            staticElement: self::@function::main::@parameter::a
+            staticType: A*
+        rightParenthesis: )
+      extendedType: A
+      staticType: null
+    operator: .
+    propertyName: SimpleIdentifier
+      token: foo
+      staticElement: <null>
+      staticType: null
+    staticType: null
+  operator: =
+  rightHandSide: IntegerLiteral
+    literal: 0
+    parameter: ParameterMember
+      base: package:test/a.dart::@extension::E::@setter::foo::@parameter::a
+      isLegacy: true
+    staticType: int*
+  readElement: <null>
+  readType: null
+  writeElement: PropertyAccessorMember
+    base: package:test/a.dart::@extension::E::@setter::foo
+    isLegacy: true
+  writeType: int*
+  staticElement: <null>
+  staticType: int*
+''');
   }
 
   test_assignment_propertyAccess_superTarget() async {
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 class A {
   int foo = 0;
 }
@@ -293,22 +506,40 @@ class B extends A {
   }
 }
 ''');
-    assertAssignment(
-      findNode.assignment('foo ='),
-      readElement: null,
-      readType: null,
-      writeElement: elementMatcher(
-        _import_a.setter('foo'),
-        isLegacy: true,
-      ),
-      writeType: 'int*',
-      operatorElement: null,
-      type: 'int*',
-    );
+
+    var assignment = findNode.assignment('foo =');
+    assertResolvedNodeText(assignment, r'''
+AssignmentExpression
+  leftHandSide: PropertyAccess
+    target: SuperExpression
+      superKeyword: super
+      staticType: B*
+    operator: .
+    propertyName: SimpleIdentifier
+      token: foo
+      staticElement: <null>
+      staticType: null
+    staticType: null
+  operator: =
+  rightHandSide: IntegerLiteral
+    literal: 0
+    parameter: ParameterMember
+      base: package:test/a.dart::@class::A::@setter::foo::@parameter::_foo
+      isLegacy: true
+    staticType: int*
+  readElement: <null>
+  readType: null
+  writeElement: PropertyAccessorMember
+    base: package:test/a.dart::@class::A::@setter::foo
+    isLegacy: true
+  writeType: int*
+  staticElement: <null>
+  staticType: int*
+''');
   }
 
   test_assignment_simpleIdentifier_topLevelVariable() async {
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 int foo = 0;
 ''');
     await assertNoErrorsInCode(r'''
@@ -319,22 +550,34 @@ main() {
   foo = null;
 }
 ''');
-    assertAssignment(
-      findNode.assignment('foo ='),
-      readElement: null,
-      readType: null,
-      writeElement: elementMatcher(
-        _import_a.topSet('foo'),
-        isLegacy: true,
-      ),
-      writeType: 'int*',
-      operatorElement: null,
-      type: 'Null*',
-    );
+
+    var assignment = findNode.assignment('foo =');
+    assertResolvedNodeText(assignment, r'''
+AssignmentExpression
+  leftHandSide: SimpleIdentifier
+    token: foo
+    staticElement: <null>
+    staticType: null
+  operator: =
+  rightHandSide: NullLiteral
+    literal: null
+    parameter: ParameterMember
+      base: package:test/a.dart::@setter::foo::@parameter::_foo
+      isLegacy: true
+    staticType: Null*
+  readElement: <null>
+  readType: null
+  writeElement: PropertyAccessorMember
+    base: package:test/a.dart::@setter::foo
+    isLegacy: true
+  writeType: int*
+  staticElement: <null>
+  staticType: Null*
+''');
   }
 
   test_binaryExpression() async {
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 class A {
   int operator+(int a) => 0;
 }
@@ -356,7 +599,7 @@ main(A a) {
   }
 
   test_functionExpressionInvocation() async {
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 int Function(int, int?)? foo;
 ''');
     await assertNoErrorsInCode(r'''
@@ -379,7 +622,7 @@ main() {
   }
 
   test_functionExpressionInvocation_call() async {
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 class A {
   int call(int a, int? b) => 0;
 }
@@ -404,7 +647,7 @@ main(A a) {
   }
 
   test_functionExpressionInvocation_extension_staticTarget() async {
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 extension E on int {
   static int Function(int) get foo => (_) => 0;
 }
@@ -429,7 +672,7 @@ main() {
   }
 
   test_instanceCreation() async {
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 class A {
   A(int a, int? b);
 }
@@ -452,7 +695,7 @@ main() {
   }
 
   test_instanceCreation_generic() async {
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 class A<T> {
   A(T a, T? b);
 }
@@ -476,7 +719,7 @@ main() {
   }
 
   test_instanceCreation_generic_instantiateToBounds() async {
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 class A<T extends num> {}
 ''');
     await assertNoErrorsInCode(r'''
@@ -491,7 +734,7 @@ var v = A();
   }
 
   test_methodInvocation_extension_functionTarget() async {
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 extension E on void Function() {
   int foo(int a) => 0;
 }
@@ -516,7 +759,7 @@ main(void Function() a) {
   }
 
   test_methodInvocation_extension_interfaceTarget() async {
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 extension E on int {
   int foo(int a) => 0;
 }
@@ -541,7 +784,7 @@ main() {
   }
 
   test_methodInvocation_extension_nullTarget() async {
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 class A {}
 extension E on A {
   int foo(int a) => 0;
@@ -569,7 +812,7 @@ class B extends A {
   }
 
   test_methodInvocation_extension_staticTarget() async {
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 extension E on int {
   static int foo(int a) => 0;
 }
@@ -594,7 +837,7 @@ main() {
   }
 
   test_methodInvocation_extensionOverride() async {
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 extension E on int {
   int foo(int a) => 0;
 }
@@ -619,7 +862,7 @@ main() {
   }
 
   test_methodInvocation_function() async {
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 int foo(int a, int? b) => 0;
 ''');
     await assertNoErrorsInCode(r'''
@@ -642,7 +885,7 @@ main() {
   }
 
   test_methodInvocation_function_prefixed() async {
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 int foo(int a, int? b) => 0;
 ''');
     await assertNoErrorsInCode(r'''
@@ -665,7 +908,7 @@ main() {
   }
 
   test_methodInvocation_method_cascade() async {
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 class A {
   int foo(int a, int? b) => 0;
 }
@@ -690,7 +933,7 @@ main(A a) {
   }
 
   test_methodInvocation_method_interfaceTarget() async {
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 class A {
   int foo(int a, int? b) => 0;
 }
@@ -715,7 +958,7 @@ main(A a) {
   }
 
   test_methodInvocation_method_nullTarget() async {
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 class A {
   int foo(int a, int? b) => 0;
 }
@@ -742,7 +985,7 @@ class B extends A {
   }
 
   test_methodInvocation_method_staticTarget() async {
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 class A {
   static int foo(int a, int? b) => 0;
 }
@@ -767,7 +1010,7 @@ main() {
   }
 
   test_methodInvocation_method_superTarget() async {
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 class A {
   int foo(int a, int? b) => 0;
 }
@@ -821,7 +1064,7 @@ f(String x) {
   }
 
   test_postfixExpression() async {
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 class A {
   A operator+(int a) => this;
 }
@@ -842,7 +1085,7 @@ main(A a) {
   }
 
   test_prefixExpression() async {
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 class A {
   int operator-() => 0;
 }
@@ -863,7 +1106,7 @@ main(A a) {
   }
 
   test_read_indexExpression_class() async {
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 class A {
   int operator[](int a) => 0;
 }
@@ -884,7 +1127,7 @@ main(A a) {
   }
 
   test_read_prefixedIdentifier_instanceTarget_class_field() async {
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 class A {
   int foo;
 }
@@ -908,7 +1151,7 @@ main(A a) {
   }
 
   test_read_prefixedIdentifier_instanceTarget_extension_getter() async {
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 class A {}
 extension E on A {
   int get foo => 0;
@@ -933,7 +1176,7 @@ main(A a) {
   }
 
   test_read_prefixedIdentifier_staticTarget_class_field() async {
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 class A {
   static int foo;
 }
@@ -957,7 +1200,7 @@ main() {
   }
 
   test_read_prefixedIdentifier_staticTarget_class_method() async {
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 class A {
   static int foo(int a) => 0;
 }
@@ -981,7 +1224,7 @@ main() {
   }
 
   test_read_prefixedIdentifier_staticTarget_extension_field() async {
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 extension E {
   static int foo;
 }
@@ -1005,7 +1248,7 @@ main() {
   }
 
   test_read_prefixedIdentifier_staticTarget_extension_method() async {
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 extension E {
   static int foo(int a) => 0;
 }
@@ -1029,7 +1272,7 @@ main() {
   }
 
   test_read_prefixedIdentifier_topLevelVariable() async {
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 int foo = 0;
 ''');
     await assertNoErrorsInCode(r'''
@@ -1051,7 +1294,7 @@ main() {
   }
 
   test_read_propertyAccessor_class_field() async {
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 class A {
   int foo = 0;
 }
@@ -1075,7 +1318,7 @@ main() {
   }
 
   test_read_propertyAccessor_class_method() async {
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 class A {
   int foo() => 0;
 }
@@ -1099,7 +1342,7 @@ main() {
   }
 
   test_read_propertyAccessor_extensionOverride_getter() async {
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 class A {}
 extension E on A {
   int get foo => 0;
@@ -1124,7 +1367,7 @@ main(A a) {
   }
 
   test_read_propertyAccessor_superTarget() async {
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 class A {
   int foo = 0;
 }
@@ -1150,7 +1393,7 @@ class B extends A {
   }
 
   test_read_simpleIdentifier_class_field() async {
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 class A {
   int foo = 0;
 }
@@ -1173,7 +1416,7 @@ class B extends A {
   }
 
   test_read_simpleIdentifier_class_method() async {
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 class A {
   int foo(int a) => 0;
 }
@@ -1196,7 +1439,7 @@ class B extends A {
   }
 
   test_read_simpleIdentifier_extension_getter() async {
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 class A {}
 extension E on A {
   int get foo => 0;
@@ -1220,7 +1463,7 @@ class B extends A {
   }
 
   test_read_simpleIdentifier_extension_method() async {
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 class A {}
 extension E on A {
   int foo(int a) => 0;
@@ -1244,7 +1487,7 @@ class B extends A {
   }
 
   test_read_simpleIdentifier_topLevelVariable() async {
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 int foo = 0;
 ''');
     await assertNoErrorsInCode(r'''
@@ -1263,7 +1506,7 @@ main() {
   }
 
   test_superConstructorInvocation() async {
-    newFile('$testPackageLibPath/a.dart', content: r'''
+    newFile('$testPackageLibPath/a.dart', r'''
 class A {
   A(int a, int? b);
 }
