@@ -9,7 +9,9 @@ import 'package:analyzer/dart/element/element.dart';
 import 'package:analyzer/dart/element/type.dart';
 import 'package:analyzer/src/dart/element/element.dart';
 import 'package:analyzer/src/generated/source.dart';
+import 'package:analyzer/src/summary2/export.dart';
 import 'package:analyzer/src/task/inference_error.dart';
+import 'package:collection/collection.dart';
 import 'package:test/test.dart';
 
 import 'resolved_ast_printer.dart';
@@ -31,10 +33,11 @@ void applyCheckElementTextReplacements() {
   if (_testPath != null && _replacements.isNotEmpty) {
     _replacements.sort((a, b) => b.offset - a.offset);
     String newCode = _testCode!;
-    _replacements.forEach((r) {
-      newCode =
-          newCode.substring(0, r.offset) + r.text + newCode.substring(r.end);
-    });
+    for (var replacement in _replacements) {
+      newCode = newCode.substring(0, replacement.offset) +
+          replacement.text +
+          newCode.substring(replacement.end);
+    }
     File(_testPath!).writeAsStringSync(newCode);
   }
 }
@@ -101,14 +104,14 @@ void checkElementText(
       int expectationEnd = _testCode!.indexOf("'''", expectationOffset);
 
       _replacements.add(
-          _Replacement(expectationOffset, expectationEnd, '\n' + actualText));
+          _Replacement(expectationOffset, expectationEnd, '\n$actualText'));
     }
   }
 
   // Print the actual text to simplify copy/paste into the expectation.
   // if (actualText != expected) {
   //   print('-------- Actual --------');
-  //   print(actualText + '------------------------');
+  //   print('$actualText------------------------');
   // }
 
   expect(actualText, expected);
@@ -134,6 +137,8 @@ class _ElementWriter {
   });
 
   void writeLibraryElement(LibraryElement e) {
+    e as LibraryElementImpl;
+
     _writelnWithIndent('library');
     _withIndent(() {
       var name = e.name;
@@ -168,9 +173,13 @@ class _ElementWriter {
       });
 
       if (withExportScope) {
-        _writelnWithIndent('exportScope');
+        _writelnWithIndent('exportedReferences');
         _withIndent(() {
-          _writeExportScope(e);
+          _writeExportedReferences(e);
+        });
+        _writelnWithIndent('exportNamespace');
+        _withIndent(() {
+          _writeExportNamespace(e);
         });
       }
     });
@@ -213,7 +222,8 @@ class _ElementWriter {
       selfUriStr: selfUriStr,
       sink: buffer,
       indent: indent,
-      withNullability: true,
+      // TODO(scheglov) https://github.com/dart-lang/sdk/issues/49101
+      withParameterElements: false,
       withOffsets: true,
     );
   }
@@ -244,12 +254,6 @@ class _ElementWriter {
     return components.join(';');
   }
 
-  String? _typeStr(DartType? type) {
-    return type?.getDisplayString(
-      withNullability: true,
-    );
-  }
-
   void _withIndent(void Function() f) {
     var savedIndent = indent;
     indent = '$savedIndent  ';
@@ -269,11 +273,16 @@ class _ElementWriter {
     }
 
     _writeIf(e.isGenerator, '*');
+
+    if (e is ExecutableElementImpl && e.invokesSuperSelf) {
+      buffer.write(' invokesSuperSelf');
+    }
   }
 
   void _writeClassElement(ClassElement e) {
     _writeIndentedLine(() {
       _writeIf(e.isAbstract && !e.isMixin, 'abstract ');
+      _writeIf(e.isMacro, 'macro ');
       _writeIf(!e.isSimplyBounded, 'notSimplyBounded ');
 
       if (e.isEnum) {
@@ -297,7 +306,7 @@ class _ElementWriter {
       var supertype = e.supertype;
       if (supertype != null &&
           (supertype.element.name != 'Object' || e.mixins.isNotEmpty)) {
-        _writeType(supertype, name: 'supertype');
+        _writeType('supertype', supertype);
       }
 
       if (e.isMixin) {
@@ -305,21 +314,21 @@ class _ElementWriter {
         if (superclassConstraints.isEmpty) {
           throw StateError('At least Object is expected.');
         }
-        _writeElements<DartType>(
-          'superclassConstraints',
-          superclassConstraints,
-          _writeType,
-        );
+        _writeTypeList('superclassConstraints', superclassConstraints);
       }
 
-      _writeElements<DartType>('mixins', e.mixins, _writeType);
-      _writeElements<DartType>('interfaces', e.interfaces, _writeType);
+      _writeTypeList('mixins', e.mixins);
+      _writeTypeList('interfaces', e.interfaces);
 
       _writeElements('fields', e.fields, _writePropertyInducingElement);
 
       var constructors = e.constructors;
-      expect(constructors, isNotEmpty);
-      _writeElements('constructors', constructors, _writeConstructorElement);
+      if (e.isMixin) {
+        expect(constructors, isEmpty);
+      } else {
+        expect(constructors, isNotEmpty);
+        _writeElements('constructors', constructors, _writeConstructorElement);
+      }
 
       _writeElements('accessors', e.accessors, _writePropertyAccessorElement);
       _writeElements('methods', e.methods, _writeMethodElement);
@@ -416,7 +425,9 @@ class _ElementWriter {
       expect(e.nameOffset, -1);
       expect(e.nonSynthetic, same(e.enclosingElement));
     } else {
-      expect(e.nameOffset, isPositive);
+      if (!e.isTempAugmentation) {
+        expect(e.nameOffset, isPositive);
+      }
     }
   }
 
@@ -452,6 +463,23 @@ class _ElementWriter {
     }
   }
 
+  void _writeExportedReferences(LibraryElementImpl e) {
+    final exportedReferences = e.exportedReferences.toList();
+    exportedReferences.sortBy((e) => e.reference.toString());
+
+    for (final exported in exportedReferences) {
+      _writeIndentedLine(() {
+        if (exported is ExportedReferenceDeclared) {
+          buffer.write('declared ');
+        } else if (exported is ExportedReferenceExported) {
+          buffer.write('exported${exported.indexes} ');
+        }
+        // TODO(scheglov) Use the same writer as for resolved AST.
+        buffer.write(exported.reference);
+      });
+    }
+  }
+
   void _writeExportElement(ExportElement e) {
     _writeIndentedLine(() {
       _writeUri(e.exportedLibrary?.source);
@@ -465,7 +493,7 @@ class _ElementWriter {
     _assertNonSyntheticElementSelf(e);
   }
 
-  void _writeExportScope(LibraryElement e) {
+  void _writeExportNamespace(LibraryElement e) {
     var map = e.exportNamespace.definedNames;
     var names = map.keys.toList()..sort();
     for (var name in names) {
@@ -485,7 +513,7 @@ class _ElementWriter {
       _writeMetadata(e);
       _writeCodeRange(e);
       _writeTypeParameterElements(e.typeParameters);
-      _writeType(e.extendedType, name: 'extendedType');
+      _writeType('extendedType', e.extendedType);
     });
 
     _withIndent(() {
@@ -509,6 +537,8 @@ class _ElementWriter {
   }
 
   void _writeFunctionElement(FunctionElement e) {
+    expect(e.isStatic, isTrue);
+
     _writeIndentedLine(() {
       _writeIf(e.isExternal, 'external ');
       _writeName(e);
@@ -521,7 +551,7 @@ class _ElementWriter {
       _writeCodeRange(e);
       _writeTypeParameterElements(e.typeParameters);
       _writeParameterElements(e.parameters);
-      _writeType(e.returnType, name: 'returnType');
+      _writeType('returnType', e.returnType);
     });
 
     _assertNonSyntheticElementSelf(e);
@@ -596,7 +626,7 @@ class _ElementWriter {
 
       _writeTypeParameterElements(e.typeParameters);
       _writeParameterElements(e.parameters);
-      _writeType(e.returnType, name: 'returnType');
+      _writeType('returnType', e.returnType);
       _writeNonSyntheticElement(e);
     });
 
@@ -671,7 +701,7 @@ class _ElementWriter {
     });
 
     _withIndent(() {
-      _writeType(e.type, name: 'type');
+      _writeType('type', e.type);
       _writeMetadata(e);
       _writeCodeRange(e);
       _writeTypeParameterElements(e.typeParameters);
@@ -688,6 +718,8 @@ class _ElementWriter {
   }
 
   void _writePropertyAccessorElement(PropertyAccessorElement e) {
+    e as PropertyAccessorElementImpl;
+
     PropertyInducingElement variable = e.variable;
     expect(variable, isNotNull);
 
@@ -713,7 +745,9 @@ class _ElementWriter {
     if (e.isSynthetic) {
       expect(e.nameOffset, -1);
     } else {
-      expect(e.nameOffset, isPositive);
+      if (!e.isTempAugmentation) {
+        expect(e.nameOffset, isPositive);
+      }
       _assertNonSyntheticElementSelf(e);
     }
 
@@ -740,12 +774,14 @@ class _ElementWriter {
 
       expect(e.typeParameters, isEmpty);
       _writeParameterElements(e.parameters);
-      _writeType(e.returnType, name: 'returnType');
+      _writeType('returnType', e.returnType);
       _writeNonSyntheticElement(e);
     });
   }
 
   void _writePropertyInducingElement(PropertyInducingElement e) {
+    e as PropertyInducingElementImpl;
+
     DartType type = e.type;
     expect(type, isNotNull);
 
@@ -759,7 +795,9 @@ class _ElementWriter {
         _assertSyntheticAccessorEnclosing(e, e.setter!);
       }
 
-      expect(e.nameOffset, isPositive);
+      if (!e.isTempAugmentation) {
+        expect(e.nameOffset, isPositive);
+      }
       _assertNonSyntheticElementSelf(e);
     }
 
@@ -782,7 +820,7 @@ class _ElementWriter {
       _writeMetadata(e);
       _writeCodeRange(e);
       _writeTypeInferenceError(e);
-      _writeType(e.type, name: 'type');
+      _writeType('type', e.type);
       _writeConstantInitializer(e);
       _writeNonSyntheticElement(e);
     });
@@ -799,26 +837,8 @@ class _ElementWriter {
     }
   }
 
-  void _writeType(DartType type, {String? name}) {
-    var typeStr = _typeStr(type);
-    if (name != null) {
-      _writelnWithIndent('$name: $typeStr');
-    } else {
-      _writelnWithIndent('$typeStr');
-    }
-
-    var alias = type.alias;
-    if (alias != null) {
-      _withIndent(() {
-        _createAstPrinter().writeElement('aliasElement', alias.element);
-
-        _writeElements<DartType>(
-          'aliasArguments',
-          alias.typeArguments,
-          _writeType,
-        );
-      });
-    }
+  void _writeType(String name, DartType type) {
+    _createAstPrinter().writeType(type, name: name);
   }
 
   void _writeTypeAliasElement(TypeAliasElement e) {
@@ -837,7 +857,7 @@ class _ElementWriter {
       _writeTypeParameterElements(e.typeParameters);
 
       var aliasedType = e.aliasedType;
-      _writeType(aliasedType, name: 'aliasedType');
+      _writeType('aliasedType', aliasedType);
       // TODO(scheglov) https://github.com/dart-lang/sdk/issues/44629
       // TODO(scheglov) Remove it when we stop providing it everywhere.
       if (aliasedType is FunctionType) {
@@ -850,7 +870,7 @@ class _ElementWriter {
         _withIndent(() {
           _writeTypeParameterElements(aliasedElement.typeParameters);
           _writeParameterElements(aliasedElement.parameters);
-          _writeType(aliasedElement.returnType, name: 'returnType');
+          _writeType('returnType', aliasedElement.returnType);
         });
       }
     });
@@ -875,6 +895,10 @@ class _ElementWriter {
     }
   }
 
+  void _writeTypeList(String name, List<DartType> types) {
+    _createAstPrinter().writeTypeList(name, types);
+  }
+
   void _writeTypeParameterElement(TypeParameterElement e) {
     e as TypeParameterElementImpl;
 
@@ -888,12 +912,12 @@ class _ElementWriter {
 
       var bound = e.bound;
       if (bound != null) {
-        _writeType(bound, name: 'bound');
+        _writeType('bound', bound);
       }
 
       var defaultType = e.defaultType;
       if (defaultType != null) {
-        _writeType(defaultType, name: 'defaultType');
+        _writeType('defaultType', defaultType);
       }
 
       _writeMetadata(e);
@@ -932,7 +956,7 @@ class _ElementWriter {
       if (uri.isScheme('file')) {
         uriStr = uri.pathSegments.last;
       }
-      buffer.write('$uriStr');
+      buffer.write(uriStr);
     } else {
       buffer.write('<unresolved>');
     }
@@ -946,3 +970,10 @@ class _Replacement {
 
   _Replacement(this.offset, this.end, this.text);
 }
+
+extension on ClassElement {
+  bool get isMacro {
+    final self = this;
+    return self is ClassElementImpl && self.isMacro;
+  }
+}
