@@ -76,9 +76,9 @@ void main() {
     });
 
     setUpAll(() {
-      registerFallbackValue<MediaStreamTrack>(MockMediaStreamTrack());
-      registerFallbackValue<CameraOptions>(MockCameraOptions());
-      registerFallbackValue<FlashMode>(FlashMode.off);
+      registerFallbackValue(MockMediaStreamTrack());
+      registerFallbackValue(MockCameraOptions());
+      registerFallbackValue(FlashMode.off);
     });
 
     testWidgets('CameraPlugin is the live instance',
@@ -498,7 +498,7 @@ void main() {
               isA<CameraException>().having(
                 (CameraException e) => e.code,
                 'code',
-                exception.code.toString(),
+                exception.code,
               ),
             ),
           );
@@ -759,7 +759,7 @@ void main() {
               isA<PlatformException>().having(
                 (PlatformException e) => e.code,
                 'code',
-                exception.name.toString(),
+                exception.name,
               ),
             ),
           );
@@ -2495,7 +2495,7 @@ void main() {
             equals(
               CameraErrorEvent(
                 cameraId,
-                'Error code: ${CameraErrorCode.abort}, error message: The video element\'s source has not fully loaded.',
+                "Error code: ${CameraErrorCode.abort}, error message: The video element's source has not fully loaded.",
               ),
             ),
           );
