@@ -16,6 +16,7 @@ import 'package:webkit_inspection_protocol/webkit_inspection_protocol.dart'
 
 import '../loaders/strategy.dart';
 import '../services/chrome_proxy_service.dart';
+import '../services/chrome_debug_exception.dart';
 import '../utilities/conversions.dart';
 import '../utilities/dart_uri.dart';
 import '../utilities/domain.dart';
@@ -67,7 +68,10 @@ class Debugger extends Domain {
 
   PauseState _pauseState = PauseState.none;
 
-  bool _pausedOverlayVisible = false;
+  // TODO(elliette): https://github.com/dart-lang/webdev/issues/1501 Re-enable
+  // after checking with Chrome team if there is a way to check if the Chrome
+  // DevTools is showing an overlay. Both cannot be shown at the same time:
+  // bool _pausedOverlayVisible = false;
 
   String get pauseState => _pauseModePauseStates.entries
       .firstWhere((entry) => entry.value == _pauseState)
@@ -84,7 +88,7 @@ class Debugger extends Domain {
 
   Future<Success> pause() async {
     _isStepping = false;
-    var result = await _remoteDebugger.pause();
+    final result = await _remoteDebugger.pause();
     handleErrorIfPresent(result);
     return Success();
   }
@@ -156,7 +160,7 @@ class Debugger extends Domain {
           'Cannot compute stack when application is not paused');
     }
 
-    var frames = await stackComputer.calculateFrames(limit: limit);
+    final frames = await stackComputer.calculateFrames(limit: limit);
     return Stack(
         frames: frames,
         messages: [],
@@ -171,7 +175,7 @@ class Debugger extends Domain {
     SkipLists skipLists,
     String root,
   ) async {
-    var debugger = Debugger._(
+    final debugger = Debugger._(
       remoteDebugger,
       streamNotify,
       appInspectorProvider,
@@ -225,15 +229,16 @@ class Debugger extends Domain {
     int line, {
     int column,
   }) async {
+    column ??= 0;
     checkIsolate('addBreakpoint', isolateId);
-    final breakpoint = await _breakpoints.add(scriptId, line);
+    final breakpoint = await _breakpoints.add(scriptId, line, column);
     _notifyBreakpoint(breakpoint);
     return breakpoint;
   }
 
   Future<ScriptRef> _updatedScriptRefFor(Breakpoint breakpoint) async {
-    var oldRef = (breakpoint.location as SourceLocation).script;
-    var dartUri = DartUri(oldRef.uri, _root);
+    final oldRef = (breakpoint.location as SourceLocation).script;
+    final dartUri = DartUri(oldRef.uri, _root);
     return await inspector.scriptRefFor(dartUri.serverPath);
   }
 
@@ -244,10 +249,12 @@ class Debugger extends Domain {
     // Previous breakpoints were never removed from Chrome since we use
     // `setBreakpointByUrl`. We simply need to update the references.
     for (var breakpoint in previousBreakpoints) {
-      var scriptRef = await _updatedScriptRefFor(breakpoint);
-      var updatedLocation = await _locations.locationForDart(
-          DartUri(scriptRef.uri, _root), _lineNumberFor(breakpoint));
-      var updatedBreakpoint = _breakpoints._dartBreakpoint(
+      final scriptRef = await _updatedScriptRefFor(breakpoint);
+      final updatedLocation = await _locations.locationForDart(
+          DartUri(scriptRef.uri, _root),
+          _lineNumberFor(breakpoint),
+          _columnNumberFor(breakpoint));
+      final updatedBreakpoint = _breakpoints._dartBreakpoint(
           scriptRef, updatedLocation, breakpoint.id);
       _breakpoints._note(
           bp: updatedBreakpoint,
@@ -260,7 +267,8 @@ class Debugger extends Domain {
       await addBreakpoint(
           inspector.isolate.id,
           (await _updatedScriptRefFor(breakpoint)).id,
-          _lineNumberFor(breakpoint));
+          _lineNumberFor(breakpoint),
+          column: _columnNumberFor(breakpoint));
     }
   }
 
@@ -285,7 +293,7 @@ class Debugger extends Domain {
     final jsId = _breakpoints.jsId(breakpointId);
     await _removeBreakpoint(jsId);
 
-    var bp = await _breakpoints.remove(jsId: jsId, dartId: breakpointId);
+    final bp = await _breakpoints.remove(jsId: jsId, dartId: breakpointId);
     if (bp != null) {
       _streamNotify(
         'Debug',
@@ -302,7 +310,7 @@ class Debugger extends Domain {
   /// Call the Chrome protocol removeBreakpoint.
   Future<void> _removeBreakpoint(String breakpointId) async {
     try {
-      var response = await _remoteDebugger.removeBreakpoint(breakpointId);
+      final response = await _remoteDebugger.removeBreakpoint(breakpointId);
       handleErrorIfPresent(response);
     } on WipError catch (e) {
       throw RPCError('removeBreakpoint', 102, '$e');
@@ -310,7 +318,7 @@ class Debugger extends Domain {
   }
 
   /// Returns Chrome script uri for Chrome script ID.
-  String _urlForScriptId(String scriptId) =>
+  String urlForScriptId(String scriptId) =>
       _remoteDebugger.scripts[scriptId]?.url;
 
   /// Returns source [Location] for the paused event.
@@ -318,20 +326,28 @@ class Debugger extends Domain {
   /// If we do not have [Location] data for the embedded JS location, null is
   /// returned.
   Future<Location> _sourceLocation(DebuggerPausedEvent e) {
-    var frame = e.params['callFrames'][0];
-    var location = frame['location'];
-    var scriptId = location['scriptId'] as String;
-    var lineNumber = location['lineNumber'] as int;
+    final frame = e.params['callFrames'][0];
+    final location = frame['location'];
+    final scriptId = location['scriptId'] as String;
+    final line = location['lineNumber'] as int;
+    final column = location['columnNumber'] as int;
 
-    var url = _urlForScriptId(scriptId);
-    return _locations.locationForJs(url, lineNumber + 1);
+    final url = urlForScriptId(scriptId);
+    if (url == null) return null;
+    return _locations.locationForJs(url, line, column);
+  }
+
+  /// Returns script ID for the paused event.
+  String _frameScriptId(DebuggerPausedEvent e) {
+    final frame = e.params['callFrames'][0];
+    return frame['location']['scriptId'] as String;
   }
 
   /// The variables visible in a frame in Dart protocol [BoundVariable] form.
   Future<List<BoundVariable>> variablesFor(WipCallFrame frame) async {
     // TODO(alanknight): Can these be moved to dart_scope.dart?
-    var properties = await visibleProperties(debugger: this, frame: frame);
-    var boundVariables = await Future.wait(
+    final properties = await visibleProperties(debugger: this, frame: frame);
+    final boundVariables = await Future.wait(
       properties.map((property) async => await _boundVariable(property)),
     );
 
@@ -345,7 +361,7 @@ class Debugger extends Domain {
   Future<BoundVariable> _boundVariable(Property property) async {
     // We return one level of properties from this object. Sub-properties are
     // another round trip.
-    var instanceRef =
+    final instanceRef =
         await inspector.instanceHelper.instanceRefFor(property.value);
     // Skip null instance refs, which we get for weird objects, e.g.
     // properties that are getter/setter pairs.
@@ -375,15 +391,15 @@ class Debugger extends Domain {
     assert(length != null);
     // TODO(#809): Sometimes we already know the type of the object, and
     // we could take advantage of that to short-circuit.
-    var receiver = remoteObjectFor(id);
-    var end = count == null ? null : math.min(offset + count, length);
-    var actualCount = count ?? length - offset;
-    var args =
+    final receiver = remoteObjectFor(id);
+    final end = count == null ? null : math.min(offset + count, length);
+    final actualCount = count ?? length - offset;
+    final args =
         [offset, actualCount, end].map(dartIdFor).map(remoteObjectFor).toList();
     // If this is a List, just call sublist. If it's a Map, get the entries, but
     // avoid doing a toList on a large map using skip/take to get the section we
     // want. To make those alternatives easier in JS, pass both count and end.
-    var expression = '''
+    final expression = '''
         function (offset, count, end) {
           const sdk = ${globalLoadStrategy.loadModuleSnippet}("dart_sdk");
           if (sdk.core.Map.is(this)) {
@@ -401,24 +417,28 @@ class Debugger extends Domain {
     return await inspector.jsCallFunctionOn(receiver, expression, args);
   }
 
+  // TODO(elliette): https://github.com/dart-lang/webdev/issues/1501 Re-enable
+  // after checking with Chrome team if there is a way to check if the Chrome
+  // DevTools is showing an overlay. Both cannot be shown at the same time:
+
   // Renders the paused at breakpoint overlay over the application.
-  void _showPausedOverlay() async {
-    if (_pausedOverlayVisible) return;
-    handleErrorIfPresent(await _remoteDebugger?.sendCommand('DOM.enable'));
-    handleErrorIfPresent(await _remoteDebugger?.sendCommand('Overlay.enable'));
-    handleErrorIfPresent(await _remoteDebugger
-        ?.sendCommand('Overlay.setPausedInDebuggerMessage', params: {
-      'message': 'Paused in Dart DevTools',
-    }));
-    _pausedOverlayVisible = true;
-  }
+  // void _showPausedOverlay() async {
+  //   if (_pausedOverlayVisible) return;
+  //   handleErrorIfPresent(await _remoteDebugger?.sendCommand('DOM.enable'));
+  //   handleErrorIfPresent(await _remoteDebugger?.sendCommand('Overlay.enable'));
+  //   handleErrorIfPresent(await _remoteDebugger
+  //       ?.sendCommand('Overlay.setPausedInDebuggerMessage', params: {
+  //     'message': 'Paused',
+  //   }));
+  //   _pausedOverlayVisible = true;
+  // }
 
   // Removes the paused at breakpoint overlay from the application.
-  void _hidePausedOverlay() async {
-    if (!_pausedOverlayVisible) return;
-    handleErrorIfPresent(await _remoteDebugger?.sendCommand('Overlay.disable'));
-    _pausedOverlayVisible = false;
-  }
+  // void _hidePausedOverlay() async {
+  //   if (!_pausedOverlayVisible) return;
+  //   handleErrorIfPresent(await _remoteDebugger?.sendCommand('Overlay.disable'));
+  //   _pausedOverlayVisible = false;
+  // }
 
   /// Calls the Chrome Runtime.getProperties API for the object with [objectId].
   ///
@@ -430,16 +450,16 @@ class Debugger extends Domain {
       {int offset, int count, int length}) async {
     var rangeId = objectId;
     if (length != null && (offset != null || count != null)) {
-      var range = await _subrange(objectId, offset ?? 0, count, length);
+      final range = await _subrange(objectId, offset ?? 0, count, length);
       rangeId = range.objectId;
     }
-    var response =
+    final response =
         await _remoteDebugger.sendCommand('Runtime.getProperties', params: {
       'objectId': rangeId,
       'ownProperties': true,
     });
-    var jsProperties = response.result['result'];
-    var properties = (jsProperties as List)
+    final jsProperties = response.result['result'];
+    final properties = (jsProperties as List)
         .map<Property>((each) => Property(each as Map<String, dynamic>))
         .toList();
     return properties;
@@ -451,50 +471,43 @@ class Debugger extends Domain {
     int frameIndex, {
     bool populateVariables = true,
   }) async {
-    var location = frame.location;
-    // Chrome is 0 based. Account for this.
-    var line = location.lineNumber + 1;
-    var column = location.columnNumber + 1;
+    final location = frame.location;
+    final line = location.lineNumber;
+    final column = location.columnNumber;
 
-    var url = _urlForScriptId(location.scriptId);
+    final url = urlForScriptId(location.scriptId);
     if (url == null) {
       logger.severe('Failed to create dart frame for ${frame.functionName}: '
-          'cannot find location for script ${location.scriptId}');
+          'cannot find url for script ${location.scriptId}');
+      return null;
     }
 
-    // TODO(sdk/issues/37240) - ideally we look for an exact location instead
-    // of the closest location on a given line.
-    Location bestLocation;
-    for (var location in await _locations.locationsForUrl(url)) {
-      if (location.jsLocation.line == line) {
-        bestLocation ??= location;
-        if ((location.jsLocation.column - column).abs() <
-            (bestLocation.jsLocation.column - column).abs()) {
-          bestLocation = location;
-        }
-      }
-    }
+    final bestLocation = await _locations.locationForJs(url, line, column);
     if (bestLocation == null) return null;
 
-    var script =
+    final script =
         await inspector?.scriptRefFor(bestLocation.dartLocation.uri.serverPath);
     // We think we found a location, but for some reason we can't find the
     // script. Just drop the frame.
     // TODO(#700): Understand when this can happen and have a better fix.
     if (script == null) return null;
 
-    var functionName =
+    final functionName =
         _prettifyMember((frame.functionName ?? '').split('.').last);
-    var codeRefName = functionName.isEmpty ? '<closure>' : functionName;
+    final codeRefName = functionName.isEmpty ? '<closure>' : functionName;
 
-    var dartFrame = Frame(
+    final dartFrame = Frame(
       index: frameIndex,
       code: CodeRef(
         name: codeRefName,
         kind: CodeKind.kDart,
         id: createId(),
       ),
-      location: SourceLocation(tokenPos: bestLocation.tokenPos, script: script),
+      location: SourceLocation(
+          line: bestLocation.dartLocation.line,
+          column: bestLocation.dartLocation.column,
+          tokenPos: bestLocation.tokenPos,
+          script: script),
       kind: FrameKind.kRegular,
     );
 
@@ -510,20 +523,20 @@ class Debugger extends Domain {
   Future<void> _pauseHandler(DebuggerPausedEvent e) async {
     if (inspector == null) return;
 
-    var isolate = inspector.isolate;
+    final isolate = inspector.isolate;
     if (isolate == null) return;
 
     Event event;
-    var timestamp = DateTime.now().millisecondsSinceEpoch;
-    var jsBreakpointIds = e.hitBreakpoints ?? [];
+    final timestamp = DateTime.now().millisecondsSinceEpoch;
+    final jsBreakpointIds = e.hitBreakpoints ?? [];
     if (jsBreakpointIds.isNotEmpty) {
-      var breakpointIds = jsBreakpointIds
+      final breakpointIds = jsBreakpointIds
           .map((id) => _breakpoints._dartIdByJsId[id])
           // In case the breakpoint was set in Chrome DevTools outside of
           // package:dwds.
           .where((entry) => entry != null)
           .toSet();
-      var pauseBreakpoints = isolate.breakpoints
+      final pauseBreakpoints = isolate.breakpoints
           .where((bp) => breakpointIds.contains(bp.id))
           .toList();
       event = Event(
@@ -535,10 +548,10 @@ class Debugger extends Domain {
       InstanceRef exception;
 
       if (e.data is Map<String, dynamic>) {
-        var map = e.data as Map<String, dynamic>;
+        final map = e.data as Map<String, dynamic>;
         if (map['type'] == 'object') {
           // The className here is generally 'DartError'.
-          var obj = RemoteObject(map);
+          final obj = RemoteObject(map);
           exception = await inspector.instanceHelper.instanceRefFor(obj);
 
           // TODO: The exception object generally doesn't get converted to a
@@ -546,8 +559,10 @@ class Debugger extends Domain {
           if (isNativeJsObject(exception)) {
             if (obj.description != null) {
               // Create a string exception object.
-              exception = await inspector.instanceHelper
-                  .instanceRefFor(obj.description);
+              final description =
+                  await inspector.mapExceptionStackTrace(obj.description);
+              exception =
+                  await inspector.instanceHelper.instanceRefFor(description);
             } else {
               exception = null;
             }
@@ -562,26 +577,32 @@ class Debugger extends Domain {
         exception: exception,
       );
     } else {
-      // If we don't have source location continue stepping.
-      if (_isStepping && (await _sourceLocation(e)) == null) {
-        var frame = e.params['callFrames'][0];
-        var scriptId = '${frame["location"]["scriptId"]}';
+      // Continue stepping until we hit a dart location,
+      // avoiding stepping through library loading code.
+      if (_isStepping) {
+        final scriptId = _frameScriptId(e);
+        final url = urlForScriptId(scriptId);
 
-        var url = _urlForScriptId(scriptId);
         if (url == null) {
           logger.severe('Stepping failed: '
-              'cannot find location for script $scriptId');
+              'cannot find url for script $scriptId');
+          throw StateError('Stepping failed in script $scriptId');
         }
 
-        // TODO(grouma) - In the future we should send all previously computed
-        // skipLists.
-        await _remoteDebugger.stepInto(params: {
-          'skipList': await _skipLists.compute(
-            scriptId,
-            await _locations.locationsForUrl(url),
-          )
-        });
-        return;
+        if (url.contains(globalLoadStrategy.loadLibrariesModule)) {
+          await _remoteDebugger.stepOut();
+          return;
+        } else if ((await _sourceLocation(e)) == null) {
+          // TODO(grouma) - In the future we should send all previously computed
+          // skipLists.
+          await _remoteDebugger.stepInto(params: {
+            'skipList': await _skipLists.compute(
+              scriptId,
+              await _locations.locationsForUrl(url),
+            )
+          });
+          return;
+        }
       }
       event = Event(
           kind: EventKind.kPauseInterrupted,
@@ -597,14 +618,17 @@ class Debugger extends Domain {
     );
 
     try {
-      var frames = await stackComputer.calculateFrames(limit: 1);
+      final frames = await stackComputer.calculateFrames(limit: 1);
       event.topFrame = frames.isNotEmpty ? frames.first : null;
     } catch (e, s) {
       // TODO: Return information about the error to the user.
       logger.warning('Error calculating Dart frames', e, s);
     }
 
-    _showPausedOverlay();
+    // TODO(elliette): https://github.com/dart-lang/webdev/issues/1501 Re-enable
+    // after checking with Chrome team if there is a way to check if the Chrome
+    // DevTools is showing an overlay. Both cannot be shown at the same time.
+    // _showPausedOverlay();
     isolate.pauseEvent = event;
     _streamNotify('Debug', event);
   }
@@ -613,16 +637,19 @@ class Debugger extends Domain {
   Future<void> _resumeHandler(DebuggerResumedEvent _) async {
     // We can receive a resume event in the middle of a reload which will result
     // in a null isolate.
-    var isolate = inspector?.isolate;
+    final isolate = inspector?.isolate;
     if (isolate == null) return;
 
     stackComputer = null;
-    var event = Event(
+    final event = Event(
         kind: EventKind.kResume,
         timestamp: DateTime.now().millisecondsSinceEpoch,
         isolate: inspector.isolateRef);
 
-    _hidePausedOverlay();
+    // TODO(elliette): https://github.com/dart-lang/webdev/issues/1501 Re-enable
+    // after checking with Chrome team if there is a way to check if the Chrome
+    // DevTools is showing an overlay. Both cannot be shown at the same time.
+    // _hidePausedOverlay();
     isolate.pauseEvent = event;
     _streamNotify('Debug', event);
   }
@@ -631,11 +658,11 @@ class Debugger extends Domain {
   Future<void> _crashHandler(TargetCrashedEvent _) async {
     // We can receive a resume event in the middle of a reload which will result
     // in a null isolate.
-    var isolate = inspector?.isolate;
+    final isolate = inspector?.isolate;
     if (isolate == null) return;
 
     stackComputer = null;
-    var event = Event(
+    final event = Event(
         kind: EventKind.kIsolateExit,
         timestamp: DateTime.now().millisecondsSinceEpoch,
         isolate: inspector.isolateRef);
@@ -700,7 +727,7 @@ class Debugger extends Domain {
 bool isNativeJsObject(InstanceRef instanceRef) {
   // New type representation of JS objects reifies them to a type suffixed with
   // JavaScriptObject.
-  var className = instanceRef?.classRef?.name;
+  final className = instanceRef?.classRef?.name;
   return (className != null &&
           className.endsWith('JavaScriptObject') &&
           instanceRef?.classRef?.library?.uri == 'dart:_interceptors') ||
@@ -710,14 +737,20 @@ bool isNativeJsObject(InstanceRef instanceRef) {
 
 /// Returns the Dart line number for the provided breakpoint.
 int _lineNumberFor(Breakpoint breakpoint) =>
-    int.parse(breakpoint.id.split('#').last);
+    int.parse(breakpoint.id.split('#').last.split(':').first);
+
+/// Returns the Dart column number for the provided breakpoint.
+int _columnNumberFor(Breakpoint breakpoint) =>
+    int.parse(breakpoint.id.split('#').last.split(':').last);
 
 /// Returns the breakpoint ID for the provided Dart script ID and Dart line
 /// number.
-String breakpointIdFor(String scriptId, int line) => 'bp/$scriptId#$line';
+String breakpointIdFor(String scriptId, int line, int column) =>
+    'bp/$scriptId#$line:$column';
 
 /// Keeps track of the Dart and JS breakpoint Ids that correspond.
 class _Breakpoints extends Domain {
+  final _logger = Logger('Breakpoints');
   final _dartIdByJsId = <String, String>{};
   final _jsIdByDartId = <String, String>{};
 
@@ -739,13 +772,15 @@ class _Breakpoints extends Domain {
   }) : super(provider);
 
   Future<Breakpoint> _createBreakpoint(
-      String id, String scriptId, int line) async {
-    var dartScript = inspector.scriptWithId(scriptId);
-    var dartUri = DartUri(dartScript.uri, root);
-    var location = await locations.locationForDart(dartUri, line);
-
+      String id, String scriptId, int line, int column) async {
+    final dartScript = inspector.scriptWithId(scriptId);
+    final dartUri = DartUri(dartScript.uri, root);
+    final location = await locations.locationForDart(dartUri, line, column);
     // TODO: Handle cases where a breakpoint can't be set exactly at that line.
     if (location == null) {
+      _logger.fine('Failed to set breakpoint $id '
+          '(${dartUri.serverPath}:$line:$column): '
+          'cannot find Dart location.');
       throw RPCError(
           'addBreakpoint',
           102,
@@ -754,8 +789,8 @@ class _Breakpoints extends Domain {
     }
 
     try {
-      var dartBreakpoint = _dartBreakpoint(dartScript, location, id);
-      var jsBreakpointId = await _setJsBreakpoint(location);
+      final dartBreakpoint = _dartBreakpoint(dartScript, location, id);
+      final jsBreakpointId = await _setJsBreakpoint(location);
 
       _note(jsId: jsBreakpointId, bp: dartBreakpoint);
       return dartBreakpoint;
@@ -766,20 +801,25 @@ class _Breakpoints extends Domain {
 
   /// Adds a breakpoint at [scriptId] and [line] or returns an existing one if
   /// present.
-  Future<Breakpoint> add(String scriptId, int line) async {
-    final id = breakpointIdFor(scriptId, line);
+  Future<Breakpoint> add(String scriptId, int line, int column) async {
+    final id = breakpointIdFor(scriptId, line, column);
     return _bpByDartId.putIfAbsent(
-        id, () => _createBreakpoint(id, scriptId, line));
+        id, () => _createBreakpoint(id, scriptId, line, column));
   }
 
   /// Create a Dart breakpoint at [location] in [dartScript] with [id].
   Breakpoint _dartBreakpoint(
       ScriptRef dartScript, Location location, String id) {
-    var breakpoint = Breakpoint(
+    final breakpoint = Breakpoint(
       id: id,
       breakpointNumber: int.parse(createId()),
       resolved: true,
-      location: SourceLocation(script: dartScript, tokenPos: location.tokenPos),
+      location: SourceLocation(
+        script: dartScript,
+        tokenPos: location.tokenPos,
+        line: location.dartLocation.line,
+        column: location.dartLocation.column,
+      ),
       enabled: true,
     )..id = id;
     return breakpoint;
@@ -787,18 +827,16 @@ class _Breakpoints extends Domain {
 
   /// Calls the Chrome protocol setBreakpoint and returns the remote ID.
   Future<String> _setJsBreakpoint(Location location) async {
-    // Location is 0 based according to:
-    // https://chromedevtools.github.io/devtools-protocol/tot/Debugger#type-Location
-
     // The module can be loaded from a nested path and contain an ETAG suffix.
-    var urlRegex = '.*${location.jsLocation.module}.*';
+    final urlRegex = '.*${location.jsLocation.module}.*';
     // Prevent `Aww, snap!` errors when setting multiple breakpoints
     // simultaneously by serializing the requests.
     return _pool.withResource(() async {
-      var response = await remoteDebugger
+      final response = await remoteDebugger
           .sendCommand('Debugger.setBreakpointByUrl', params: {
         'urlRegex': urlRegex,
-        'lineNumber': location.jsLocation.line - 1,
+        'lineNumber': location.jsLocation.line,
+        'columnNumber': location.jsLocation.column,
       });
       return response.result['breakpointId'] as String;
     });
@@ -809,7 +847,7 @@ class _Breakpoints extends Domain {
   void _note({@required Breakpoint bp, @required String jsId}) {
     _dartIdByJsId[jsId] = bp.id;
     _jsIdByDartId[bp.id] = jsId;
-    var isolate = inspector.isolate;
+    final isolate = inspector.isolate;
     isolate?.breakpoints?.add(bp);
   }
 
@@ -817,7 +855,7 @@ class _Breakpoints extends Domain {
     @required String jsId,
     @required String dartId,
   }) async {
-    var isolate = inspector.isolate;
+    final isolate = inspector.isolate;
     _dartIdByJsId.remove(jsId);
     _jsIdByDartId.remove(dartId);
     isolate?.breakpoints?.removeWhere((b) => b.id == dartId);
@@ -850,9 +888,9 @@ String _prettifyMember(String member) {
 /// Reformats a JS member name as an extension method invocation.
 String _prettifyExtension(String member) {
   var isSetter = false;
-  var pipeIndex = member.indexOf('|');
-  var spaceIndex = member.indexOf(' ');
-  var poundIndex = member.indexOf(escapedPound);
+  final pipeIndex = member.indexOf('|');
+  final spaceIndex = member.indexOf(' ');
+  final poundIndex = member.indexOf(escapedPound);
   if (spaceIndex >= 0) {
     // Here member is a static field or static getter/setter.
     isSetter = member.substring(0, spaceIndex) == 'set';
@@ -862,7 +900,7 @@ String _prettifyExtension(String member) {
     isSetter = member.substring(pipeIndex + 1, poundIndex) == 'set';
     member = member.replaceRange(pipeIndex + 1, poundIndex + 3, '');
   } else {
-    var body = member.substring(pipeIndex + 1, member.length);
+    final body = member.substring(pipeIndex + 1, member.length);
     if (body.startsWith('unary') || body.startsWith('\$')) {
       // Here member's an operator, so it's safe to unescape everything lazily.
       member = _unescape(member);
