@@ -1,3 +1,7 @@
+// Copyright (c) 2020, the Dart project authors.  Please see the AUTHORS file
+// for details. All rights reserved. Use of this source code is governed by a
+// BSD-style license that can be found in the LICENSE file.
+
 // Dart implementation of the Win32 sample of configuring a comms resource.
 
 // C++ implementation can be found here:
@@ -11,7 +15,7 @@ import 'dart:io';
 import 'package:ffi/ffi.dart';
 import 'package:win32/win32.dart';
 
-void PrintCommState(DCB dcb) => print('BaudRate = ${dcb.BaudRate}, '
+void printCommState(DCB dcb) => print('BaudRate = ${dcb.BaudRate}, '
     'ByteSize = ${dcb.ByteSize}, '
     'Parity = ${dcb.Parity}, '
     'StopBits = ${dcb.StopBits}');
@@ -36,7 +40,7 @@ void main() {
       print('GetCommState failed.');
       exit(2);
     }
-    PrintCommState(dcb.ref);
+    printCommState(dcb.ref);
 
     dcb
       ..ref.BaudRate = CBR_57600
@@ -50,7 +54,7 @@ void main() {
       exit(3);
     }
 
-    PrintCommState(dcb.ref);
+    printCommState(dcb.ref);
   } finally {
     free(pcCommPort);
     free(dcb);
