@@ -1,8 +1,11 @@
+import 'package:meta/meta.dart';
 import 'package:test/test.dart';
 import 'package:xml/xml.dart';
 
-import 'assertions.dart';
+import 'utils/assertions.dart';
+import 'utils/matchers.dart';
 
+@isTest
 void mutatingTest(String description, String before,
     void Function(XmlElement node) action, String after) {
   test(description, () {
@@ -14,6 +17,7 @@ void mutatingTest(String description, String before,
   });
 }
 
+@isTest
 void throwingTest(String description, String before,
     void Function(XmlElement node) action, Matcher matcher) {
   test(description, () {
@@ -129,20 +133,19 @@ void main() {
       },
       '<element1><element2/><element2/></element1>',
     );
+    final wrong = XmlAttribute(XmlName('invalid'), 'invalid');
     throwingTest(
       'element (attribute children)',
       '<element/>',
-      (node) {
-        final wrong = XmlAttribute(XmlName('invalid'), 'invalid');
-        node.children.add(wrong);
-      },
-      throwsA(isXmlNodeTypeException),
+      (node) => node.children.add(wrong),
+      throwsA(isXmlNodeTypeException(
+          node: wrong, types: contains(XmlNodeType.ELEMENT))),
     );
     throwingTest(
       'element (parent error)',
       '<element1><element2/></element1>',
       (node) => node.children.add(node.firstChild!),
-      throwsA(isXmlParentException),
+      throwsA(isXmlParentException()),
     );
   });
   group('addAll', () {
@@ -194,20 +197,19 @@ void main() {
       },
       '<element1><element2/><element2/></element1>',
     );
+    final wrong = XmlAttribute(XmlName('invalid'), 'invalid');
     throwingTest(
       'element (attribute children)',
       '<element/>',
-      (node) {
-        final wrong = XmlAttribute(XmlName('invalid'), 'invalid');
-        node.children.addAll([wrong]);
-      },
-      throwsA(isXmlNodeTypeException),
+      (node) => node.children.addAll([wrong]),
+      throwsA(isXmlNodeTypeException(
+          node: wrong, types: contains(XmlNodeType.ELEMENT))),
     );
     throwingTest(
       'element (parent error)',
       '<element1><element2/></element1>',
       (node) => node.children.addAll([node.firstChild!]),
-      throwsA(isXmlParentException),
+      throwsA(isXmlParentException()),
     );
   });
   group('innerText', () {
@@ -372,20 +374,19 @@ void main() {
       (node) => node.children.insert(2, XmlText(' World')),
       throwsRangeError,
     );
+    final wrong = XmlAttribute(XmlName('invalid'), 'invalid');
     throwingTest(
       'element (attribute children)',
       '<element/>',
-      (node) {
-        final wrong = XmlAttribute(XmlName('invalid'), 'invalid');
-        node.children.insert(0, wrong);
-      },
-      throwsA(isXmlNodeTypeException),
+      (node) => node.children.insert(0, wrong),
+      throwsA(isXmlNodeTypeException(
+          node: wrong, types: contains(XmlNodeType.ELEMENT))),
     );
     throwingTest(
       'element (parent error)',
       '<element1><element2/></element1>',
       (node) => node.children.insert(0, node.firstChild!),
-      throwsA(isXmlParentException),
+      throwsA(isXmlParentException()),
     );
   });
   group('insertAll', () {
@@ -450,20 +451,19 @@ void main() {
       (node) => node.children.insertAll(2, [XmlText(' World')]),
       throwsRangeError,
     );
+    final wrong = XmlAttribute(XmlName('invalid'), 'invalid');
     throwingTest(
       'element (attribute children)',
       '<element/>',
-      (node) {
-        final wrong = XmlAttribute(XmlName('invalid'), 'invalid');
-        node.children.insertAll(0, [wrong]);
-      },
-      throwsA(isXmlNodeTypeException),
+      (node) => node.children.insertAll(0, [wrong]),
+      throwsA(isXmlNodeTypeException(
+          node: wrong, types: contains(XmlNodeType.ELEMENT))),
     );
     throwingTest(
       'element (parent error)',
       '<element1><element2/></element1>',
       (node) => node.children.insertAll(0, [node.firstChild!]),
-      throwsA(isXmlParentException),
+      throwsA(isXmlParentException()),
     );
   });
   group('[]=', () {
@@ -491,20 +491,19 @@ void main() {
       (node) => node.children[2] = XmlText(' World'),
       throwsRangeError,
     );
+    final wrong = XmlAttribute(XmlName('invalid'), 'invalid');
     throwingTest(
       'element (attribute children)',
       '<element1><element2/></element1>',
-      (node) {
-        final wrong = XmlAttribute(XmlName('invalid'), 'invalid');
-        node.children[0] = wrong;
-      },
-      throwsA(isXmlNodeTypeException),
+      (node) => node.children[0] = wrong,
+      throwsA(isXmlNodeTypeException(
+          node: wrong, types: contains(XmlNodeType.ELEMENT))),
     );
     throwingTest(
       'element (parent error)',
       '<element1><element2/></element1>',
       (node) => node.children[0] = node.firstChild!,
-      throwsA(isXmlParentException),
+      throwsA(isXmlParentException()),
     );
   });
   group('remove', () {
