@@ -6,7 +6,6 @@ part of dart._engine;
 
 
 
-
 /// When `true` prints statistics about what happened to the surface tree when
 /// it was composited.
 ///
@@ -305,7 +304,7 @@ abstract class PersistedSurface implements ui.EngineLayer {
   ///
   /// This element can be reused across frames. See also, [childContainer],
   /// which is the element used to manage child nodes.
-  html.Element? rootElement;
+  DomElement? rootElement;
 
   /// Whether this surface can update an existing [oldSurface].
   
@@ -318,7 +317,7 @@ abstract class PersistedSurface implements ui.EngineLayer {
   /// By default this is the same as the [rootElement]. However, specialized
   /// surface implementations may choose to override this and provide a
   /// different element for nesting children.
-  html.Element? get childContainer => rootElement;
+  DomElement? get childContainer => rootElement;
 
   /// This surface's immediate parent.
   PersistedContainerSurface? parent;
@@ -350,7 +349,7 @@ abstract class PersistedSurface implements ui.EngineLayer {
   
   void build() {
     if (assertionsEnabled) {
-      final html.Element? existingElement = rootElement;
+      final DomElement? existingElement = rootElement;
       if (existingElement != null) {
         throw PersistedSurfaceException(
           this,
@@ -490,12 +489,12 @@ abstract class PersistedSurface implements ui.EngineLayer {
   }
 
   /// Creates a DOM element for this surface.
-  html.Element createElement();
+  DomElement createElement();
 
   /// Creates a DOM element for this surface preconfigured with common
   /// attributes, such as absolute positioning and debug information.
-  html.Element defaultCreateElement(String tagName) {
-    final html.Element element = html.Element.tag(tagName);
+  DomElement defaultCreateElement(String tagName) {
+    final DomElement element = createDomElement(tagName);
     element.style.position = 'absolute';
     if (assertionsEnabled) {
       element.setAttribute('flt-layer-state', 'new');
@@ -659,7 +658,7 @@ abstract class PersistedContainerSurface extends PersistedSurface {
     // Memoize length for efficiency.
     final int len = _children.length;
     // Memoize container element for efficiency. [childContainer] is polymorphic
-    final html.Element? containerElement = childContainer;
+    final DomElement? containerElement = childContainer;
     for (int i = 0; i < len; i++) {
       final PersistedSurface child = _children[i];
       if (child.isPendingRetention) {
@@ -764,7 +763,7 @@ abstract class PersistedContainerSurface extends PersistedSurface {
     assert(oldSurface._children.isEmpty);
 
     // Memoizing variables for efficiency.
-    final html.Element? containerElement = childContainer;
+    final DomElement? containerElement = childContainer;
     final int length = _children.length;
 
     for (int i = 0; i < length; i++) {
@@ -905,7 +904,7 @@ abstract class PersistedContainerSurface extends PersistedSurface {
     assert(_children.isNotEmpty && oldSurface._children.isNotEmpty);
 
     // Memoize container element for efficiency. [childContainer] is polymorphic
-    final html.Element? containerElement = childContainer;
+    final DomElement? containerElement = childContainer;
     final Map<PersistedSurface?, PersistedSurface> matches =
         _matchChildren(oldSurface);
 
@@ -1032,15 +1031,15 @@ abstract class PersistedContainerSurface extends PersistedSurface {
       stationaryIndices[i] = indexMapNew![stationaryIndices[i]!];
     }
 
-    html.HtmlElement? refNode;
-    final html.Element? containerElement = childContainer;
+    DomHTMLElement? refNode;
+    final DomElement? containerElement = childContainer;
     for (int i = _children.length - 1; i >= 0; i -= 1) {
       final int indexInNew = indexMapNew!.indexOf(i);
       final bool isStationary =
           indexInNew != -1 && stationaryIndices.contains(i);
       final PersistedSurface child = _children[i];
-      final html.HtmlElement childElement =
-          child.rootElement! as html.HtmlElement;
+      final DomHTMLElement childElement =
+          child.rootElement! as DomHTMLElement;
       assert(childElement != null); // ignore: unnecessary_null_comparison
       if (!isStationary) {
         if (refNode == null) {
