@@ -5,12 +5,10 @@
 import 'template.dart';
 
 class SurfaceTintTemplate extends TokenTemplate {
-  const SurfaceTintTemplate(super.fileName, super.tokens);
+  const SurfaceTintTemplate(super.blockName, super.fileName, super.tokens);
 
   @override
   String generate() => '''
-// Generated version ${tokens["version"]}
-
 // Surface tint opacities based on elevations according to the
 // Material Design 3 specification:
 //   https://m3.material.io/styles/color/the-color-system/color-roles
