@@ -9,7 +9,7 @@ import 'package:flutter/material.dart';
 void main() => runApp(const MyApp());
 
 class MyApp extends StatelessWidget {
-  const MyApp({Key? key}) : super(key: key);
+  const MyApp({super.key});
 
   @override
   Widget build(BuildContext context) {
@@ -21,7 +21,7 @@ class MyApp extends StatelessWidget {
 }
 
 class InputDecoratorExample extends StatelessWidget {
-  const InputDecoratorExample({Key? key}) : super(key: key);
+  const InputDecoratorExample({super.key});
 
   @override
   Widget build(BuildContext context) {
