@@ -9,7 +9,7 @@ import 'package:flutter/material.dart';
 void main() => runApp(const MyApp());
 
 class MyApp extends StatelessWidget {
-  const MyApp({Key? key}) : super(key: key);
+  const MyApp({super.key});
 
   @override
   Widget build(BuildContext context) {
@@ -18,7 +18,7 @@ class MyApp extends StatelessWidget {
 }
 
 class MoodyGradient extends StatelessWidget {
-  const MoodyGradient({Key? key}) : super(key: key);
+  const MoodyGradient({super.key});
 
   @override
   Widget build(BuildContext context) {
