@@ -3,14 +3,13 @@
 // found in the LICENSE file.
 
 // Flutter code sample for FontFeature.FontFeature.localeAware
-import 'dart:ui';
 
 import 'package:flutter/widgets.dart';
 
 void main() => runApp(const ExampleApp());
 
 class ExampleApp extends StatelessWidget {
-  const ExampleApp({Key? key}) : super(key: key);
+  const ExampleApp({super.key});
 
   @override
   Widget build(BuildContext context) {
@@ -22,7 +21,7 @@ class ExampleApp extends StatelessWidget {
 }
 
 class ExampleWidget extends StatelessWidget {
-  const ExampleWidget({Key? key}) : super(key: key);
+  const ExampleWidget({super.key});
 
   @override
   Widget build(BuildContext context) {
