@@ -10,7 +10,7 @@ const Offset _kRowOffset = Offset(0.0, -50.0);
 void main() {
   testWidgets('Can pick a duration from CupertinoTimerPicker', (WidgetTester tester) async {
     await tester.pumpWidget(
-      const example.MyApp(),
+      const example.TimerPickerApp(),
     );
 
     // Launch the timer picker.
