@@ -62,7 +62,7 @@ class AnimatedList extends StatefulWidget {
   /// Creates a scrolling container that animates items when they are inserted
   /// or removed.
   const AnimatedList({
-    Key? key,
+    super.key,
     required this.itemBuilder,
     this.initialItemCount = 0,
     this.scrollDirection = Axis.vertical,
@@ -74,8 +74,7 @@ class AnimatedList extends StatefulWidget {
     this.padding,
     this.clipBehavior = Clip.hardEdge,
   }) : assert(itemBuilder != null),
-       assert(initialItemCount != null && initialItemCount >= 0),
-       super(key: key);
+       assert(initialItemCount != null && initialItemCount >= 0);
 
   /// Called, as needed, to build list item widgets.
   ///
@@ -337,13 +336,12 @@ class AnimatedListState extends State<AnimatedList> with TickerProviderStateMixi
 class SliverAnimatedList extends StatefulWidget {
   /// Creates a sliver that animates items when they are inserted or removed.
   const SliverAnimatedList({
-    Key? key,
+    super.key,
     required this.itemBuilder,
     this.findChildIndexCallback,
     this.initialItemCount = 0,
   }) : assert(itemBuilder != null),
-       assert(initialItemCount != null && initialItemCount >= 0),
-       super(key: key);
+       assert(initialItemCount != null && initialItemCount >= 0);
 
   /// Called, as needed, to build list item widgets.
   ///
@@ -490,10 +488,11 @@ class SliverAnimatedListState extends State<SliverAnimatedList> with TickerProvi
   int _indexToItemIndex(int index) {
     int itemIndex = index;
     for (final _ActiveItem item in _outgoingItems) {
-      if (item.itemIndex <= itemIndex)
+      if (item.itemIndex <= itemIndex) {
         itemIndex += 1;
-      else
+      } else {
         break;
+      }
     }
     return itemIndex;
   }
@@ -502,10 +501,11 @@ class SliverAnimatedListState extends State<SliverAnimatedList> with TickerProvi
     int index = itemIndex;
     for (final _ActiveItem item in _outgoingItems) {
       assert(item.itemIndex != itemIndex);
-      if (item.itemIndex < itemIndex)
+      if (item.itemIndex < itemIndex) {
         index -= 1;
-      else
+      } else {
         break;
+      }
     }
     return index;
   }
@@ -534,12 +534,14 @@ class SliverAnimatedListState extends State<SliverAnimatedList> with TickerProvi
     // Increment the incoming and outgoing item indices to account
     // for the insertion.
     for (final _ActiveItem item in _incomingItems) {
-      if (item.itemIndex >= itemIndex)
+      if (item.itemIndex >= itemIndex) {
         item.itemIndex += 1;
+      }
     }
     for (final _ActiveItem item in _outgoingItems) {
-      if (item.itemIndex >= itemIndex)
+      if (item.itemIndex >= itemIndex) {
         item.itemIndex += 1;
+      }
     }
 
     final AnimationController controller = AnimationController(
@@ -598,12 +600,14 @@ class SliverAnimatedListState extends State<SliverAnimatedList> with TickerProvi
       // Decrement the incoming and outgoing item indices to account
       // for the removal.
       for (final _ActiveItem item in _incomingItems) {
-        if (item.itemIndex > outgoingItem.itemIndex)
+        if (item.itemIndex > outgoingItem.itemIndex) {
           item.itemIndex -= 1;
+        }
       }
       for (final _ActiveItem item in _outgoingItems) {
-        if (item.itemIndex > outgoingItem.itemIndex)
+        if (item.itemIndex > outgoingItem.itemIndex) {
           item.itemIndex -= 1;
+        }
       }
 
       setState(() => _itemsCount -= 1);
