@@ -649,7 +649,7 @@ void main() {
 
         // Prev/Next month buttons.
         expect(tester.getSemantics(previousMonthIcon), matchesSemantics(
-          label: 'Previous month',
+          tooltip: 'Previous month',
           isButton: true,
           hasTapAction: true,
           isEnabled: true,
@@ -657,7 +657,7 @@ void main() {
           isFocusable: true,
         ));
         expect(tester.getSemantics(nextMonthIcon), matchesSemantics(
-          label: 'Next month',
+          tooltip: 'Next month',
           isButton: true,
           hasTapAction: true,
           isEnabled: true,
