@@ -796,7 +796,7 @@ void main() {
 
       // Given a custom paint for an input decoration, extract the border and
       // fill color and test them against the expected values.
-      void _testInputDecorator(CustomPaint decoratorPaint, InputBorder expectedBorder, Color expectedContainerColor) {
+      void testInputDecorator(CustomPaint decoratorPaint, InputBorder expectedBorder, Color expectedContainerColor) {
         final dynamic/*_InputBorderPainter*/ inputBorderPainter = decoratorPaint.foregroundPainter;
         // ignore: avoid_dynamic_calls
         final dynamic/*_InputBorderTween*/ inputBorderTween = inputBorderPainter.border;
@@ -851,10 +851,10 @@ void main() {
       );
 
       // Test the start date text field
-      _testInputDecorator(tester.widget(borderContainers.first), border, Colors.transparent);
+      testInputDecorator(tester.widget(borderContainers.first), border, Colors.transparent);
 
       // Test the end date text field
-      _testInputDecorator(tester.widget(borderContainers.last), border, Colors.transparent);
+      testInputDecorator(tester.widget(borderContainers.last), border, Colors.transparent);
     });
   });
 
@@ -1080,9 +1080,8 @@ void main() {
 
 class _RestorableDateRangePickerDialogTestWidget extends StatefulWidget {
   const _RestorableDateRangePickerDialogTestWidget({
-    Key? key,
     this.datePickerEntryMode = DatePickerEntryMode.calendar,
-  }) : super(key: key);
+  });
 
   final DatePickerEntryMode datePickerEntryMode;
 
