@@ -525,7 +525,6 @@ void main() {
 
     // Start hovering
     final TestGesture gesture = await tester.createGesture(kind: PointerDeviceKind.mouse);
-    addTearDown(gesture.removePointer);
     await gesture.moveTo(tester.getCenter(find.byKey(radioKey)));
 
     // Check when the radio isn't selected.
@@ -704,7 +703,6 @@ void main() {
 
     final TestGesture gesture = await tester.createGesture(kind: PointerDeviceKind.mouse, pointer: 1);
     await gesture.addPointer(location: tester.getCenter(find.byKey(key)));
-    addTearDown(gesture.removePointer);
 
     await tester.pump();
 
@@ -935,7 +933,6 @@ void main() {
     // Start hovering
     final TestGesture gesture = await tester.createGesture(kind: PointerDeviceKind.mouse);
     await gesture.addPointer();
-    addTearDown(gesture.removePointer);
     await gesture.moveTo(tester.getCenter(find.byKey(radioKey)));
     await tester.pumpAndSettle();
 
@@ -980,12 +977,12 @@ void main() {
     }
     const double splashRadius = 24.0;
 
-    Finder _findRadio() {
+    Finder findRadio() {
       return find.byWidgetPredicate((Widget widget) => widget is Radio<bool>);
     }
 
-    MaterialInkController? _getRadioMaterial(WidgetTester tester) {
-      return Material.of(tester.element(_findRadio()));
+    MaterialInkController? getRadioMaterial(WidgetTester tester) {
+      return Material.of(tester.element(findRadio()));
     }
 
     Widget buildRadio({bool active = false, bool focused = false, bool useOverlay = true}) {
@@ -997,7 +994,7 @@ void main() {
             value: active,
             groupValue: true,
             onChanged: (_) { },
-            fillColor: MaterialStateProperty.all(fillColor),
+            fillColor: const MaterialStatePropertyAll<Color>(fillColor),
             overlayColor: useOverlay ? MaterialStateProperty.resolveWith(getOverlayColor) : null,
             hoverColor: hoverColor,
             focusColor: focusColor,
@@ -1008,11 +1005,11 @@ void main() {
     }
 
     await tester.pumpWidget(buildRadio(useOverlay: false));
-    await tester.press(_findRadio());
+    await tester.press(findRadio());
     await tester.pumpAndSettle();
 
     expect(
-      _getRadioMaterial(tester),
+      getRadioMaterial(tester),
       paints
         ..circle(
           color: fillColor.withAlpha(kRadialReactionAlpha),
@@ -1022,11 +1019,11 @@ void main() {
     );
 
     await tester.pumpWidget(buildRadio(active: true, useOverlay: false));
-    await tester.press(_findRadio());
+    await tester.press(findRadio());
     await tester.pumpAndSettle();
 
     expect(
-      _getRadioMaterial(tester),
+      getRadioMaterial(tester),
       paints
         ..circle(
           color: fillColor.withAlpha(kRadialReactionAlpha),
@@ -1036,11 +1033,11 @@ void main() {
     );
 
     await tester.pumpWidget(buildRadio());
-    await tester.press(_findRadio());
+    await tester.press(findRadio());
     await tester.pumpAndSettle();
 
     expect(
-      _getRadioMaterial(tester),
+      getRadioMaterial(tester),
       paints
         ..circle(
           color: inactivePressedOverlayColor,
@@ -1050,11 +1047,11 @@ void main() {
     );
 
     await tester.pumpWidget(buildRadio(active: true));
-    await tester.press(_findRadio());
+    await tester.press(findRadio());
     await tester.pumpAndSettle();
 
     expect(
-      _getRadioMaterial(tester),
+      getRadioMaterial(tester),
       paints
         ..circle(
           color: activePressedOverlayColor,
@@ -1068,7 +1065,7 @@ void main() {
 
     expect(focusNode.hasPrimaryFocus, isTrue);
     expect(
-      _getRadioMaterial(tester),
+      getRadioMaterial(tester),
       paints
         ..circle(
           color: focusOverlayColor,
@@ -1080,12 +1077,11 @@ void main() {
     // Start hovering
     final TestGesture gesture = await tester.createGesture(kind: PointerDeviceKind.mouse);
     await gesture.addPointer();
-    addTearDown(gesture.removePointer);
-    await gesture.moveTo(tester.getCenter(_findRadio()));
+    await gesture.moveTo(tester.getCenter(findRadio()));
     await tester.pumpAndSettle();
 
     expect(
-      _getRadioMaterial(tester),
+      getRadioMaterial(tester),
       paints
         ..circle(
           color: hoverOverlayColor,
