@@ -962,7 +962,6 @@ void main() {
 
     final TestGesture gesture = await tester.createGesture(kind: ui.PointerDeviceKind.mouse);
     await gesture.addPointer();
-    addTearDown(gesture.removePointer);
     await gesture.moveTo(const Offset(794.0, 5.0));
     await tester.pumpAndSettle();
 
@@ -1027,7 +1026,6 @@ void main() {
     // Now trigger hover with a mouse.
     final TestGesture gesture = await tester.createGesture(kind: ui.PointerDeviceKind.mouse);
     await gesture.addPointer();
-    addTearDown(gesture.removePointer);
     await gesture.moveTo(const Offset(794.0, 5.0));
     await tester.pump();
 
@@ -1067,8 +1065,9 @@ void main() {
             return states.contains(MaterialState.hovered);
           }),
           thickness: MaterialStateProperty.resolveWith((Set<MaterialState> states) {
-            if (states.contains(MaterialState.hovered))
+            if (states.contains(MaterialState.hovered)) {
               return 40.0;
+            }
             // Default thickness
             return 8.0;
           }),
@@ -1092,7 +1091,6 @@ void main() {
 
     final TestGesture gesture = await tester.createGesture(kind: ui.PointerDeviceKind.mouse);
     await gesture.addPointer();
-    addTearDown(gesture.removePointer);
     await gesture.moveTo(const Offset(794.0, 5.0));
     await tester.pump();
 
@@ -1133,8 +1131,9 @@ void main() {
         theme: ThemeData(scrollbarTheme: ScrollbarThemeData(
           isAlwaysShown: true,
           trackVisibility: MaterialStateProperty.resolveWith((Set<MaterialState> states) {
-            if (states.contains(MaterialState.hovered))
+            if (states.contains(MaterialState.hovered)) {
               return true;
+            }
             return false;
           }),
         )),
@@ -1157,7 +1156,6 @@ void main() {
 
     final TestGesture gesture = await tester.createGesture(kind: ui.PointerDeviceKind.mouse);
     await gesture.addPointer();
-    addTearDown(gesture.removePointer);
     await gesture.moveTo(const Offset(794.0, 5.0));
     await tester.pump();
 
@@ -1218,7 +1216,6 @@ void main() {
 
     final TestGesture gesture = await tester.createGesture(kind: ui.PointerDeviceKind.mouse);
     await gesture.addPointer();
-    addTearDown(gesture.removePointer);
     await gesture.moveTo(const Offset(794.0, 5.0));
     await tester.pump();
 
@@ -1713,7 +1710,7 @@ void main() {
   });
 
   testWidgets('Scrollbar.isAlwaysShown triggers assertion when multiple ScrollPositions are attached.', (WidgetTester tester) async {
-    Widget _getTabContent({ ScrollController? scrollController }) {
+    Widget getTabContent({ ScrollController? scrollController }) {
       return Scrollbar(
         isAlwaysShown: true,
         controller: scrollController,
@@ -1725,7 +1722,7 @@ void main() {
       );
     }
 
-    Widget _buildApp({
+    Widget buildApp({
       required String id,
       ScrollController? scrollController,
     }) {
@@ -1736,8 +1733,8 @@ void main() {
           child: Scaffold(
             body: TabBarView(
               children: <Widget>[
-                _getTabContent(scrollController: scrollController),
-                _getTabContent(scrollController: scrollController),
+                getTabContent(scrollController: scrollController),
+                getTabContent(scrollController: scrollController),
               ],
             ),
           ),
@@ -1746,7 +1743,7 @@ void main() {
     }
 
     // Asserts when using the PrimaryScrollController.
-    await tester.pumpWidget(_buildApp(id: 'PrimaryScrollController'));
+    await tester.pumpWidget(buildApp(id: 'PrimaryScrollController'));
 
     // Swipe to the second tab, resulting in two attached ScrollPositions during
     // the transition.
@@ -1762,7 +1759,7 @@ void main() {
     // Asserts when using the ScrollController provided by the user.
     final ScrollController scrollController = ScrollController();
     await tester.pumpWidget(
-      _buildApp(
+      buildApp(
         id: 'Provided ScrollController',
         scrollController: scrollController,
       ),
@@ -1782,7 +1779,7 @@ void main() {
   testWidgets('Scrollbar scrollOrientation works correctly', (WidgetTester tester) async {
     final ScrollController scrollController = ScrollController();
 
-    Widget _buildScrollWithOrientation(ScrollbarOrientation orientation) {
+    Widget buildScrollWithOrientation(ScrollbarOrientation orientation) {
       return _buildBoilerplate(
         child: Theme(
           data: ThemeData(
@@ -1804,7 +1801,7 @@ void main() {
       );
     }
 
-    await tester.pumpWidget(_buildScrollWithOrientation(ScrollbarOrientation.left));
+    await tester.pumpWidget(buildScrollWithOrientation(ScrollbarOrientation.left));
     await tester.pumpAndSettle();
 
     expect(
