@@ -6,7 +6,6 @@ import 'dart:ui' as ui;
 import 'package:flutter/cupertino.dart';
 import 'package:flutter/material.dart';
 import 'package:flutter/rendering.dart';
-import 'package:flutter/src/foundation/diagnostics.dart';
 import 'package:flutter_test/flutter_test.dart';
 
 void main() {
@@ -47,6 +46,55 @@ void main() {
     expect(Theme.of(tester.element(find.text('menuItem'))).brightness, equals(Brightness.dark));
   });
 
+  testWidgets('Theme overrides selection style', (WidgetTester tester) async {
+    final Key key = UniqueKey();
+    const Color defaultSelectionColor = Color(0x11111111);
+    const Color defaultCursorColor = Color(0x22222222);
+    const Color themeSelectionColor = Color(0x33333333);
+    const Color themeCursorColor = Color(0x44444444);
+    await tester.pumpWidget(
+      MaterialApp(
+        theme: ThemeData(brightness: Brightness.dark),
+        home: Scaffold(
+          body: DefaultSelectionStyle(
+            selectionColor: defaultSelectionColor,
+            cursorColor: defaultCursorColor,
+            child: Theme(
+              data: ThemeData(
+                textSelectionTheme: const TextSelectionThemeData(
+                  selectionColor: themeSelectionColor,
+                  cursorColor: themeCursorColor,
+                ),
+              ),
+              child: TextField(
+                key: key,
+              ),
+            )
+          ),
+        ),
+      ),
+    );
+    // Finds RenderEditable.
+    final RenderObject root = tester.renderObject(find.byType(EditableText));
+    late RenderEditable renderEditable;
+    void recursiveFinder(RenderObject child) {
+      if (child is RenderEditable) {
+        renderEditable = child;
+        return;
+      }
+      child.visitChildren(recursiveFinder);
+    }
+    root.visitChildren(recursiveFinder);
+
+    // Focus text field so it has a selection color. The selection color is null
+    // on an unfocused text field.
+    await tester.tap(find.byKey(key));
+    await tester.pump();
+
+    expect(renderEditable.selectionColor, themeSelectionColor);
+    expect(tester.widget<EditableText>(find.byType(EditableText)).cursorColor, themeCursorColor);
+  });
+
   testWidgets('Fallback theme', (WidgetTester tester) async {
     late BuildContext capturedContext;
     await tester.pumpWidget(
@@ -152,8 +200,9 @@ void main() {
     await tester.tap(find.byKey(dropdownMenuButtonKey));
     await tester.pump(const Duration(seconds: 1));
 
-    for (final Element item in tester.elementList(find.text('menuItem')))
+    for (final Element item in tester.elementList(find.text('menuItem'))) {
       expect(Theme.of(item).brightness, equals(Brightness.light));
+    }
   });
 
   testWidgets('ModalBottomSheet inherits shadowed app theme', (WidgetTester tester) async {
@@ -680,7 +729,7 @@ void main() {
 
 int testBuildCalled = 0;
 class Test extends StatefulWidget {
-  const Test({ Key? key }) : super(key: key);
+  const Test({ super.key });
 
   @override
   State<Test> createState() => _TestState();
@@ -755,6 +804,8 @@ class _TextStyleProxy implements TextStyle {
   @override
   List<ui.FontFeature>? get fontFeatures => _delegate.fontFeatures;
   @override
+  List<ui.FontVariation>? get fontVariations => _delegate.fontVariations;
+  @override
   TextOverflow? get overflow => _delegate.overflow;
 
   @override
@@ -797,6 +848,7 @@ class _TextStyleProxy implements TextStyle {
     Locale? locale,
     List<ui.Shadow>? shadows,
     List<ui.FontFeature>? fontFeatures,
+    List<ui.FontVariation>? fontVariations,
     TextOverflow? overflow,
     String? package,
   }) {
@@ -828,6 +880,7 @@ class _TextStyleProxy implements TextStyle {
     ui.Paint? background,
     List<Shadow>? shadows,
     List<ui.FontFeature>? fontFeatures,
+    List<ui.FontVariation>? fontVariations,
     TextDecoration? decoration,
     Color? decorationColor,
     TextDecorationStyle? decorationStyle,
