@@ -3,7 +3,6 @@
 // found in the LICENSE file.
 
 import 'dart:async';
-import 'dart:typed_data';
 import 'dart:ui' as ui show Image, ColorFilter;
 
 import 'package:fake_async/fake_async.dart';
@@ -697,11 +696,11 @@ void main() {
     final ImageStream stream = provider.resolve(ImageConfiguration.empty);
 
     final Completer<ImageInfo> infoCompleter = Completer<ImageInfo>();
-    void _listener(ImageInfo image, bool syncCall) {
+    void listener(ImageInfo image, bool syncCall) {
       assert(!infoCompleter.isCompleted);
       infoCompleter.complete(image);
     }
-    stream.addListener(ImageStreamListener(_listener));
+    stream.addListener(ImageStreamListener(listener));
 
     final ImageInfo info = await infoCompleter.future;
     final int baselineRefCount = info.image.debugGetOpenHandleStackTraces()!.length;
