@@ -1708,9 +1708,8 @@ void main() {
           '   If this widget is always nested in a scrollable widget there is\n'
           '   no need to use a viewport because there will always be enough\n'
           '   horizontal space for the children. In this case, consider using a\n'
-          '   Row instead. Otherwise, consider using the "shrinkWrap" property\n'
-          '   (or a ShrinkWrappingViewport) to size the width of the viewport\n'
-          '   to the sum of the widths of its children.\n',
+          '   Row or Wrap instead. Otherwise, consider using a CustomScrollView\n'
+          '   to concatenate arbitrary slivers into a single scrollable.\n',
       );
     });
 
@@ -1743,9 +1742,9 @@ void main() {
           '   If this widget is always nested in a scrollable widget there is\n'
           '   no need to use a viewport because there will always be enough\n'
           '   vertical space for the children. In this case, consider using a\n'
-          '   Column instead. Otherwise, consider using the "shrinkWrap"\n'
-          '   property (or a ShrinkWrappingViewport) to size the height of the\n'
-          '   viewport to the sum of the heights of its children.\n',
+          '   Column or Wrap instead. Otherwise, consider using a\n'
+          '   CustomScrollView to concatenate arbitrary slivers into a single\n'
+          '   scrollable.\n',
       );
     });
   });
@@ -1845,7 +1844,7 @@ void main() {
   });
 
   group('Overscrolling RenderShrinkWrappingViewport', () {
-    Widget _buildSimpleShrinkWrap({
+    Widget buildSimpleShrinkWrap({
       ScrollController? controller,
       Axis scrollDirection = Axis.vertical,
       ScrollPhysics? physics,
@@ -1867,7 +1866,7 @@ void main() {
       );
     }
 
-    Widget _buildClippingShrinkWrap(
+    Widget buildClippingShrinkWrap(
       ScrollController controller, {
       bool constrain = false,
     }) {
@@ -1912,7 +1911,7 @@ void main() {
       // Regression test for https://github.com/flutter/flutter/issues/89717
       final  ScrollController controller = ScrollController();
       await tester.pumpWidget(
-        _buildClippingShrinkWrap(controller, constrain: true)
+        buildClippingShrinkWrap(controller, constrain: true)
       );
       expect(controller.offset, 0.0);
       expect(tester.getTopLeft(find.text('Item 0')).dy, 100.0);
@@ -1939,7 +1938,7 @@ void main() {
       // Regression test for https://github.com/flutter/flutter/issues/89717
       final  ScrollController controller = ScrollController();
       await tester.pumpWidget(
-        _buildClippingShrinkWrap(controller)
+        buildClippingShrinkWrap(controller)
       );
       expect(controller.offset, 0.0);
       expect(tester.getTopLeft(find.text('Item 0')).dy, 100.0);
@@ -1967,7 +1966,7 @@ void main() {
       // Scrollables should overscroll by default on iOS and macOS
       final  ScrollController controller = ScrollController();
       await tester.pumpWidget(
-        _buildSimpleShrinkWrap(controller: controller),
+        buildSimpleShrinkWrap(controller: controller),
       );
       expect(controller.offset, 0.0);
       expect(tester.getTopLeft(find.text('Item 0')).dy, 0.0);
@@ -2006,7 +2005,7 @@ void main() {
       // Scrollables should overscroll by default on iOS and macOS
       final  ScrollController controller = ScrollController();
       await tester.pumpWidget(
-        _buildSimpleShrinkWrap(controller: controller, scrollDirection: Axis.horizontal),
+        buildSimpleShrinkWrap(controller: controller, scrollDirection: Axis.horizontal),
       );
       expect(controller.offset, 0.0);
       expect(tester.getTopLeft(find.text('Item 0')).dx, 0.0);
@@ -2045,7 +2044,7 @@ void main() {
       // Scrollables should overscroll when the scroll physics allow
       final  ScrollController controller = ScrollController();
       await tester.pumpWidget(
-        _buildSimpleShrinkWrap(controller: controller, physics: const BouncingScrollPhysics()),
+        buildSimpleShrinkWrap(controller: controller, physics: const BouncingScrollPhysics()),
       );
       expect(controller.offset, 0.0);
       expect(tester.getTopLeft(find.text('Item 0')).dy, 0.0);
@@ -2084,7 +2083,7 @@ void main() {
       // Scrollables should overscroll when the scroll physics allow
       final  ScrollController controller = ScrollController();
       await tester.pumpWidget(
-        _buildSimpleShrinkWrap(
+        buildSimpleShrinkWrap(
           controller: controller,
           scrollDirection: Axis.horizontal,
           physics: const BouncingScrollPhysics(),
@@ -2158,4 +2157,41 @@ void main() {
     await tester.drag(find.text('b'), const Offset(0, 200));
     await tester.pumpAndSettle();
   }, variant: const TargetPlatformVariant(<TargetPlatform>{ TargetPlatform.iOS, TargetPlatform.macOS }));
+
+  testWidgets('Viewport describeApproximateClip respects clipBehavior', (WidgetTester tester) async {
+    await tester.pumpWidget(const Directionality(
+      textDirection: TextDirection.ltr,
+      child: CustomScrollView(
+        clipBehavior: Clip.none,
+        slivers: <Widget>[
+          SliverToBoxAdapter(child: SizedBox(width: 20, height: 20)),
+        ]
+      ),
+    ));
+    RenderViewport viewport = tester.allRenderObjects.whereType<RenderViewport>().first;
+    expect(viewport.clipBehavior, Clip.none);
+    bool visited = false;
+    viewport.visitChildren((RenderObject child) {
+      visited = true;
+      expect(viewport.describeApproximatePaintClip(child as RenderSliver), null);
+    });
+    expect(visited, true);
+
+    await tester.pumpWidget(const Directionality(
+      textDirection: TextDirection.ltr,
+      child: CustomScrollView(
+        slivers: <Widget>[
+          SliverToBoxAdapter(child: SizedBox(width: 20, height: 20)),
+        ]
+      ),
+    ));
+    viewport = tester.allRenderObjects.whereType<RenderViewport>().first;
+    expect(viewport.clipBehavior, Clip.hardEdge);
+    visited = false;
+    viewport.visitChildren((RenderObject child) {
+      visited = true;
+      expect(viewport.describeApproximatePaintClip(child as RenderSliver), Offset.zero & viewport.size);
+    });
+    expect(visited, true);
+  });
 }
