@@ -8,6 +8,7 @@
 
 import 'dart:math' as math;
 import 'dart:ui' as ui;
+import 'dart:ui';
 
 import 'package:flutter/gestures.dart';
 import 'package:flutter/material.dart';
@@ -750,7 +751,6 @@ void main() {
 
     final TestGesture gesture = await tester.createGesture(pointer: 1, kind: PointerDeviceKind.mouse);
     await gesture.addPointer(location: const Offset(200, 200));
-    addTearDown(gesture.removePointer);
 
     await tester.pumpWidget(target(ignoring: true));
     expect(logs, isEmpty);
@@ -828,7 +828,6 @@ void main() {
 
     final TestGesture gesture = await tester.createGesture(pointer: 1, kind: PointerDeviceKind.mouse);
     await gesture.addPointer(location: const Offset(200, 200));
-    addTearDown(gesture.removePointer);
 
     await tester.pumpWidget(target(absorbing: true));
     expect(logs, isEmpty);
