@@ -84,10 +84,12 @@ void main() {
     // Populate a fake clipboard.
     const String clipboardContent = ' ';
     tester.binding.defaultBinaryMessenger.setMockMethodCallHandler(SystemChannels.platform, (MethodCall methodCall) async {
-      if (methodCall.method == 'Clipboard.getData')
+      if (methodCall.method == 'Clipboard.getData') {
         return const <String, dynamic>{'text': clipboardContent};
-      if (methodCall.method == 'Clipboard.hasStrings')
+      }
+      if (methodCall.method == 'Clipboard.hasStrings') {
         return <String, dynamic>{'value': clipboardContent.isNotEmpty};
+      }
       return null;
     });
 
@@ -138,10 +140,12 @@ void main() {
     // Populate a fake clipboard.
     const String clipboardContent = ' ';
     tester.binding.defaultBinaryMessenger.setMockMethodCallHandler(SystemChannels.platform, (MethodCall methodCall) async {
-      if (methodCall.method == 'Clipboard.getData')
+      if (methodCall.method == 'Clipboard.getData') {
         return const <String, dynamic>{'text': clipboardContent};
-      if (methodCall.method == 'Clipboard.hasStrings')
+      }
+      if (methodCall.method == 'Clipboard.hasStrings') {
         return <String, dynamic>{'value': clipboardContent.isNotEmpty};
+      }
       return null;
     });
 
@@ -162,61 +166,75 @@ void main() {
     );
   });
 
-  testWidgets('Cursor animates', (WidgetTester tester) async {
-    const Widget widget = MaterialApp(
-      home: Material(
-        child: TextField(
-          maxLines: 3,
+  testWidgets('Cursor animates on iOS', (WidgetTester tester) async {
+    await tester.pumpWidget(
+      const MaterialApp(
+        home: Material(
+          child: TextField(),
         ),
       ),
     );
-    await tester.pumpWidget(widget);
 
-    await tester.tap(find.byType(TextField));
+    final Finder textFinder = find.byType(TextField);
+    await tester.tap(textFinder);
     await tester.pump();
 
     final EditableTextState editableTextState = tester.firstState(find.byType(EditableText));
     final RenderEditable renderEditable = editableTextState.renderEditable;
 
-    expect(renderEditable.cursorColor!.alpha, 255);
+    expect(renderEditable.cursorColor!.opacity, 1.0);
 
-    // Trigger initial timer. When focusing the first time, the cursor shows
-    // for slightly longer than the average on time.
+    int walltimeMicrosecond = 0;
+    double lastVerifiedOpacity = 1.0;
+
+    Future<void> verifyKeyFrame({ required double opacity, required int at }) async {
+      const int delta = 1;
+      assert(at - delta > walltimeMicrosecond);
+      await tester.pump(Duration(microseconds: at - delta - walltimeMicrosecond));
+
+      // Instead of verifying the opacity at each key frame, this function
+      // verifies the opacity immediately *before* each key frame to avoid
+      // fp precision issues.
+      expect(
+        renderEditable.cursorColor!.opacity,
+        closeTo(lastVerifiedOpacity, 0.01),
+        reason: 'opacity at ${at-delta} microseconds',
+      );
+
+      walltimeMicrosecond = at - delta;
+      lastVerifiedOpacity = opacity;
+    }
+
+    await verifyKeyFrame(opacity: 1.0,  at: 500000);
+    await verifyKeyFrame(opacity: 0.75, at: 537500);
+    await verifyKeyFrame(opacity: 0.5,  at: 575000);
+    await verifyKeyFrame(opacity: 0.25, at: 612500);
+    await verifyKeyFrame(opacity: 0.0,  at: 650000);
+    await verifyKeyFrame(opacity: 0.0,  at: 850000);
+    await verifyKeyFrame(opacity: 0.25, at: 887500);
+    await verifyKeyFrame(opacity: 0.5,  at: 925000);
+    await verifyKeyFrame(opacity: 0.75, at: 962500);
+    await verifyKeyFrame(opacity: 1.0,  at: 1000000);
+  }, variant: const TargetPlatformVariant(<TargetPlatform>{ TargetPlatform.iOS }));
+
+  testWidgets('Cursor does not animate on non-iOS platforms', (WidgetTester tester) async {
+    await tester.pumpWidget(
+      const MaterialApp(
+        home: Material(child: TextField(maxLines: 3)),
+      ),
+    );
+
+    await tester.tap(find.byType(TextField));
     await tester.pump();
-    await tester.pump(const Duration(milliseconds: 200));
-    // Start timing standard cursor show period.
-    expect(renderEditable.cursorColor!.alpha, 255);
-    expect(renderEditable, paints..rrect(color: const Color(0xff2196f3)));
+    // Wait for the current animation to finish. If the cursor never stops its
+    // blinking animation the test will timeout.
+    await tester.pumpAndSettle();
 
-    await tester.pump(const Duration(milliseconds: 500));
-    // Start to animate the cursor away.
-    expect(renderEditable.cursorColor!.alpha, 255);
-    expect(renderEditable, paints..rrect(color: const Color(0xff2196f3)));
-
-    await tester.pump(const Duration(milliseconds: 100));
-    expect(renderEditable.cursorColor!.alpha, 110);
-    expect(renderEditable, paints..rrect(color: const Color(0x6e2196f3)));
-
-    await tester.pump(const Duration(milliseconds: 100));
-    expect(renderEditable.cursorColor!.alpha, 16);
-    expect(renderEditable, paints..rrect(color: const Color(0x102196f3)));
-
-    await tester.pump(const Duration(milliseconds: 100));
-    expect(renderEditable.cursorColor!.alpha, 0);
-    // Don't try to draw the cursor.
-    expect(renderEditable, paintsExactlyCountTimes(#drawRRect, 0));
-
-    // Wait some more while the cursor is gone. It'll trigger the cursor to
-    // start animating in again.
-    await tester.pump(const Duration(milliseconds: 300));
-    expect(renderEditable.cursorColor!.alpha, 0);
-    expect(renderEditable, paintsExactlyCountTimes(#drawRRect, 0));
-
-    await tester.pump(const Duration(milliseconds: 50));
-    // Cursor starts coming back.
-    expect(renderEditable.cursorColor!.alpha, 79);
-    expect(renderEditable, paints..rrect(color: const Color(0x4f2196f3)));
-  }, variant: const TargetPlatformVariant(<TargetPlatform>{ TargetPlatform.iOS,  TargetPlatform.macOS }));
+    for (int i = 0; i < 40; i += 1) {
+      await tester.pump(const Duration(milliseconds: 100));
+      expect(tester.hasRunningAnimations, false);
+    }
+  }, variant: TargetPlatformVariant.all(excluding: <TargetPlatform>{ TargetPlatform.iOS }));
 
   testWidgets('Cursor does not animate on Android', (WidgetTester tester) async {
     final Color defaultCursorColor = Color(ThemeData.fallback().colorScheme.primary.value);
@@ -440,6 +458,37 @@ void main() {
     expect(renderEditable, paintsExactlyCountTimes(#drawRect, 0));
   });
 
+  testWidgets('Cursor does not show when not focused', (WidgetTester tester) async {
+    // Regression test for https://github.com/flutter/flutter/issues/106512 .
+    final FocusNode focusNode = FocusNode();
+    await tester.pumpWidget(
+      MaterialApp(
+        home: Material(
+          child: TextField(focusNode: focusNode, autofocus: true),
+        ),
+      ),
+    );
+    assert(focusNode.hasFocus);
+    final EditableTextState editableTextState = tester.firstState(find.byType(EditableText));
+    final RenderEditable renderEditable = editableTextState.renderEditable;
+
+    focusNode.unfocus();
+    await tester.pump();
+
+    for (int i = 0; i < 10; i += 10) {
+      // Make sure it does not paint for a period of time.
+      expect(renderEditable, paintsExactlyCountTimes(#drawRect, 0));
+      expect(tester.hasRunningAnimations, isFalse);
+      await tester.pump(const Duration(milliseconds: 29));
+    }
+
+    // Refocus and it should paint the caret.
+    focusNode.requestFocus();
+    await tester.pump();
+    await tester.pump(const Duration(milliseconds: 100));
+    expect(renderEditable, isNot(paintsExactlyCountTimes(#drawRect, 0)));
+  });
+
   testWidgets('Cursor radius is 2.0', (WidgetTester tester) async {
     const Widget widget = MaterialApp(
       home: Material(
@@ -864,10 +913,12 @@ void main() {
     // Populate a fake clipboard.
     const String clipboardContent = 'Hello world!';
     tester.binding.defaultBinaryMessenger.setMockMethodCallHandler(SystemChannels.platform, (MethodCall methodCall) async {
-      if (methodCall.method == 'Clipboard.getData')
+      if (methodCall.method == 'Clipboard.getData') {
         return const <String, dynamic>{'text': clipboardContent};
-      if (methodCall.method == 'Clipboard.hasStrings')
+      }
+      if (methodCall.method == 'Clipboard.hasStrings') {
         return <String, dynamic>{'value': clipboardContent.isNotEmpty};
+      }
       return null;
     });
 
@@ -924,10 +975,12 @@ void main() {
     // Populate a fake clipboard.
     const String clipboardContent = 'Hello world!';
     tester.binding.defaultBinaryMessenger.setMockMethodCallHandler(SystemChannels.platform, (MethodCall methodCall) async {
-      if (methodCall.method == 'Clipboard.getData')
+      if (methodCall.method == 'Clipboard.getData') {
         return const <String, dynamic>{'text': clipboardContent};
-      if (methodCall.method == 'Clipboard.hasStrings')
+      }
+      if (methodCall.method == 'Clipboard.hasStrings') {
         return <String, dynamic>{'value': clipboardContent.isNotEmpty};
+      }
       return null;
     });
 
@@ -948,4 +1001,40 @@ void main() {
     );
     EditableText.debugDeterministicCursor = false;
   }, variant: const TargetPlatformVariant(<TargetPlatform>{ TargetPlatform.iOS,  TargetPlatform.macOS }));
+
+  testWidgets('password briefly does not show last character when disabled by system', (WidgetTester tester) async {
+    final bool debugDeterministicCursor = EditableText.debugDeterministicCursor;
+    EditableText.debugDeterministicCursor = false;
+    addTearDown(() {
+      EditableText.debugDeterministicCursor = debugDeterministicCursor;
+    });
+
+    await tester.pumpWidget(MaterialApp(
+      home: EditableText(
+        backgroundCursorColor: Colors.grey,
+        controller: controller,
+        obscureText: true,
+        focusNode: focusNode,
+        style: textStyle,
+        cursorColor: cursorColor,
+      ),
+    ));
+
+    await tester.enterText(find.byType(EditableText), 'AA');
+    await tester.pump();
+    await tester.enterText(find.byType(EditableText), 'AAA');
+    await tester.pump();
+
+    tester.binding.platformDispatcher.brieflyShowPasswordTestValue = false;
+    addTearDown(() {
+      tester.binding.platformDispatcher.brieflyShowPasswordTestValue = true;
+    });
+    expect((findRenderEditable(tester).text! as TextSpan).text, '••A');
+    await tester.pump(const Duration(milliseconds: 500));
+    expect((findRenderEditable(tester).text! as TextSpan).text, '•••');
+    await tester.pump(const Duration(milliseconds: 500));
+    await tester.pump(const Duration(milliseconds: 500));
+    await tester.pump(const Duration(milliseconds: 500));
+    expect((findRenderEditable(tester).text! as TextSpan).text, '•••');
+  });
 }
