@@ -2,6 +2,7 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
+import 'dart:async';
 import 'dart:typed_data';
 import 'dart:ui' as ui;
 
@@ -35,8 +36,9 @@ class FadeInImageParts {
   Element? get semanticsElement {
     Element? result;
     fadeInImageElement.visitChildren((Element child) {
-      if (child.widget is Semantics)
+      if (child.widget is Semantics) {
         result = child;
+      }
     });
     return result;
   }
@@ -57,8 +59,8 @@ class LoadTestImageProvider extends ImageProvider<Object> {
 
   final ImageProvider provider;
 
-  ImageStreamCompleter testLoad(Object key, DecoderCallback decode) {
-    return provider.load(key, decode);
+  ImageStreamCompleter testLoad(Object key, DecoderBufferCallback decode) {
+    return provider.loadBuffer(key, decode);
   }
 
   @override
@@ -156,6 +158,82 @@ Future<void> main() async {
       expect(findFadeInImage(tester).target.opacity, 1);
     });
 
+    testWidgets("FadeInImage's image obeys gapless playback", (WidgetTester tester) async {
+      final TestImageProvider placeholderProvider = TestImageProvider(placeholderImage);
+      final TestImageProvider imageProvider = TestImageProvider(targetImage);
+      final TestImageProvider secondImageProvider = TestImageProvider(replacementImage);
+
+      await tester.pumpWidget(FadeInImage(
+        placeholder: placeholderProvider,
+        image: imageProvider,
+        fadeOutDuration: animationDuration,
+        fadeInDuration: animationDuration,
+      ));
+
+      imageProvider.complete();
+      placeholderProvider.complete();
+      await tester.pump();
+      await tester.pump(animationDuration * 2);
+      // Calls setState after the animation, which removes the placeholder image.
+      await tester.pump(const Duration(milliseconds: 100));
+
+      await tester.pumpWidget(FadeInImage(
+        placeholder: placeholderProvider,
+        image: secondImageProvider,
+      ));
+      await tester.pump();
+
+      FadeInImageParts parts = findFadeInImage(tester);
+      // Continually shows previously loaded image,
+      expect(parts.placeholder, isNull);
+      expect(parts.target.rawImage.image!.isCloneOf(targetImage), isTrue);
+      expect(parts.target.opacity, 1);
+
+      // Until the new image provider provides the image.
+      secondImageProvider.complete();
+      await tester.pump();
+
+      parts = findFadeInImage(tester);
+      expect(parts.target.rawImage.image!.isCloneOf(replacementImage), isTrue);
+      expect(parts.target.opacity, 1);
+    });
+
+    testWidgets("FadeInImage's placeholder obeys gapless playback", (WidgetTester tester) async {
+      final TestImageProvider placeholderProvider = TestImageProvider(placeholderImage);
+      final TestImageProvider secondPlaceholderProvider = TestImageProvider(replacementImage);
+      final TestImageProvider imageProvider = TestImageProvider(targetImage);
+
+      await tester.pumpWidget(FadeInImage(
+        placeholder: placeholderProvider,
+        image: imageProvider,
+      ));
+
+      placeholderProvider.complete();
+      await tester.pump();
+
+      FadeInImageParts parts = findFadeInImage(tester);
+      expect(parts.placeholder!.rawImage.image!.isCloneOf(placeholderImage), true);
+      expect(parts.placeholder!.opacity, 1);
+
+      await tester.pumpWidget(FadeInImage(
+        placeholder: secondPlaceholderProvider,
+        image: imageProvider,
+      ));
+
+      parts = findFadeInImage(tester);
+      // continually shows previously loaded image.
+      expect(parts.placeholder!.rawImage.image!.isCloneOf(placeholderImage), true);
+      expect(parts.placeholder!.opacity, 1);
+
+      // Until the new image provider provides the image.
+      secondPlaceholderProvider.complete();
+      await tester.pump();
+
+      parts = findFadeInImage(tester);
+      expect(parts.placeholder!.rawImage.image!.isCloneOf(replacementImage), true);
+      expect(parts.placeholder!.opacity, 1);
+    });
+
     testWidgets('shows a cached image immediately when skipFadeOnSynchronousLoad=true', (WidgetTester tester) async {
       final TestImageProvider placeholderProvider = TestImageProvider(placeholderImage);
       final TestImageProvider imageProvider = TestImageProvider(targetImage);
@@ -226,48 +304,6 @@ Future<void> main() async {
       expect(find.byType(Image), findsOneWidget);
     });
 
-    testWidgets('re-fades in the image when the target image is updated', (WidgetTester tester) async {
-      final TestImageProvider placeholderProvider = TestImageProvider(placeholderImage);
-      final TestImageProvider imageProvider = TestImageProvider(targetImage);
-      final TestImageProvider secondImageProvider = TestImageProvider(replacementImage);
-
-      await tester.pumpWidget(FadeInImage(
-        placeholder: placeholderProvider,
-        image: imageProvider,
-        fadeOutDuration: animationDuration,
-        fadeInDuration: animationDuration,
-        excludeFromSemantics: true,
-      ));
-
-      final State? state = findFadeInImage(tester).state;
-      placeholderProvider.complete();
-      imageProvider.complete();
-      await tester.pump();
-      await tester.pump(animationDuration * 2);
-
-      await tester.pumpWidget(FadeInImage(
-        placeholder: placeholderProvider,
-        image: secondImageProvider,
-        fadeOutDuration: animationDuration,
-        fadeInDuration: animationDuration,
-        excludeFromSemantics: true,
-      ));
-
-      secondImageProvider.complete();
-      await tester.pump();
-
-      expect(findFadeInImage(tester).target.rawImage.image!.isCloneOf(replacementImage), true);
-      expect(findFadeInImage(tester).state, same(state));
-      expect(findFadeInImage(tester).placeholder!.opacity, moreOrLessEquals(1));
-      expect(findFadeInImage(tester).target.opacity, moreOrLessEquals(0));
-      await tester.pump(animationDuration);
-      expect(findFadeInImage(tester).placeholder!.opacity, moreOrLessEquals(0));
-      expect(findFadeInImage(tester).target.opacity, moreOrLessEquals(0));
-      await tester.pump(animationDuration);
-      expect(findFadeInImage(tester).placeholder!.opacity, moreOrLessEquals(0));
-      expect(findFadeInImage(tester).target.opacity, moreOrLessEquals(1));
-    });
-
     testWidgets("doesn't interrupt in-progress animation when animation values are updated", (WidgetTester tester) async {
       final TestImageProvider placeholderProvider = TestImageProvider(placeholderImage);
       final TestImageProvider imageProvider = TestImageProvider(targetImage);
@@ -304,7 +340,7 @@ Future<void> main() async {
 
     group('ImageProvider', () {
 
-      testWidgets('memory placeholder cacheWidth and cacheHeight is passed through', (WidgetTester tester) async {
+      test('memory placeholder cacheWidth and cacheHeight is passed through', () async {
         final Uint8List testBytes = Uint8List.fromList(kTransparentImage);
         final FadeInImage image = FadeInImage.memoryNetwork(
           placeholder: testBytes,
@@ -316,22 +352,29 @@ Future<void> main() async {
         );
 
         bool called = false;
-        Future<ui.Codec> decode(Uint8List bytes, {int? cacheWidth, int? cacheHeight, bool allowUpscaling = false}) {
+        Future<ui.Codec> decode(ui.ImmutableBuffer buffer, {int? cacheWidth, int? cacheHeight, bool allowUpscaling = false}) {
           expect(cacheWidth, 20);
           expect(cacheHeight, 30);
           expect(allowUpscaling, false);
           called = true;
-          return PaintingBinding.instance.instantiateImageCodec(bytes, cacheWidth: cacheWidth, cacheHeight: cacheHeight, allowUpscaling: allowUpscaling);
+          return PaintingBinding.instance.instantiateImageCodecFromBuffer(buffer, cacheWidth: cacheWidth, cacheHeight: cacheHeight, allowUpscaling: allowUpscaling);
         }
         final ImageProvider resizeImage = image.placeholder;
         expect(image.placeholder, isA<ResizeImage>());
         expect(called, false);
         final LoadTestImageProvider testProvider = LoadTestImageProvider(image.placeholder);
-        testProvider.testLoad(await resizeImage.obtainKey(ImageConfiguration.empty), decode);
+        final ImageStreamCompleter streamCompleter = testProvider.testLoad(await resizeImage.obtainKey(ImageConfiguration.empty), decode);
+
+        final Completer<void> completer = Completer<void>();
+        streamCompleter.addListener(ImageStreamListener((ImageInfo imageInfo, bool syncCall) {
+          completer.complete();
+        }));
+        await completer.future;
+
         expect(called, true);
       });
 
-      testWidgets('do not resize when null cache dimensions', (WidgetTester tester) async {
+      test('do not resize when null cache dimensions', () async {
         final Uint8List testBytes = Uint8List.fromList(kTransparentImage);
         final FadeInImage image = FadeInImage.memoryNetwork(
           placeholder: testBytes,
@@ -339,19 +382,26 @@ Future<void> main() async {
         );
 
         bool called = false;
-        Future<ui.Codec> decode(Uint8List bytes, {int? cacheWidth, int? cacheHeight, bool allowUpscaling = false}) {
+        Future<ui.Codec> decode(ui.ImmutableBuffer buffer, {int? cacheWidth, int? cacheHeight, bool allowUpscaling = false}) {
           expect(cacheWidth, null);
           expect(cacheHeight, null);
           expect(allowUpscaling, false);
           called = true;
-          return PaintingBinding.instance.instantiateImageCodec(bytes, cacheWidth: cacheWidth, cacheHeight: cacheHeight);
+          return PaintingBinding.instance.instantiateImageCodecFromBuffer(buffer, cacheWidth: cacheWidth, cacheHeight: cacheHeight);
         }
         // image.placeholder should be an instance of MemoryImage instead of ResizeImage
         final ImageProvider memoryImage = image.placeholder;
         expect(image.placeholder, isA<MemoryImage>());
         expect(called, false);
         final LoadTestImageProvider testProvider = LoadTestImageProvider(image.placeholder);
-        testProvider.testLoad(await memoryImage.obtainKey(ImageConfiguration.empty), decode);
+        final ImageStreamCompleter streamCompleter = testProvider.testLoad(await memoryImage.obtainKey(ImageConfiguration.empty), decode);
+
+        final Completer<void> completer = Completer<void>();
+        streamCompleter.addListener(ImageStreamListener((ImageInfo imageInfo, bool syncCall) {
+          completer.complete();
+        }));
+        await completer.future;
+
         expect(called, true);
       });
     });
