@@ -701,9 +701,8 @@ void main() {
 
 class _TestLayoutPerformer extends SingleChildRenderObjectWidget {
   const _TestLayoutPerformer({
-    Key? key,
     required this.performLayout,
-  }) : super(key: key);
+  });
 
   final VoidCallback performLayout;
 
@@ -726,8 +725,9 @@ class _RenderTestLayoutPerformer extends RenderBox {
   @override
   void performLayout() {
     size = const Size(1, 1);
-    if (_performLayout != null)
+    if (_performLayout != null) {
       _performLayout();
+    }
   }
 }
 
@@ -735,8 +735,9 @@ Map<Type, GestureRecognizerFactory> _buildGestureMap<T extends GestureRecognizer
   GestureRecognizerFactoryConstructor<T>? constructor,
   GestureRecognizerFactoryInitializer<T>? initializer,
 ) {
-  if (constructor == null)
+  if (constructor == null) {
     return <Type, GestureRecognizerFactory>{};
+  }
   return <Type, GestureRecognizerFactory>{
     T: GestureRecognizerFactoryWithHandlers<T>(
       constructor,
