@@ -10,7 +10,7 @@ import '../rendering/mock_canvas.dart';
 import 'semantics_tester.dart';
 
 class TestState extends StatefulWidget {
-  const TestState({ Key? key, required this.child, required this.log }) : super(key: key);
+  const TestState({ super.key, required this.child, required this.log });
   final Widget child;
   final List<String> log;
   @override
@@ -35,7 +35,7 @@ void main() {
     final List<String> log = <String>[];
     const Key anchor = Key('drag');
 
-    Widget _boilerPlate(Widget sliver) {
+    Widget boilerPlate(Widget sliver) {
       return Localizations(
         locale: const Locale('en', 'us'),
         delegates: const <LocalizationsDelegate<dynamic>>[
@@ -75,7 +75,7 @@ void main() {
     // also verifies that the widget can dynamically change from state to state.
 
     // Default
-    await tester.pumpWidget(_boilerPlate(SliverVisibility(sliver: testChild)));
+    await tester.pumpWidget(boilerPlate(SliverVisibility(sliver: testChild)));
     expect(find.byType(Text, skipOffstage: false), findsOneWidget);
     expect(find.text('a true', skipOffstage: false), findsOneWidget);
     expect(find.byType(SliverVisibility), findsOneWidget);
@@ -91,7 +91,7 @@ void main() {
     log.clear();
 
     // visible: false
-    await tester.pumpWidget(_boilerPlate(SliverVisibility(
+    await tester.pumpWidget(boilerPlate(SliverVisibility(
       sliver: testChild,
       visible: false,
     )));
@@ -108,7 +108,7 @@ void main() {
     log.clear();
 
     // visible: false, with replacementSliver
-    await tester.pumpWidget(_boilerPlate(SliverVisibility(
+    await tester.pumpWidget(boilerPlate(SliverVisibility(
       sliver: testChild,
       replacementSliver: const SliverToBoxAdapter(child: Placeholder()),
       visible: false,
@@ -126,7 +126,7 @@ void main() {
     log.clear();
 
     // visible: true, with replacementSliver
-    await tester.pumpWidget(_boilerPlate(SliverVisibility(
+    await tester.pumpWidget(boilerPlate(SliverVisibility(
       sliver: testChild,
       replacementSliver: const SliverToBoxAdapter(child: Placeholder()),
     )));
@@ -145,7 +145,7 @@ void main() {
     log.clear();
 
     // visible: true, maintain all
-    await tester.pumpWidget(_boilerPlate(SliverVisibility(
+    await tester.pumpWidget(boilerPlate(SliverVisibility(
       sliver: testChild,
       maintainState: true,
       maintainAnimation: true,
@@ -167,7 +167,7 @@ void main() {
     log.clear();
 
     // visible: false, maintain all
-    await tester.pumpWidget(_boilerPlate(SliverVisibility(
+    await tester.pumpWidget(boilerPlate(SliverVisibility(
       sliver: testChild,
       visible: false,
       maintainState: true,
@@ -190,7 +190,7 @@ void main() {
     log.clear();
 
     // visible: false, maintain all, replacementSliver
-    await tester.pumpWidget(_boilerPlate(SliverVisibility(
+    await tester.pumpWidget(boilerPlate(SliverVisibility(
       sliver: testChild,
       replacementSliver: const SliverToBoxAdapter(child: Placeholder()),
       visible: false,
@@ -216,7 +216,7 @@ void main() {
     log.clear();
 
     // visible: false, maintain all but semantics
-    await tester.pumpWidget(_boilerPlate(SliverVisibility(
+    await tester.pumpWidget(boilerPlate(SliverVisibility(
       sliver: testChild,
       visible: false,
       maintainState: true,
@@ -239,7 +239,7 @@ void main() {
     log.clear();
 
     // visible: false, maintain all but interactivity
-    await tester.pumpWidget(_boilerPlate(SliverVisibility(
+    await tester.pumpWidget(boilerPlate(SliverVisibility(
       sliver: testChild,
       visible: false,
       maintainState: true,
@@ -262,7 +262,7 @@ void main() {
     log.clear();
 
     // visible: false, maintain state, animation, size.
-    await tester.pumpWidget(_boilerPlate(SliverVisibility(
+    await tester.pumpWidget(boilerPlate(SliverVisibility(
       sliver: testChild,
       visible: false,
       maintainState: true,
@@ -284,7 +284,7 @@ void main() {
     log.clear();
 
     // visible: false, maintain state and animation.
-    await tester.pumpWidget(_boilerPlate(SliverVisibility(
+    await tester.pumpWidget(boilerPlate(SliverVisibility(
       sliver: testChild,
       visible: false,
       maintainState: true,
@@ -305,7 +305,7 @@ void main() {
     log.clear();
 
     // visible: false, maintain state.
-    await tester.pumpWidget(_boilerPlate(SliverVisibility(
+    await tester.pumpWidget(boilerPlate(SliverVisibility(
       sliver: testChild,
       visible: false,
       maintainState: true,
@@ -328,7 +328,7 @@ void main() {
     // works.
 
     // visible: true, maintain state
-    await tester.pumpWidget(_boilerPlate(SliverVisibility(
+    await tester.pumpWidget(boilerPlate(SliverVisibility(
       sliver: testChild,
       maintainState: true,
     )));
@@ -347,7 +347,7 @@ void main() {
     log.clear();
 
     // visible: false, maintain state.
-    await tester.pumpWidget(_boilerPlate(SliverVisibility(
+    await tester.pumpWidget(boilerPlate(SliverVisibility(
       sliver: testChild,
       visible: false,
       maintainState: true,
@@ -367,7 +367,7 @@ void main() {
     log.clear();
 
     // visible: true, maintain state.
-    await tester.pumpWidget(_boilerPlate(SliverVisibility(
+    await tester.pumpWidget(boilerPlate(SliverVisibility(
       sliver: testChild,
       maintainState: true,
     )));
@@ -386,7 +386,7 @@ void main() {
     log.clear();
 
     // visible: false, maintain state.
-    await tester.pumpWidget(_boilerPlate(SliverVisibility(
+    await tester.pumpWidget(boilerPlate(SliverVisibility(
       sliver: testChild,
       visible: false,
       maintainState: true,
@@ -408,7 +408,7 @@ void main() {
     // Same but without maintainState.
 
     // visible: false.
-    await tester.pumpWidget(_boilerPlate(SliverVisibility(
+    await tester.pumpWidget(boilerPlate(SliverVisibility(
       sliver: testChild,
       visible: false,
     )));
@@ -425,7 +425,7 @@ void main() {
     log.clear();
 
     // visible: true.
-    await tester.pumpWidget(_boilerPlate(SliverVisibility(
+    await tester.pumpWidget(boilerPlate(SliverVisibility(
       sliver: testChild,
     )));
     expect(find.byType(Text), findsOneWidget);
@@ -443,7 +443,7 @@ void main() {
     log.clear();
 
     //visible: false.
-    await tester.pumpWidget(_boilerPlate(SliverVisibility(
+    await tester.pumpWidget(boilerPlate(SliverVisibility(
       sliver: testChild,
       visible: false,
     )));
@@ -460,7 +460,7 @@ void main() {
     log.clear();
 
     // visible: true.
-    await tester.pumpWidget(_boilerPlate(SliverVisibility(
+    await tester.pumpWidget(boilerPlate(SliverVisibility(
       sliver: testChild,
     )));
     expect(find.byType(Text), findsOneWidget);
