@@ -500,8 +500,9 @@ class _RenderRootableRepaintBoundary extends RenderRepaintBoundary {
 
   TransformLayer _rootLayer() {
     Layer layer = this.layer!;
-    while (layer.parent != null)
+    while (layer.parent != null) {
       layer = layer.parent!;
+    }
     return layer as TransformLayer;
   }
 }
