@@ -2,6 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
+import 'dart:async';
+
 import 'package:process/process.dart';
 
 import '../base/common.dart';
@@ -269,7 +271,7 @@ class AndroidValidator extends DoctorValidator {
 /// SDK have been accepted.
 class AndroidLicenseValidator extends DoctorValidator {
   AndroidLicenseValidator({
-    required AndroidSdk androidSdk,
+    required AndroidSdk? androidSdk,
     required Platform platform,
     required OperatingSystemUtils operatingSystemUtils,
     required FileSystem fileSystem,
@@ -289,7 +291,7 @@ class AndroidLicenseValidator extends DoctorValidator {
        _userMessages = userMessages,
        super('Android license subvalidator');
 
-  final AndroidSdk _androidSdk;
+  final AndroidSdk? _androidSdk;
   final AndroidStudio? _androidStudio;
   final Stdio _stdio;
   final OperatingSystemUtils _operatingSystemUtils;
@@ -307,13 +309,13 @@ class AndroidLicenseValidator extends DoctorValidator {
     final List<ValidationMessage> messages = <ValidationMessage>[];
 
     // Match pre-existing early termination behavior
-    if (_androidSdk == null || _androidSdk.latestVersion == null ||
-        _androidSdk.validateSdkWellFormed().isNotEmpty ||
+    if (_androidSdk == null || _androidSdk?.latestVersion == null ||
+        _androidSdk!.validateSdkWellFormed().isNotEmpty ||
         ! await _checkJavaVersionNoOutput()) {
       return ValidationResult(ValidationType.missing, messages);
     }
 
-    final String sdkVersionText = _userMessages.androidStatusInfo(_androidSdk.latestVersion!.buildToolsVersionName);
+    final String sdkVersionText = _userMessages.androidStatusInfo(_androidSdk!.latestVersion!.buildToolsVersionName);
 
     // Check for licenses.
     switch (await licensesAccepted) {
@@ -366,7 +368,7 @@ class AndroidLicenseValidator extends DoctorValidator {
   Future<LicensesAccepted> get licensesAccepted async {
     LicensesAccepted? status;
 
-    void _handleLine(String line) {
+    void handleLine(String line) {
       if (licenseCounts.hasMatch(line)) {
         final Match? match = licenseCounts.firstMatch(line);
         if (match?.group(1) != match?.group(2)) {
@@ -390,8 +392,8 @@ class AndroidLicenseValidator extends DoctorValidator {
 
     try {
       final Process process = await _processManager.start(
-        <String>[_androidSdk.sdkManagerPath!, '--licenses'],
-        environment: _androidSdk.sdkManagerEnv,
+        <String>[_androidSdk!.sdkManagerPath!, '--licenses'],
+        environment: _androidSdk!.sdkManagerEnv,
       );
       process.stdin.write('n\n');
       // We expect logcat streams to occasionally contain invalid utf-8,
@@ -399,13 +401,13 @@ class AndroidLicenseValidator extends DoctorValidator {
       final Future<void> output = process.stdout
         .transform<String>(const Utf8Decoder(reportErrors: false))
         .transform<String>(const LineSplitter())
-        .listen(_handleLine)
-        .asFuture<void>(null);
+        .listen(handleLine)
+        .asFuture<void>();
       final Future<void> errors = process.stderr
         .transform<String>(const Utf8Decoder(reportErrors: false))
         .transform<String>(const LineSplitter())
-        .listen(_handleLine)
-        .asFuture<void>(null);
+        .listen(handleLine)
+        .asFuture<void>();
       await Future.wait<void>(<Future<void>>[output, errors]);
       return status ?? LicensesAccepted.unknown;
     } on ProcessException catch (e) {
@@ -430,8 +432,8 @@ class AndroidLicenseValidator extends DoctorValidator {
 
     try {
       final Process process = await _processManager.start(
-        <String>[_androidSdk.sdkManagerPath!, '--licenses'],
-        environment: _androidSdk.sdkManagerEnv,
+        <String>[_androidSdk!.sdkManagerPath!, '--licenses'],
+        environment: _androidSdk!.sdkManagerEnv,
       );
 
       // The real stdin will never finish streaming. Pipe until the child process
@@ -461,7 +463,7 @@ class AndroidLicenseValidator extends DoctorValidator {
       return exitCode == 0;
     } on ProcessException catch (e) {
       throwToolExit(_userMessages.androidCannotRunSdkManager(
-        _androidSdk.sdkManagerPath ?? '',
+        _androidSdk?.sdkManagerPath ?? '',
         e.toString(),
         _platform,
       ));
@@ -469,7 +471,7 @@ class AndroidLicenseValidator extends DoctorValidator {
   }
 
   bool _canRunSdkManager() {
-    final String? sdkManagerPath = _androidSdk.sdkManagerPath;
+    final String? sdkManagerPath = _androidSdk?.sdkManagerPath;
     if (sdkManagerPath == null) {
       return false;
     }
