@@ -2,12 +2,11 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-// @dart = 2.8
-
 import 'dart:async';
 import 'dart:typed_data';
 
 import 'package:dwds/data/build_result.dart';
+// ignore: import_of_legacy_library_into_null_safe
 import 'package:dwds/dwds.dart';
 import 'package:html/dom.dart';
 import 'package:html/parser.dart';
@@ -41,25 +40,29 @@ import '../vmservice.dart';
 import '../web/bootstrap.dart';
 import '../web/chrome.dart';
 import '../web/compile.dart';
-import '../web/flutter_js.dart' as flutter_js;
+import '../web/file_generators/flutter_js.dart' as flutter_js;
 import '../web/memory_fs.dart';
+import 'sdk_web_configuration.dart';
 
 typedef DwdsLauncher = Future<Dwds> Function({
-  @required AssetReader assetReader,
-  @required Stream<BuildResult> buildResults,
-  @required ConnectionProvider chromeConnection,
-  @required LoadStrategy loadStrategy,
-  @required bool enableDebugging,
-  ExpressionCompiler expressionCompiler,
-  bool enableDebugExtension,
-  String hostname,
-  bool useSseForDebugProxy,
-  bool useSseForDebugBackend,
-  bool useSseForInjectedClient,
-  UrlEncoder urlEncoder,
-  bool spawnDds,
-  bool enableDevtoolsLaunch,
-  DevtoolsLauncher devtoolsLauncher,
+  required AssetReader assetReader,
+  required Stream<BuildResult> buildResults,
+  required ConnectionProvider chromeConnection,
+  required LoadStrategy loadStrategy,
+  required bool enableDebugging,
+  ExpressionCompiler? expressionCompiler,
+  bool? enableDebugExtension,
+  String? hostname,
+  bool? useSseForDebugProxy,
+  bool? useSseForDebugBackend,
+  bool? useSseForInjectedClient,
+  UrlEncoder? urlEncoder,
+  bool? spawnDds,
+  bool? enableDevtoolsLaunch,
+  DevtoolsLauncher? devtoolsLauncher,
+  bool? launchDevToolsInNewWindow,
+  SdkConfigurationProvider? sdkConfigurationProvider,
+  bool? emitDebugEvents,
 });
 
 // A minimal index for projects that do not yet support web.
@@ -79,11 +82,11 @@ const String _kDefaultIndex = '''
 /// This is only used in development mode.
 class WebExpressionCompiler implements ExpressionCompiler {
   WebExpressionCompiler(this._generator, {
-    @required FileSystem fileSystem,
+    required FileSystem? fileSystem,
   }) : _fileSystem = fileSystem;
 
   final ResidentCompiler _generator;
-  final FileSystem _fileSystem;
+  final FileSystem? _fileSystem;
 
   @override
   Future<ExpressionCompilationResult> compileExpressionToJs(
@@ -96,13 +99,13 @@ class WebExpressionCompiler implements ExpressionCompiler {
     String moduleName,
     String expression,
   ) async {
-    final CompilerOutput compilerOutput =
+    final CompilerOutput? compilerOutput =
         await _generator.compileExpressionToJs(libraryUri, line, column,
             jsModules, jsFrameValues, moduleName, expression);
 
     if (compilerOutput != null && compilerOutput.outputFilename != null) {
       final String content = utf8.decode(
-          _fileSystem.file(compilerOutput.outputFilename).readAsBytesSync());
+          _fileSystem!.file(compilerOutput.outputFilename).readAsBytesSync());
       return ExpressionCompilationResult(
           content, compilerOutput.errorCount > 0);
     }
@@ -113,7 +116,7 @@ class WebExpressionCompiler implements ExpressionCompiler {
   }
 
   @override
-  Future<void> initialize({String moduleFormat, bool soundNullSafety}) async {}
+  Future<void> initialize({String? moduleFormat, bool? soundNullSafety}) async {}
 
   @override
   Future<bool> updateDependencies(Map<String, ModuleInfo> modules) async => true;
@@ -176,10 +179,10 @@ class WebAssetServer implements AssetReader {
   /// Unhandled exceptions will throw a [ToolExit] with the error and stack
   /// trace.
   static Future<WebAssetServer> start(
-    ChromiumLauncher chromiumLauncher,
+    ChromiumLauncher? chromiumLauncher,
     String hostname,
-    int port,
-    UrlTunneller urlTunneller,
+    int? port,
+    UrlTunneller? urlTunneller,
     bool useSseForDebugProxy,
     bool useSseForDebugBackend,
     bool useSseForInjectedClient,
@@ -187,7 +190,7 @@ class WebAssetServer implements AssetReader {
     bool enableDwds,
     bool enableDds,
     Uri entrypoint,
-    ExpressionCompiler expressionCompiler,
+    ExpressionCompiler? expressionCompiler,
     NullSafetyMode nullSafetyMode, {
     bool testMode = false,
     DwdsLauncher dwdsLauncher = Dwds.start,
@@ -198,7 +201,7 @@ class WebAssetServer implements AssetReader {
     } else {
       address = (await InternetAddress.lookup(hostname)).first;
     }
-    HttpServer httpServer;
+    HttpServer? httpServer;
     const int kMaxRetries = 4;
     for (int i = 0; i <= kMaxRetries; i++) {
       try {
@@ -214,7 +217,7 @@ class WebAssetServer implements AssetReader {
     }
 
     // Allow rendering in a iframe.
-    httpServer.defaultResponseHeaders.remove('x-frame-options', 'SAMEORIGIN');
+    httpServer!.defaultResponseHeaders.remove('x-frame-options', 'SAMEORIGIN');
 
     final PackageConfig packageConfig = buildInfo.packageConfig;
     final Map<String, String> digests = <String, String>{};
@@ -242,7 +245,7 @@ class WebAssetServer implements AssetReader {
         basePath: server.basePath,
       );
       runZonedGuarded(() {
-        shelf.serveRequests(httpServer, releaseAssetServer.handle);
+        shelf.serveRequests(httpServer!, releaseAssetServer.handle);
       }, (Object e, StackTrace s) {
         globals.printTrace('Release asset server: error serving requests: $e:$s');
       });
@@ -251,7 +254,7 @@ class WebAssetServer implements AssetReader {
 
     // Return a version string for all active modules. This is populated
     // along with the `moduleProvider` update logic.
-    Future<Map<String, String>> _digestProvider() async => digests;
+    Future<Map<String, String>> digestProvider() async => digests;
 
     // Ensure dwds is present and provide middleware to avoid trying to
     // load the through the isolate APIs.
@@ -264,7 +267,7 @@ class WebAssetServer implements AssetReader {
           final String result =
               await globals.fs.file(uri.toFilePath()).readAsString();
           return shelf.Response.ok(result, headers: <String, String>{
-            HttpHeaders.contentTypeHeader: 'application/javascript'
+            HttpHeaders.contentTypeHeader: 'application/javascript',
           });
         }
         return innerHandler(request);
@@ -272,7 +275,7 @@ class WebAssetServer implements AssetReader {
     }
 
     logging.Logger.root.level = logging.Level.ALL;
-    logging.Logger.root.onRecord.listen(_log);
+    logging.Logger.root.onRecord.listen(log);
 
     // In debug builds, spin up DWDS and the full asset server.
     final Dwds dwds = await dwdsLauncher(
@@ -280,7 +283,7 @@ class WebAssetServer implements AssetReader {
       enableDebugExtension: true,
       buildResults: const Stream<BuildResult>.empty(),
       chromeConnection: () async {
-        final Chromium chromium = await chromiumLauncher.connectedInstance;
+        final Chromium chromium = await chromiumLauncher!.connectedInstance;
         return chromium.chromeConnection;
       },
       hostname: hostname,
@@ -292,10 +295,12 @@ class WebAssetServer implements AssetReader {
       loadStrategy: FrontendServerRequireStrategyProvider(
         ReloadConfiguration.none,
         server,
-        _digestProvider,
+        digestProvider,
+        server.basePath!,
       ).strategy,
       expressionCompiler: expressionCompiler,
       spawnDds: enableDds,
+      sdkConfigurationProvider: SdkWebConfigurationProvider(globals.artifacts!),
     );
     shelf.Pipeline pipeline = const shelf.Pipeline();
     if (enableDwds) {
@@ -307,42 +312,42 @@ class WebAssetServer implements AssetReader {
     final shelf.Cascade cascade =
         shelf.Cascade().add(dwds.handler).add(dwdsHandler);
     runZonedGuarded(() {
-      shelf.serveRequests(httpServer, cascade.handler);
+      shelf.serveRequests(httpServer!, cascade.handler);
     }, (Object e, StackTrace s) {
       globals.printTrace('Dwds server: error serving requests: $e:$s');
     });
     server.dwds = dwds;
+    server._dwdsInit = true;
     return server;
   }
 
   final NullSafetyMode _nullSafetyMode;
   final HttpServer _httpServer;
   final WebMemoryFS _webMemoryFS = WebMemoryFS();
-
-
   final PackageConfig _packages;
   final InternetAddress internetAddress;
-  /* late final */ Dwds dwds;
-  Directory entrypointCacheDirectory;
+  late final Dwds dwds;
+  late Directory entrypointCacheDirectory;
+  bool _dwdsInit = false;
 
   @visibleForTesting
   HttpHeaders get defaultResponseHeaders => _httpServer.defaultResponseHeaders;
 
   @visibleForTesting
-  Uint8List getFile(String path) => _webMemoryFS.files[path];
+  Uint8List? getFile(String path) => _webMemoryFS.files[path];
 
   @visibleForTesting
-  Uint8List getSourceMap(String path) => _webMemoryFS.sourcemaps[path];
+  Uint8List? getSourceMap(String path) => _webMemoryFS.sourcemaps[path];
 
   @visibleForTesting
-  Uint8List getMetadata(String path) => _webMemoryFS.metadataFiles[path];
+  Uint8List? getMetadata(String path) => _webMemoryFS.metadataFiles[path];
 
   @visibleForTesting
 
   /// The base path to serve from.
   ///
   /// It should have no leading or trailing slashes.
-  String basePath = '';
+  String? basePath = '';
 
   // handle requests for JavaScript source, dart sources maps, or asset files.
   @visibleForTesting
@@ -352,7 +357,7 @@ class WebAssetServer implements AssetReader {
       return shelf.Response.notFound('');
     }
 
-    final String requestPath = _stripBasePath(request.url.path, basePath);
+    final String? requestPath = _stripBasePath(request.url.path, basePath);
 
     if (requestPath == null) {
       return shelf.Response.notFound('');
@@ -366,7 +371,7 @@ class WebAssetServer implements AssetReader {
     final Map<String, String> headers = <String, String>{};
 
     // Track etag headers for better caching of resources.
-    final String ifNoneMatch = request.headers[HttpHeaders.ifNoneMatchHeader];
+    final String? ifNoneMatch = request.headers[HttpHeaders.ifNoneMatchHeader];
     headers[HttpHeaders.cacheControlHeader] = 'max-age=0, must-revalidate';
 
     // If this is a JavaScript file, it must be in the in-memory cache.
@@ -374,7 +379,7 @@ class WebAssetServer implements AssetReader {
     final String webServerPath =
         requestPath.replaceFirst('.dart.js', '.dart.lib.js');
     if (_webMemoryFS.files.containsKey(requestPath) || _webMemoryFS.files.containsKey(webServerPath)) {
-      final List<int> bytes = getFile(requestPath) ?? getFile(webServerPath);
+      final List<int>? bytes = getFile(requestPath) ?? getFile(webServerPath);
       // Use the underlying buffer hashCode as a revision string. This buffer is
       // replaced whenever the frontend_server produces new output files, which
       // will also change the hashCode.
@@ -382,7 +387,7 @@ class WebAssetServer implements AssetReader {
       if (ifNoneMatch == etag) {
         return shelf.Response.notModified();
       }
-      headers[HttpHeaders.contentLengthHeader] = bytes.length.toString();
+      headers[HttpHeaders.contentLengthHeader] = bytes!.length.toString();
       headers[HttpHeaders.contentTypeHeader] = 'application/javascript';
       headers[HttpHeaders.etagHeader] = etag;
       return shelf.Response.ok(bytes, headers: headers);
@@ -390,12 +395,12 @@ class WebAssetServer implements AssetReader {
     // If this is a sourcemap file, then it might be in the in-memory cache.
     // Attempt to lookup the file by URI.
     if (_webMemoryFS.sourcemaps.containsKey(requestPath)) {
-      final List<int> bytes = getSourceMap(requestPath);
+      final List<int>? bytes = getSourceMap(requestPath);
       final String etag = bytes.hashCode.toString();
       if (ifNoneMatch == etag) {
         return shelf.Response.notModified();
       }
-      headers[HttpHeaders.contentLengthHeader] = bytes.length.toString();
+      headers[HttpHeaders.contentLengthHeader] = bytes!.length.toString();
       headers[HttpHeaders.contentTypeHeader] = 'application/json';
       headers[HttpHeaders.etagHeader] = etag;
       return shelf.Response.ok(bytes, headers: headers);
@@ -404,12 +409,12 @@ class WebAssetServer implements AssetReader {
     // If this is a metadata file, then it might be in the in-memory cache.
     // Attempt to lookup the file by URI.
     if (_webMemoryFS.metadataFiles.containsKey(requestPath)) {
-      final List<int> bytes = getMetadata(requestPath);
+      final List<int>? bytes = getMetadata(requestPath);
       final String etag = bytes.hashCode.toString();
       if (ifNoneMatch == etag) {
         return shelf.Response.notModified();
       }
-      headers[HttpHeaders.contentLengthHeader] = bytes.length.toString();
+      headers[HttpHeaders.contentLengthHeader] = bytes!.length.toString();
       headers[HttpHeaders.contentTypeHeader] = 'application/json';
       headers[HttpHeaders.etagHeader] = etag;
       return shelf.Response.ok(bytes, headers: headers);
@@ -469,7 +474,9 @@ class WebAssetServer implements AssetReader {
 
   /// Tear down the http server running.
   Future<void> dispose() async {
-    await dwds?.stop();
+    if (_dwdsInit) {
+      await dwds.stop();
+    }
     return _httpServer.close();
   }
 
@@ -540,7 +547,7 @@ class WebAssetServer implements AssetReader {
     // The file might have been a package file which is signaled by a
     // `/packages/<package>/<path>` request.
     if (segments.first == 'packages') {
-      final Uri filePath = _packages
+      final Uri? filePath = _packages
           .resolve(Uri(scheme: 'package', pathSegments: segments.skip(1)));
       if (filePath != null) {
         final File packageFile = globals.fs.file(filePath);
@@ -553,7 +560,7 @@ class WebAssetServer implements AssetReader {
     // Otherwise it must be a Dart SDK source or a Flutter Web SDK source.
     final Directory dartSdkParent = globals.fs
         .directory(
-            globals.artifacts.getHostArtifact(HostArtifact.engineDartSdkPath))
+            globals.artifacts!.getHostArtifact(HostArtifact.engineDartSdkPath))
         .parent;
     final File dartSdkFile = globals.fs.file(dartSdkParent.uri.resolve(path));
     if (dartSdkFile.existsSync()) {
@@ -561,25 +568,25 @@ class WebAssetServer implements AssetReader {
     }
 
     final Directory flutterWebSdk = globals.fs
-        .directory(globals.artifacts.getHostArtifact(HostArtifact.flutterWebSdk));
+        .directory(globals.artifacts!.getHostArtifact(HostArtifact.flutterWebSdk));
     final File webSdkFile = globals.fs.file(flutterWebSdk.uri.resolve(path));
 
     return webSdkFile;
   }
 
   File get _resolveDartSdkJsFile =>
-      globals.fs.file(globals.artifacts.getHostArtifact(
-          kDartSdkJsArtifactMap[webRenderer][_nullSafetyMode]
+      globals.fs.file(globals.artifacts!.getHostArtifact(
+          kDartSdkJsArtifactMap[webRenderer]![_nullSafetyMode]!
       ));
 
   File get _resolveDartSdkJsMapFile =>
-    globals.fs.file(globals.artifacts.getHostArtifact(
-        kDartSdkJsMapArtifactMap[webRenderer][_nullSafetyMode]
+    globals.fs.file(globals.artifacts!.getHostArtifact(
+        kDartSdkJsMapArtifactMap[webRenderer]![_nullSafetyMode]!
     ));
 
   @override
-  Future<String> dartSourceContents(String serverPath) async {
-    serverPath = _stripBasePath(serverPath, basePath);
+  Future<String?> dartSourceContents(String serverPath) async {
+    serverPath = _stripBasePath(serverPath, basePath)!;
     final File result = _resolveDartFile(serverPath);
     if (result.existsSync()) {
       return result.readAsString();
@@ -589,18 +596,18 @@ class WebAssetServer implements AssetReader {
 
   @override
   Future<String> sourceMapContents(String serverPath) async {
-    serverPath = _stripBasePath(serverPath, basePath);
-    return utf8.decode(_webMemoryFS.sourcemaps[serverPath]);
+    serverPath = _stripBasePath(serverPath, basePath)!;
+    return utf8.decode(_webMemoryFS.sourcemaps[serverPath]!);
   }
 
   @override
-  Future<String> metadataContents(String serverPath) async {
-    serverPath = _stripBasePath(serverPath, basePath);
-    if (serverPath == 'main_module.ddc_merged_metadata') {
+  Future<String?> metadataContents(String serverPath) async {
+    final String? resultPath = _stripBasePath(serverPath, basePath);
+    if (resultPath == 'main_module.ddc_merged_metadata') {
       return _webMemoryFS.mergedMetadata;
     }
-    if (_webMemoryFS.metadataFiles.containsKey(serverPath)) {
-      return utf8.decode(_webMemoryFS.metadataFiles[serverPath]);
+    if (_webMemoryFS.metadataFiles.containsKey(resultPath)) {
+      return utf8.decode(_webMemoryFS.metadataFiles[resultPath]!);
     }
     throw Exception('Could not find metadata contents for $serverPath');
   }
@@ -612,8 +619,8 @@ class WebAssetServer implements AssetReader {
 class ConnectionResult {
   ConnectionResult(this.appConnection, this.debugConnection, this.vmService);
 
-  final AppConnection appConnection;
-  final DebugConnection debugConnection;
+  final AppConnection? appConnection;
+  final DebugConnection? debugConnection;
   final vm_service.VmService vmService;
 }
 
@@ -624,29 +631,29 @@ class WebDevFS implements DevFS {
   /// [testMode] is true, do not actually initialize dwds or the shelf static
   /// server.
   WebDevFS({
-    @required this.hostname,
-    @required int port,
-    @required this.packagesFilePath,
-    @required this.urlTunneller,
-    @required this.useSseForDebugProxy,
-    @required this.useSseForDebugBackend,
-    @required this.useSseForInjectedClient,
-    @required this.buildInfo,
-    @required this.enableDwds,
-    @required this.enableDds,
-    @required this.entrypoint,
-    @required this.expressionCompiler,
-    @required this.chromiumLauncher,
-    @required this.nullAssertions,
-    @required this.nativeNullAssertions,
-    @required this.nullSafetyMode,
+    required this.hostname,
+    required int? port,
+    required this.packagesFilePath,
+    required this.urlTunneller,
+    required this.useSseForDebugProxy,
+    required this.useSseForDebugBackend,
+    required this.useSseForInjectedClient,
+    required this.buildInfo,
+    required this.enableDwds,
+    required this.enableDds,
+    required this.entrypoint,
+    required this.expressionCompiler,
+    required this.chromiumLauncher,
+    required this.nullAssertions,
+    required this.nativeNullAssertions,
+    required this.nullSafetyMode,
     this.testMode = false,
   }) : _port = port;
 
   final Uri entrypoint;
   final String hostname;
   final String packagesFilePath;
-  final UrlTunneller urlTunneller;
+  final UrlTunneller? urlTunneller;
   final bool useSseForDebugProxy;
   final bool useSseForDebugBackend;
   final bool useSseForInjectedClient;
@@ -654,14 +661,14 @@ class WebDevFS implements DevFS {
   final bool enableDwds;
   final bool enableDds;
   final bool testMode;
-  final ExpressionCompiler expressionCompiler;
-  final ChromiumLauncher chromiumLauncher;
+  final ExpressionCompiler? expressionCompiler;
+  final ChromiumLauncher? chromiumLauncher;
   final bool nullAssertions;
   final bool nativeNullAssertions;
-  final int _port;
+  final int? _port;
   final NullSafetyMode nullSafetyMode;
 
-  WebAssetServer webAssetServer;
+  late WebAssetServer webAssetServer;
 
   Dwds get dwds => webAssetServer.dwds;
 
@@ -669,13 +676,13 @@ class WebDevFS implements DevFS {
   @override
   bool hasSetAssetDirectory = false;
 
-  Future<DebugConnection> _cachedExtensionFuture;
-  StreamSubscription<void> _connectedApps;
+  Future<DebugConnection>? _cachedExtensionFuture;
+  StreamSubscription<void>? _connectedApps;
 
   /// Connect and retrieve the [DebugConnection] for the current application.
   ///
   /// Only calls [AppConnection.runMain] on the subsequent connections.
-  Future<ConnectionResult> connect(bool useDebugExtension) {
+  Future<ConnectionResult?> connect(bool useDebugExtension) {
     final Completer<ConnectionResult> firstConnection =
         Completer<ConnectionResult>();
     _connectedApps =
@@ -700,7 +707,7 @@ class WebDevFS implements DevFS {
           firstConnection.completeError(error, stackTrace);
         }
       }
-    }, onError: (dynamic error, StackTrace stackTrace) {
+    }, onError: (Object error, StackTrace stackTrace) {
       globals.printError(
           'Unknown error while waiting for debug connection:$error\n$stackTrace');
       if (!firstConnection.isCompleted) {
@@ -714,18 +721,18 @@ class WebDevFS implements DevFS {
   List<Uri> sources = <Uri>[];
 
   @override
-  DateTime lastCompiled;
+  DateTime? lastCompiled;
 
   @override
-  PackageConfig lastPackageConfig;
+  PackageConfig? lastPackageConfig;
 
   // We do not evict assets on the web.
   @override
   Set<String> get assetPathsToEvict => const <String>{};
 
   @override
-  Uri get baseUri => _baseUri;
-  Uri _baseUri;
+  Uri? get baseUri => _baseUri;
+  Uri? _baseUri;
 
   @override
   Future<Uri> create() async {
@@ -752,11 +759,11 @@ class WebDevFS implements DevFS {
       webAssetServer.webRenderer = WebRendererMode.canvaskit;
     }
     if (hostname == 'any') {
-      _baseUri = Uri.http('localhost:$selectedPort', webAssetServer.basePath);
+      _baseUri = Uri.http('localhost:$selectedPort', webAssetServer.basePath!);
     } else {
-      _baseUri = Uri.http('$hostname:$selectedPort', webAssetServer.basePath);
+      _baseUri = Uri.http('$hostname:$selectedPort', webAssetServer.basePath!);
     }
-    return _baseUri;
+    return _baseUri!;
   }
 
   @override
@@ -774,24 +781,24 @@ class WebDevFS implements DevFS {
   String get fsName => 'web_asset';
 
   @override
-  Directory get rootDirectory => null;
+  Directory? get rootDirectory => null;
 
   @override
   Future<UpdateFSReport> update({
-    @required Uri mainUri,
-    @required ResidentCompiler generator,
-    @required bool trackWidgetCreation,
-    @required String pathToReload,
-    @required List<Uri> invalidatedFiles,
-    @required PackageConfig packageConfig,
-    @required String dillOutputPath,
-    DevFSWriter devFSWriter,
-    String target,
-    AssetBundle bundle,
-    DateTime firstBuildTime,
+    required Uri mainUri,
+    required ResidentCompiler generator,
+    required bool trackWidgetCreation,
+    required String pathToReload,
+    required List<Uri> invalidatedFiles,
+    required PackageConfig packageConfig,
+    required String dillOutputPath,
+    DevFSWriter? devFSWriter,
+    String? target,
+    AssetBundle? bundle,
+    DateTime? firstBuildTime,
     bool bundleFirstUpload = false,
     bool fullRestart = false,
-    String projectRootPath,
+    String? projectRootPath,
   }) async {
     assert(trackWidgetCreation != null);
     assert(generator != null);
@@ -836,6 +843,7 @@ class WebDevFS implements DevFS {
         await writeBundle(
           globals.fs.directory(getAssetBuildDirectory()),
           bundle.entries,
+          bundle.entryKinds,
         );
       }
     }
@@ -848,7 +856,7 @@ class WebDevFS implements DevFS {
     // the web specific bootstrap logic. To make it easier for DWDS to handle
     // mapping the file name, this is done via an additional file root and
     // special hard-coded scheme.
-    final CompilerOutput compilerOutput = await generator.recompile(
+    final CompilerOutput? compilerOutput = await generator.recompile(
       Uri(
         scheme: 'org-dartlang-app',
         path: '/${mainUri.pathSegments.last}',
@@ -867,11 +875,11 @@ class WebDevFS implements DevFS {
     lastCompiled = candidateCompileTime;
     // list of sources that needs to be monitored are in [compilerOutput.sources]
     sources = compilerOutput.sources;
-    File codeFile;
+    late File codeFile;
     File manifestFile;
     File sourcemapFile;
     File metadataFile;
-    List<String> modules;
+    late List<String> modules;
     try {
       final Directory parentDirectory = globals.fs.directory(outputDirectoryPath);
       codeFile = parentDirectory.childFile('${compilerOutput.outputFilename}.sources');
@@ -892,7 +900,7 @@ class WebDevFS implements DevFS {
 
   @visibleForTesting
   final File requireJS = globals.fs.file(globals.fs.path.join(
-    globals.artifacts.getHostArtifact(HostArtifact.engineDartSdkPath).path,
+    globals.artifacts!.getHostArtifact(HostArtifact.engineDartSdkPath).path,
     'lib',
     'dev_compiler',
     'kernel',
@@ -902,7 +910,7 @@ class WebDevFS implements DevFS {
 
   @visibleForTesting
   final File stackTraceMapper = globals.fs.file(globals.fs.path.join(
-    globals.artifacts.getHostArtifact(HostArtifact.engineDartSdkPath).path,
+    globals.artifacts!.getHostArtifact(HostArtifact.engineDartSdkPath).path,
     'lib',
     'dev_compiler',
     'web',
@@ -918,10 +926,10 @@ class WebDevFS implements DevFS {
 class ReleaseAssetServer {
   ReleaseAssetServer(
     this.entrypoint, {
-    @required FileSystem fileSystem,
-    @required String webBuildDirectory,
-    @required String flutterRoot,
-    @required Platform platform,
+    required FileSystem fileSystem,
+    required String? webBuildDirectory,
+    required String? flutterRoot,
+    required Platform platform,
     this.basePath = '',
   })  : _fileSystem = fileSystem,
         _platform = platform,
@@ -931,8 +939,8 @@ class ReleaseAssetServer {
             FileSystemUtils(fileSystem: fileSystem, platform: platform);
 
   final Uri entrypoint;
-  final String _flutterRoot;
-  final String _webBuildDirectory;
+  final String? _flutterRoot;
+  final String? _webBuildDirectory;
   final FileSystem _fileSystem;
   final FileSystemUtils _fileSystemUtils;
   final Platform _platform;
@@ -942,7 +950,7 @@ class ReleaseAssetServer {
   /// The base path to serve from.
   ///
   /// It should have no leading or trailing slashes.
-  final String basePath;
+  final String? basePath;
 
   // Locations where source files, assets, or source maps may be located.
   List<Uri> _searchPaths() => <Uri>[
@@ -959,8 +967,8 @@ class ReleaseAssetServer {
       return shelf.Response.notFound('');
     }
 
-    Uri fileUri;
-    final String requestPath = _stripBasePath(request.url.path, basePath);
+    Uri? fileUri;
+    final String? requestPath = _stripBasePath(request.url.path, basePath);
 
     if (requestPath == null) {
       return shelf.Response.notFound('');
@@ -994,28 +1002,19 @@ class ReleaseAssetServer {
     }
 
     final File file = _fileSystem
-        .file(_fileSystem.path.join(_webBuildDirectory, 'index.html'));
+        .file(_fileSystem.path.join(_webBuildDirectory!, 'index.html'));
     return shelf.Response.ok(file.readAsBytesSync(), headers: <String, String>{
       'Content-Type': 'text/html',
     });
   }
 }
 
-void _log(logging.LogRecord event) {
+@visibleForTesting
+void log(logging.LogRecord event) {
   final String error = event.error == null? '': 'Error: ${event.error}';
   if (event.level >= logging.Level.SEVERE) {
     globals.printError('${event.loggerName}: ${event.message}$error', stackTrace: event.stackTrace);
   } else if (event.level == logging.Level.WARNING) {
-    // TODO(elliette): Remove the following message suppressions after DWDS is
-    // >13.1.0, https://github.com/flutter/flutter/issues/101639
-    const String dartUri = 'DartUri';
-    if (event.loggerName == dartUri) {
-      const String webSqlWarning = 'Unresolved uri: dart:web_sql';
-      const String uiWarning = 'Unresolved uri: dart:ui';
-      if (event.message == webSqlWarning || event.message == uiWarning) {
-        return;
-      }
-    }
     globals.printWarning('${event.loggerName}: ${event.message}$error');
   } else  {
     globals.printTrace('${event.loggerName}: ${event.message}$error');
@@ -1025,19 +1024,19 @@ void _log(logging.LogRecord event) {
 Future<Directory> _loadDwdsDirectory(
     FileSystem fileSystem, Logger logger) async {
   final String toolPackagePath =
-      fileSystem.path.join(Cache.flutterRoot, 'packages', 'flutter_tools');
+      fileSystem.path.join(Cache.flutterRoot!, 'packages', 'flutter_tools');
   final String packageFilePath =
       fileSystem.path.join(toolPackagePath, '.dart_tool', 'package_config.json');
   final PackageConfig packageConfig = await loadPackageConfigWithLogging(
     fileSystem.file(packageFilePath),
     logger: logger,
   );
-  return fileSystem.directory(packageConfig['dwds'].packageUriRoot);
+  return fileSystem.directory(packageConfig['dwds']!.packageUriRoot);
 }
 
-String _stripBasePath(String path, String basePath) {
+String? _stripBasePath(String path, String? basePath) {
   path = _stripLeadingSlashes(path);
-  if (path.startsWith(basePath)) {
+  if (basePath != null && path.startsWith(basePath)) {
     path = path.substring(basePath.length);
   } else {
     // The given path isn't under base path, return null to indicate that.
@@ -1060,25 +1059,25 @@ String _stripTrailingSlashes(String path) {
   return path;
 }
 
-String _parseBasePathFromIndexHtml(File indexHtml) {
+String? _parseBasePathFromIndexHtml(File indexHtml) {
   final String htmlContent =
       indexHtml.existsSync() ? indexHtml.readAsStringSync() : _kDefaultIndex;
   final Document document = parse(htmlContent);
-  final Element baseElement = document.querySelector('base');
-  String baseHref =
-      baseElement?.attributes == null ? null : baseElement.attributes['href'];
+  final Element? baseElement = document.querySelector('base');
+  String? baseHref =
+      baseElement?.attributes == null ? null : baseElement!.attributes['href'];
 
   if (baseHref == null || baseHref == kBaseHrefPlaceholder) {
     baseHref = '';
   } else if (!baseHref.startsWith('/')) {
     throw ToolExit(
       'Error: The base href in "web/index.html" must be absolute (i.e. start '
-      'with a "/"), but found: `${baseElement.outerHtml}`.\n'
+      'with a "/"), but found: `${baseElement!.outerHtml}`.\n'
       '$basePathExample',
     );
   } else if (!baseHref.endsWith('/')) {
     throw ToolExit(
-      'Error: The base href in "web/index.html" must end with a "/", but found: `${baseElement.outerHtml}`.\n'
+      'Error: The base href in "web/index.html" must end with a "/", but found: `${baseElement!.outerHtml}`.\n'
       '$basePathExample',
     );
   } else {
