@@ -23,6 +23,7 @@ const String kRunInViewMethod = '_flutter.runInView';
 const String kListViewsMethod = '_flutter.listViews';
 const String kScreenshotSkpMethod = '_flutter.screenshotSkp';
 const String kScreenshotMethod = '_flutter.screenshot';
+const String kRenderFrameWithRasterStatsMethod = '_flutter.renderFrameWithRasterStats';
 
 /// The error response code from an unrecoverable compilation failure.
 const int kIsolateReloadBarred = 1005;
@@ -98,7 +99,7 @@ typedef CompileExpression = Future<String> Function(
 /// A method that pulls an SkSL shader from the device and writes it to a file.
 ///
 /// The name of the file returned as a result.
-typedef GetSkSLMethod = Future<String> Function();
+typedef GetSkSLMethod = Future<String?> Function();
 
 Future<io.WebSocket> _defaultOpenChannel(String url, {
   io.CompressionOptions compression = io.CompressionOptions.compressionDefault,
@@ -197,7 +198,7 @@ Future<vm_service.VmService> setUpVmService(
       return <String, Object>{
         'result': <String, Object>{
           'type': 'Success',
-        }
+        },
       };
     });
     registrationRequests.add(vmService.registerService('reloadSources', 'Flutter Tools'));
@@ -210,7 +211,7 @@ Future<vm_service.VmService> setUpVmService(
       return <String, Object>{
         'result': <String, Object>{
           'type': 'Success',
-        }
+        },
       };
     });
     registrationRequests.add(vmService.registerService('hotRestart', 'Flutter Tools'));
@@ -225,7 +226,7 @@ Future<vm_service.VmService> setUpVmService(
       'result': <String, Object>{
         'type': 'Success',
         ...versionJson,
-      }
+      },
     };
   });
   registrationRequests.add(vmService.registerService('flutterVersion', 'Flutter Tools'));
@@ -257,19 +258,26 @@ Future<vm_service.VmService> setUpVmService(
         'result': <String, Object>{
           'type': 'Success',
           ...result.toJson(),
-        }
+        },
       };
     });
     registrationRequests.add(vmService.registerService('flutterMemoryInfo', 'Flutter Tools'));
   }
   if (skSLMethod != null) {
     vmService.registerServiceCallback('flutterGetSkSL', (Map<String, Object?> params) async {
-      final String filename = await skSLMethod();
+      final String? filename = await skSLMethod();
+      if (filename == null) {
+        return <String, Object>{
+          'result': <String, Object>{
+            'type': 'Success',
+          },
+        };
+      }
       return <String, Object>{
         'result': <String, Object>{
           'type': 'Success',
           'filename': filename,
-        }
+        },
       };
     });
     registrationRequests.add(vmService.registerService('flutterGetSkSL', 'Flutter Tools'));
@@ -280,6 +288,9 @@ Future<vm_service.VmService> setUpVmService(
     // thrown if we're already subscribed.
     registrationRequests.add(vmService
       .streamListen(vm_service.EventStreams.kExtension)
+      // TODO(srawlins): Fix this static issue,
+      // https://github.com/flutter/flutter/issues/105750.
+      // ignore: body_might_complete_normally_catch_error
       .catchError((Object? error) {}, test: (Object? error) => error is vm_service.RPCError)
     );
   }
@@ -538,6 +549,26 @@ class FlutterVmService {
     await onRunnable;
   }
 
+  /// Renders the last frame with additional raster tracing enabled.
+  ///
+  /// When a frame is rendered using this method it will incur additional cost
+  /// for rasterization which is not reflective of how long the frame takes in
+  /// production. This is primarily intended to be used to identify the layers
+  /// that result in the most raster perf degradation.
+  Future<Map<String, Object>?> renderFrameWithRasterStats({
+    required String? viewId,
+    required String? uiIsolateId,
+  }) async {
+    final vm_service.Response? response = await callMethodWrapper(
+      kRenderFrameWithRasterStatsMethod,
+      isolateId: uiIsolateId,
+      args: <String, String?>{
+        'viewId': viewId,
+      },
+    );
+    return response?.json as Map<String, Object>?;
+  }
+
   Future<String> flutterDebugDumpApp({
     required String isolateId,
   }) async {
@@ -826,7 +857,7 @@ class FlutterVmService {
       final List<FlutterView> views = <FlutterView>[
         if (rawViews != null)
           for (final Map<String, Object?> rawView in rawViews.whereType<Map<String, Object?>>())
-            FlutterView.parse(rawView)
+            FlutterView.parse(rawView),
       ];
       if (views.isNotEmpty || returnEarly) {
         return views;
