@@ -28,7 +28,7 @@ const FakeCommand kARMCheckCommand = FakeCommand(
 );
 
 const List<String> kDefaultClang = <String>[
-  '-miphoneos-version-min=9.0',
+  '-miphoneos-version-min=11.0',
   '-isysroot',
   'path/to/sdk',
   '-dynamiclib',
@@ -76,7 +76,7 @@ void main() {
         FakeCommand(
           command: <String>[
             artifacts.getArtifactPath(Artifact.genSnapshot, platform: TargetPlatform.android_x64, mode: BuildMode.release),
-            '--additional_arg'
+            '--additional_arg',
           ],
         ),
       );
@@ -88,24 +88,6 @@ void main() {
       expect(result, 0);
     });
 
-    testWithoutContext('iOS armv7', () async {
-      processManager.addCommand(
-        FakeCommand(
-          command: <String>[
-            '${artifacts.getArtifactPath(Artifact.genSnapshot, platform: TargetPlatform.ios, mode: BuildMode.release)}_armv7',
-            '--additional_arg'
-          ],
-        ),
-      );
-
-      final int result = await genSnapshot.run(
-        snapshotType: SnapshotType(TargetPlatform.ios, BuildMode.release),
-        darwinArch: DarwinArch.armv7,
-        additionalArgs: <String>['--additional_arg'],
-      );
-      expect(result, 0);
-    });
-
     testWithoutContext('iOS arm64', () async {
       final String genSnapshotPath = artifacts.getArtifactPath(
         Artifact.genSnapshot,
@@ -224,13 +206,11 @@ void main() {
       );
       processManager.addCommands(<FakeCommand>[
         FakeCommand(command: <String>[
-          '${genSnapshotPath}_armv7',
+          '${genSnapshotPath}_arm64',
           '--deterministic',
           '--snapshot_kind=app-aot-assembly',
           '--assembly=$assembly',
           '--strip',
-          '--no-sim-use-hardfp',
-          '--no-use-integer-division',
           'main.dill',
         ]),
         kWhichSysctlCommand,
@@ -239,8 +219,8 @@ void main() {
           'xcrun',
           'cc',
           '-arch',
-          'armv7',
-          '-miphoneos-version-min=9.0',
+          'arm64',
+          '-miphoneos-version-min=11.0',
           '-isysroot',
           'path/to/sdk',
           '-fembed-bitcode',
@@ -253,8 +233,8 @@ void main() {
           'xcrun',
           'clang',
           '-arch',
-          'armv7',
-          '-miphoneos-version-min=9.0',
+          'arm64',
+          '-miphoneos-version-min=11.0',
           '-isysroot',
           'path/to/sdk',
           '-dynamiclib',
@@ -280,7 +260,7 @@ void main() {
         buildMode: BuildMode.profile,
         mainPath: 'main.dill',
         outputPath: outputPath,
-        darwinArch: DarwinArch.armv7,
+        darwinArch: DarwinArch.arm64,
         sdkRoot: 'path/to/sdk',
         bitcode: true,
         dartObfuscation: false,
@@ -290,10 +270,10 @@ void main() {
       expect(processManager, hasNoRemainingExpectations);
     });
 
-    testWithoutContext('builds iOS armv7 snapshot with dwarStackTraces', () async {
+    testWithoutContext('builds iOS snapshot with dwarfStackTraces', () async {
       final String outputPath = fileSystem.path.join('build', 'foo');
       final String assembly = fileSystem.path.join(outputPath, 'snapshot_assembly.S');
-      final String debugPath = fileSystem.path.join('foo', 'app.ios-armv7.symbols');
+      final String debugPath = fileSystem.path.join('foo', 'app.ios-arm64.symbols');
       final String genSnapshotPath = artifacts.getArtifactPath(
         Artifact.genSnapshot,
         platform: TargetPlatform.ios,
@@ -301,13 +281,11 @@ void main() {
       );
       processManager.addCommands(<FakeCommand>[
         FakeCommand(command: <String>[
-          '${genSnapshotPath}_armv7',
+          '${genSnapshotPath}_arm64',
           '--deterministic',
           '--snapshot_kind=app-aot-assembly',
           '--assembly=$assembly',
           '--strip',
-          '--no-sim-use-hardfp',
-          '--no-use-integer-division',
           '--dwarf-stack-traces',
           '--save-debugging-info=$debugPath',
           'main.dill',
@@ -318,8 +296,8 @@ void main() {
           'xcrun',
           'cc',
           '-arch',
-          'armv7',
-          '-miphoneos-version-min=9.0',
+          'arm64',
+          '-miphoneos-version-min=11.0',
           '-isysroot',
           'path/to/sdk',
           '-c',
@@ -331,7 +309,7 @@ void main() {
           'xcrun',
           'clang',
           '-arch',
-          'armv7',
+          'arm64',
           ...kDefaultClang,
         ]),
       ]);
@@ -341,7 +319,7 @@ void main() {
         buildMode: BuildMode.profile,
         mainPath: 'main.dill',
         outputPath: outputPath,
-        darwinArch: DarwinArch.armv7,
+        darwinArch: DarwinArch.arm64,
         sdkRoot: 'path/to/sdk',
         bitcode: false,
         splitDebugInfo: 'foo',
@@ -352,7 +330,7 @@ void main() {
       expect(processManager, hasNoRemainingExpectations);
     });
 
-    testWithoutContext('builds iOS armv7 snapshot with obfuscate', () async {
+    testWithoutContext('builds iOS snapshot with obfuscate', () async {
       final String outputPath = fileSystem.path.join('build', 'foo');
       final String assembly = fileSystem.path.join(outputPath, 'snapshot_assembly.S');
       final String genSnapshotPath = artifacts.getArtifactPath(
@@ -362,13 +340,11 @@ void main() {
       );
       processManager.addCommands(<FakeCommand>[
         FakeCommand(command: <String>[
-          '${genSnapshotPath}_armv7',
+          '${genSnapshotPath}_arm64',
           '--deterministic',
           '--snapshot_kind=app-aot-assembly',
           '--assembly=$assembly',
           '--strip',
-          '--no-sim-use-hardfp',
-          '--no-use-integer-division',
           '--obfuscate',
           'main.dill',
         ]),
@@ -378,8 +354,8 @@ void main() {
           'xcrun',
           'cc',
           '-arch',
-          'armv7',
-          '-miphoneos-version-min=9.0',
+          'arm64',
+          '-miphoneos-version-min=11.0',
           '-isysroot',
           'path/to/sdk',
           '-c',
@@ -391,7 +367,7 @@ void main() {
           'xcrun',
           'clang',
           '-arch',
-          'armv7',
+          'arm64',
           ...kDefaultClang,
         ]),
       ]);
@@ -401,7 +377,7 @@ void main() {
         buildMode: BuildMode.profile,
         mainPath: 'main.dill',
         outputPath: outputPath,
-        darwinArch: DarwinArch.armv7,
+        darwinArch: DarwinArch.arm64,
         sdkRoot: 'path/to/sdk',
         bitcode: false,
         dartObfuscation: true,
@@ -411,64 +387,7 @@ void main() {
       expect(processManager, hasNoRemainingExpectations);
     });
 
-    testWithoutContext('builds iOS armv7 snapshot', () async {
-      final String outputPath = fileSystem.path.join('build', 'foo');
-      final String genSnapshotPath = artifacts.getArtifactPath(
-        Artifact.genSnapshot,
-        platform: TargetPlatform.ios,
-        mode: BuildMode.release,
-      );
-      processManager.addCommands(<FakeCommand>[
-        FakeCommand(command: <String>[
-          '${genSnapshotPath}_armv7',
-          '--deterministic',
-          '--snapshot_kind=app-aot-assembly',
-          '--assembly=${fileSystem.path.join(outputPath, 'snapshot_assembly.S')}',
-          '--strip',
-          '--no-sim-use-hardfp',
-          '--no-use-integer-division',
-          'main.dill',
-        ]),
-        kWhichSysctlCommand,
-        kARMCheckCommand,
-        const FakeCommand(command: <String>[
-          'xcrun',
-          'cc',
-          '-arch',
-          'armv7',
-          '-miphoneos-version-min=9.0',
-          '-isysroot',
-          'path/to/sdk',
-          '-c',
-          'build/foo/snapshot_assembly.S',
-          '-o',
-          'build/foo/snapshot_assembly.o',
-        ]),
-        const FakeCommand(command: <String>[
-          'xcrun',
-          'clang',
-          '-arch',
-          'armv7',
-          ...kDefaultClang,
-        ]),
-      ]);
-
-      final int genSnapshotExitCode = await snapshotter.build(
-        platform: TargetPlatform.ios,
-        buildMode: BuildMode.release,
-        mainPath: 'main.dill',
-        outputPath: outputPath,
-        darwinArch: DarwinArch.armv7,
-        sdkRoot: 'path/to/sdk',
-        bitcode: false,
-        dartObfuscation: false,
-      );
-
-      expect(genSnapshotExitCode, 0);
-      expect(processManager, hasNoRemainingExpectations);
-    });
-
-    testWithoutContext('builds iOS arm64 snapshot', () async {
+    testWithoutContext('builds iOS snapshot', () async {
       final String outputPath = fileSystem.path.join('build', 'foo');
       final String genSnapshotPath = artifacts.getArtifactPath(
         Artifact.genSnapshot,
@@ -491,7 +410,7 @@ void main() {
           'cc',
           '-arch',
           'arm64',
-          '-miphoneos-version-min=9.0',
+          '-miphoneos-version-min=11.0',
           '-isysroot',
           'path/to/sdk',
           '-c',
