@@ -2,8 +2,6 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-// @dart = 2.8
-
 import 'package:file/memory.dart';
 import 'package:flutter_tools/src/artifacts.dart';
 import 'package:flutter_tools/src/base/file_system.dart';
@@ -26,12 +24,12 @@ const String kAssemblyAot = '--snapshot_kind=app-aot-assembly';
 
 final Platform macPlatform = FakePlatform(operatingSystem: 'macos', environment: <String, String>{});
 void main() {
-  FakeProcessManager processManager;
-  Environment androidEnvironment;
-  Environment iosEnvironment;
-  Artifacts artifacts;
-  FileSystem fileSystem;
-  Logger logger;
+  late FakeProcessManager processManager;
+  late Environment androidEnvironment;
+  late Environment iosEnvironment;
+  late Artifacts artifacts;
+  late FileSystem fileSystem;
+  late Logger logger;
 
   setUp(() {
     processManager = FakeProcessManager.empty();
@@ -102,6 +100,7 @@ void main() {
         '$build/app.dill',
         '--depfile',
         '$build/kernel_snapshot.d',
+        '--verbosity=error',
         'file:///lib/main.dart',
       ], exitCode: 1),
     ]);
@@ -139,6 +138,7 @@ void main() {
         '$build/app.dill',
         '--depfile',
         '$build/kernel_snapshot.d',
+        '--verbosity=error',
         'file:///lib/main.dart',
       ], stdout: 'result $kBoundaryKey\n$kBoundaryKey\n$kBoundaryKey $build/app.dill 0\n'),
     ]);
@@ -177,6 +177,7 @@ void main() {
         '$build/app.dill',
         '--depfile',
         '$build/kernel_snapshot.d',
+        '--verbosity=error',
         'file:///lib/main.dart',
       ], stdout: 'result $kBoundaryKey\n$kBoundaryKey\n$kBoundaryKey $build/app.dill 0\n'),
     ]);
@@ -216,6 +217,7 @@ void main() {
         '$build/app.dill',
         '--depfile',
         '$build/kernel_snapshot.d',
+        '--verbosity=error',
         'foo',
         'bar',
         'file:///lib/main.dart',
@@ -255,6 +257,10 @@ void main() {
         '$build/app.dill',
         '--depfile',
         '$build/kernel_snapshot.d',
+        '--incremental',
+        '--initialize-from-dill',
+        '$build/app.dill',
+        '--verbosity=error',
         'file:///lib/main.dart',
       ], stdout: 'result $kBoundaryKey\n$kBoundaryKey\n$kBoundaryKey $build/app.dill 0\n'),
     ]);
@@ -292,6 +298,10 @@ void main() {
         '$build/app.dill',
         '--depfile',
         '$build/kernel_snapshot.d',
+        '--incremental',
+        '--initialize-from-dill',
+        '$build/app.dill',
+        '--verbosity=error',
         'file:///lib/main.dart',
       ], stdout: 'result $kBoundaryKey\n$kBoundaryKey\n$kBoundaryKey $build/app.dill 0\n'),
     ]);
@@ -344,6 +354,10 @@ void main() {
         '$build/app.dill',
         '--depfile',
         '$build/kernel_snapshot.d',
+        '--incremental',
+        '--initialize-from-dill',
+        '$build/app.dill',
+        '--verbosity=error',
         'file:///lib/main.dart',
       ], stdout: 'result $kBoundaryKey\n$kBoundaryKey\n$kBoundaryKey /build/653e11a8e6908714056a57cd6b4f602a/app.dill 0\n'),
     ]);
@@ -369,7 +383,7 @@ void main() {
         '--no-sim-use-hardfp',
         '--no-use-integer-division',
         '$build/app.dill',
-      ])
+      ]),
     ]);
     androidEnvironment.buildDir.childFile('app.dill').createSync(recursive: true);
 
@@ -397,7 +411,7 @@ void main() {
         '--no-sim-use-hardfp',
         '--no-use-integer-division',
         '$build/app.dill',
-      ])
+      ]),
     ]);
     androidEnvironment.buildDir.childFile('app.dill').createSync(recursive: true);
 
@@ -451,123 +465,7 @@ void main() {
     ProcessManager: () => processManager,
   });
 
-  testUsingContext('AotAssemblyProfile generates multiple arches and lipos together', () async {
-    final String build = iosEnvironment.buildDir.path;
-    processManager.addCommands(<FakeCommand>[
-      FakeCommand(command: <String>[
-        // This path is not known by the cache due to the iOS gen_snapshot split.
-        'Artifact.genSnapshot.TargetPlatform.ios.profile_armv7',
-        '--deterministic',
-        kAssemblyAot,
-        '--assembly=$build/armv7/snapshot_assembly.S',
-        '--strip',
-        '--no-sim-use-hardfp',
-        '--no-use-integer-division',
-        '$build/app.dill',
-      ]),
-      FakeCommand(command: <String>[
-        // This path is not known by the cache due to the iOS gen_snapshot split.
-        'Artifact.genSnapshot.TargetPlatform.ios.profile_arm64',
-        '--deterministic',
-        kAssemblyAot,
-        '--assembly=$build/arm64/snapshot_assembly.S',
-        '--strip',
-        '$build/app.dill',
-      ]),
-      FakeCommand(command: <String>[
-        'xcrun',
-        'cc',
-        '-arch',
-        'armv7',
-        '-miphoneos-version-min=9.0',
-        '-isysroot',
-        'path/to/iPhoneOS.sdk',
-        '-c',
-        '$build/armv7/snapshot_assembly.S',
-        '-o',
-        '$build/armv7/snapshot_assembly.o',
-      ]),
-      FakeCommand(command: <String>[
-        'xcrun',
-        'cc',
-        '-arch',
-        'arm64',
-        '-miphoneos-version-min=9.0',
-        '-isysroot',
-        'path/to/iPhoneOS.sdk',
-        '-c',
-        '$build/arm64/snapshot_assembly.S',
-        '-o',
-        '$build/arm64/snapshot_assembly.o',
-      ]),
-      FakeCommand(command: <String>[
-        'xcrun',
-        'clang',
-        '-arch',
-        'armv7',
-        '-miphoneos-version-min=9.0',
-        '-isysroot',
-        'path/to/iPhoneOS.sdk',
-        '-dynamiclib',
-        '-Xlinker',
-        '-rpath',
-        '-Xlinker',
-        '@executable_path/Frameworks',
-        '-Xlinker',
-        '-rpath',
-        '-Xlinker',
-        '@loader_path/Frameworks',
-        '-install_name',
-        '@rpath/App.framework/App',
-        '-o',
-        '$build/armv7/App.framework/App',
-        '$build/armv7/snapshot_assembly.o',
-      ]),
-      FakeCommand(command: <String>[
-        'xcrun',
-        'clang',
-        '-arch',
-        'arm64',
-        '-miphoneos-version-min=9.0',
-        '-isysroot',
-        'path/to/iPhoneOS.sdk',
-        '-dynamiclib',
-        '-Xlinker',
-        '-rpath',
-        '-Xlinker',
-        '@executable_path/Frameworks',
-        '-Xlinker',
-        '-rpath',
-        '-Xlinker',
-        '@loader_path/Frameworks',
-        '-install_name',
-        '@rpath/App.framework/App',
-        '-o',
-        '$build/arm64/App.framework/App',
-        '$build/arm64/snapshot_assembly.o',
-      ]),
-      FakeCommand(command: <String>[
-        'lipo',
-        '$build/armv7/App.framework/App',
-        '$build/arm64/App.framework/App',
-        '-create',
-        '-output',
-        '$build/App.framework/App',
-      ]),
-    ]);
-    iosEnvironment.defines[kIosArchs] ='armv7 arm64';
-    iosEnvironment.defines[kSdkRoot] = 'path/to/iPhoneOS.sdk';
-
-    await const AotAssemblyProfile().build(iosEnvironment);
-
-    expect(processManager, hasNoRemainingExpectations);
-  }, overrides: <Type, Generator>{
-    Platform: () => macPlatform,
-    FileSystem: () => fileSystem,
-    ProcessManager: () => processManager,
-  });
-
-  testUsingContext('AotAssemblyProfile with bitcode sends correct argument to snapshotter (one arch)', () async {
+  testUsingContext('AotAssemblyProfile with bitcode sends correct argument to snapshotter', () async {
     iosEnvironment.defines[kIosArchs] = 'arm64';
     iosEnvironment.defines[kBitcodeFlag] = 'true';
     iosEnvironment.defines[kSdkRoot] = 'path/to/iPhoneOS.sdk';
@@ -587,7 +485,7 @@ void main() {
         'cc',
         '-arch',
         'arm64',
-        '-miphoneos-version-min=9.0',
+        '-miphoneos-version-min=11.0',
         '-isysroot',
         'path/to/iPhoneOS.sdk',
         // Contains bitcode flag.
@@ -602,7 +500,7 @@ void main() {
         'clang',
         '-arch',
         'arm64',
-        '-miphoneos-version-min=9.0',
+        '-miphoneos-version-min=11.0',
         '-isysroot',
         'path/to/iPhoneOS.sdk',
         '-dynamiclib',
@@ -663,7 +561,7 @@ void main() {
         'cc',
         '-arch',
         'arm64',
-        '-miphoneos-version-min=9.0',
+        '-miphoneos-version-min=11.0',
         '-isysroot',
         'path/to/iPhoneOS.sdk',
         // Contains bitcode flag.
@@ -678,7 +576,7 @@ void main() {
         'clang',
         '-arch',
         'arm64',
-        '-miphoneos-version-min=9.0',
+        '-miphoneos-version-min=11.0',
         '-isysroot',
         'path/to/iPhoneOS.sdk',
         '-dynamiclib',
