@@ -2,8 +2,7 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-// @dart = 2.8
-
+import 'package:collection/collection.dart' show IterableExtension;
 import 'package:file/file.dart';
 import 'package:file/memory.dart';
 import 'package:file_testing/file_testing.dart';
@@ -17,7 +16,6 @@ import 'package:flutter_tools/src/cache.dart';
 import 'package:flutter_tools/src/dart/pub.dart';
 import 'package:flutter_tools/src/flutter_cache.dart';
 import 'package:flutter_tools/src/globals.dart' as globals;
-import 'package:meta/meta.dart';
 import 'package:test/fake.dart';
 
 import '../src/common.dart';
@@ -41,7 +39,7 @@ const FakeCommand unameCommandForArm64 = FakeCommand(
 );
 
 void main() {
-  FakeProcessManager fakeProcessManager;
+  late FakeProcessManager fakeProcessManager;
 
   setUp(() {
     fakeProcessManager = FakeProcessManager.empty();
@@ -79,7 +77,7 @@ void main() {
     });
 
     testWithoutContext('should not throw when lock is acquired', () async {
-      final String oldRoot = Cache.flutterRoot;
+      final String? oldRoot = Cache.flutterRoot;
       Cache.flutterRoot = '';
       try {
         final FileSystem fileSystem = MemoryFileSystem.test();
@@ -319,6 +317,22 @@ void main() {
 
       expect(() => cache.storageBaseUrl, throwsToolExit());
     });
+
+    testWithoutContext('overridden storage base url prints warning to STDERR', () async {
+      final BufferLogger logger = BufferLogger.test();
+      const String baseUrl = 'https://storage.com';
+      final Cache cache = Cache.test(
+        platform: FakePlatform(environment: <String, String>{
+          'FLUTTER_STORAGE_BASE_URL': baseUrl,
+        }),
+        processManager: FakeProcessManager.any(),
+        logger: logger,
+      );
+
+      expect(cache.storageBaseUrl, baseUrl);
+      expect(logger.errorText, contains('Flutter assets will be downloaded from $baseUrl'));
+      expect(logger.statusText, isEmpty);
+    });
   });
 
   testWithoutContext('flattenNameSubdirs', () {
@@ -349,7 +363,7 @@ void main() {
     final Directory dir = fileSystem.systemTempDirectory
         .listSync(recursive: true)
         .whereType<Directory>()
-        .singleWhere((Directory directory) => directory.basename == 'bin_dir', orElse: () => null);
+        .singleWhereOrNull((Directory directory) => directory.basename == 'bin_dir')!;
 
     expect(dir, isNotNull);
     expect(dir.path, artifactDir.childDirectory('bin_dir').path);
@@ -442,6 +456,7 @@ void main() {
   testWithoutContext('FlutterRunnerDebugSymbols downloads Flutter runner debug symbols', () async {
     final FileSystem fileSystem = MemoryFileSystem.test();
     final Cache cache = FakeSecondaryCache()
+      ..artifactDirectory = fileSystem.currentDirectory
       ..version = '123456';
 
     final FakeVersionedPackageResolver packageResolver = FakeVersionedPackageResolver();
@@ -499,7 +514,7 @@ void main() {
       const FakeCommand(
         command: <String>[
           'which',
-          'sysctl'
+          'sysctl',
         ],
         stdout: '/sbin/sysctl',
       ),
@@ -604,20 +619,6 @@ void main() {
     ]));
   });
 
-  testWithoutContext('Windows UWP desktop artifacts include profile, debug, and release artifacts', () {
-    final Cache cache = Cache.test(processManager: FakeProcessManager.any());
-    final WindowsUwpEngineArtifacts artifacts = WindowsUwpEngineArtifacts(
-      cache,
-      platform: FakePlatform(operatingSystem: 'windows'),
-    );
-
-    expect(artifacts.getBinaryDirs(), containsAll(<Matcher>[
-      contains(contains('profile')),
-      contains(contains('release')),
-      contains(contains('debug')),
-    ]));
-  });
-
   testWithoutContext('Linux desktop artifacts ignore filtering when requested', () {
     fakeProcessManager.addCommand(unameCommandForX64);
 
@@ -812,7 +813,7 @@ void main() {
       fileSystem: fileSystem,
       platform: FakePlatform(
         environment: <String, String>{
-          'FLUTTER_STORAGE_BASE_URL': 'https://flutter.storage.com/override'
+          'FLUTTER_STORAGE_BASE_URL': 'https://flutter.storage.com/override',
         },
       ),
     );
@@ -834,7 +835,7 @@ void main() {
 
     expect(downloads, <String>[
       'https://flutter.storage.com/override/flutter_infra_release/flutter/hijklmnop/flutter-web-sdk-linux-x64.zip',
-      'https://flutter.storage.com/override/flutter_infra_release/cipd/flutter/web/canvaskit_bundle/+/abcdefg'
+      'https://flutter.storage.com/override/flutter_infra_release/cipd/flutter/web/canvaskit_bundle/+/abcdefg',
     ]);
   });
 
@@ -972,9 +973,9 @@ void main() {
   });
 
   group('AndroidMavenArtifacts', () {
-    MemoryFileSystem memoryFileSystem;
-    Cache cache;
-    FakeAndroidSdk fakeAndroidSdk;
+    MemoryFileSystem? memoryFileSystem;
+    Cache? cache;
+    FakeAndroidSdk? fakeAndroidSdk;
 
     setUp(() {
       memoryFileSystem = MemoryFileSystem.test();
@@ -986,25 +987,25 @@ void main() {
     });
 
     testWithoutContext('AndroidMavenArtifacts has a specified development artifact', () async {
-      final AndroidMavenArtifacts mavenArtifacts = AndroidMavenArtifacts(cache, platform: FakePlatform());
+      final AndroidMavenArtifacts mavenArtifacts = AndroidMavenArtifacts(cache!, platform: FakePlatform());
       expect(mavenArtifacts.developmentArtifact, DevelopmentArtifact.androidMaven);
     });
 
     testUsingContext('AndroidMavenArtifacts can invoke Gradle resolve dependencies if Android SDK is present', () async {
-      final String oldRoot = Cache.flutterRoot;
+      final String? oldRoot = Cache.flutterRoot;
       Cache.flutterRoot = '';
       try {
-        final AndroidMavenArtifacts mavenArtifacts = AndroidMavenArtifacts(cache, platform: FakePlatform());
-        expect(await mavenArtifacts.isUpToDate(memoryFileSystem), isFalse);
+        final AndroidMavenArtifacts mavenArtifacts = AndroidMavenArtifacts(cache!, platform: FakePlatform());
+        expect(await mavenArtifacts.isUpToDate(memoryFileSystem!), isFalse);
 
-        final Directory gradleWrapperDir = cache.getArtifactDirectory('gradle_wrapper')..createSync(recursive: true);
+        final Directory gradleWrapperDir = cache!.getArtifactDirectory('gradle_wrapper')..createSync(recursive: true);
         gradleWrapperDir.childFile('gradlew').writeAsStringSync('irrelevant');
         gradleWrapperDir.childFile('gradlew.bat').writeAsStringSync('irrelevant');
 
-        await mavenArtifacts.update(FakeArtifactUpdater(), BufferLogger.test(), memoryFileSystem, FakeOperatingSystemUtils());
+        await mavenArtifacts.update(FakeArtifactUpdater(), BufferLogger.test(), memoryFileSystem!, FakeOperatingSystemUtils());
 
-        expect(await mavenArtifacts.isUpToDate(memoryFileSystem), isFalse);
-        expect(fakeAndroidSdk.reinitialized, true);
+        expect(await mavenArtifacts.isUpToDate(memoryFileSystem!), isFalse);
+        expect(fakeAndroidSdk!.reinitialized, true);
       } finally {
         Cache.flutterRoot = oldRoot;
       }
@@ -1020,23 +1021,23 @@ void main() {
           '--project-cache-dir',
           'cache/bin/cache/flutter_gradle_wrapper.rand0',
           'resolveDependencies',
-        ])
+        ]),
       ]),
-      AndroidSdk: () => fakeAndroidSdk
+      AndroidSdk: () => fakeAndroidSdk,
     });
 
     testUsingContext('AndroidMavenArtifacts is a no-op if the Android SDK is absent', () async {
-      final AndroidMavenArtifacts mavenArtifacts = AndroidMavenArtifacts(cache, platform: FakePlatform());
-      expect(await mavenArtifacts.isUpToDate(memoryFileSystem), isFalse);
+      final AndroidMavenArtifacts mavenArtifacts = AndroidMavenArtifacts(cache!, platform: FakePlatform());
+      expect(await mavenArtifacts.isUpToDate(memoryFileSystem!), isFalse);
 
-      await mavenArtifacts.update(FakeArtifactUpdater(), BufferLogger.test(), memoryFileSystem, FakeOperatingSystemUtils());
+      await mavenArtifacts.update(FakeArtifactUpdater(), BufferLogger.test(), memoryFileSystem!, FakeOperatingSystemUtils());
 
-      expect(await mavenArtifacts.isUpToDate(memoryFileSystem), isFalse);
+      expect(await mavenArtifacts.isUpToDate(memoryFileSystem!), isFalse);
     }, overrides: <Type, Generator>{
       Cache: () => cache,
       FileSystem: () => memoryFileSystem,
       ProcessManager: () => FakeProcessManager.empty(),
-      AndroidSdk: () => null // Android SDK was not located.
+      AndroidSdk: () => null, // Android SDK was not located.
     });
   });
 }
@@ -1044,8 +1045,8 @@ void main() {
 class FakeCachedArtifact extends EngineCachedArtifact {
   FakeCachedArtifact({
     String stampName = 'STAMP',
-    @required Cache cache,
-    DevelopmentArtifact requiredArtifacts,
+    required Cache cache,
+    required DevelopmentArtifact requiredArtifacts,
     this.binaryDirs = const <List<String>>[],
     this.licenseDirs = const <String>[],
     this.packageDirs = const <String>[],
@@ -1076,31 +1077,18 @@ class FakeSimpleArtifact extends CachedArtifact {
   Future<void> updateInner(ArtifactUpdater artifactUpdater, FileSystem fileSystem, OperatingSystemUtils operatingSystemUtils) async { }
 }
 
-class FakeDownloadedArtifact extends CachedArtifact {
-  FakeDownloadedArtifact(this.downloadedFile, Cache cache) : super(
-    'fake',
-    cache,
-    DevelopmentArtifact.universal,
-  );
-
-  final File downloadedFile;
-
-  @override
-  Future<void> updateInner(ArtifactUpdater artifactUpdater, FileSystem fileSystem, OperatingSystemUtils operatingSystemUtils) async { }
-}
-
 class FakeSecondaryCachedArtifact extends Fake implements CachedArtifact {
   bool upToDate = false;
   bool didUpdate = false;
-  Exception updateException;
+  Exception? updateException;
 
   @override
   Future<bool> isUpToDate(FileSystem fileSystem) async => upToDate;
 
   @override
-  Future<void> update(ArtifactUpdater artifactUpdater, Logger logger, FileSystem fileSystem, OperatingSystemUtils operatingSystemUtils) async {
+  Future<void> update(ArtifactUpdater artifactUpdater, Logger logger, FileSystem fileSystem, OperatingSystemUtils operatingSystemUtils, {bool offline = false}) async {
     if (updateException != null) {
-      throw updateException;
+      throw updateException!;
     }
     didUpdate = true;
   }
@@ -1118,10 +1106,10 @@ class FakeIosUsbArtifacts extends Fake implements IosUsbArtifacts {
 }
 
 class FakeSecondaryCache extends Fake implements Cache {
-  Directory downloadDir;
-  Directory artifactDirectory;
-  String version;
-  void Function(String artifactName, String version) onSetStamp;
+  Directory? downloadDir;
+  late Directory artifactDirectory;
+  String? version;
+  late void Function(String artifactName, String version) onSetStamp;
 
   @override
   String get storageBaseUrl => 'https://storage.googleapis.com';
@@ -1143,7 +1131,7 @@ class FakeSecondaryCache extends Fake implements Cache {
   }
 
   @override
-  String getVersionFor(String artifactName) => version;
+  String? getVersionFor(String artifactName) => version;
 
   @override
   void setStampFor(String artifactName, String version) {
@@ -1166,13 +1154,13 @@ class FakePub extends Fake implements Pub {
 
   @override
   Future<void> get({
-    PubContext context,
-    String directory,
+    PubContext? context,
+    String? directory,
     bool skipIfAbsent = false,
     bool upgrade = false,
     bool offline = false,
     bool generateSyntheticPackage = false,
-    String flutterRootOverride,
+    String? flutterRootOverride,
     bool checkUpToDate = false,
     bool shouldSkipThirdPartyGenerator = true,
     bool printProgress = true,
@@ -1183,19 +1171,15 @@ class FakePub extends Fake implements Pub {
 
 class FakeCache extends Cache {
   FakeCache({
-    @required Logger logger,
-    @required FileSystem fileSystem,
-    @required Platform platform,
-    @required OperatingSystemUtils osUtils,
+    required super.logger,
+    required super.fileSystem,
+    required super.platform,
+    required super.osUtils,
   }) : super(
-    logger: logger,
-    fileSystem: fileSystem,
-    platform: platform,
-    osUtils: osUtils,
     artifacts: <ArtifactSet>[],
   );
 
-  File stampFile;
+  late File stampFile;
 
   @override
   File getStampFileFor(String artifactName) {
@@ -1213,8 +1197,8 @@ class FakeAndroidSdk extends Fake implements AndroidSdk {
 }
 
 class FakeArtifactUpdater extends Fake implements ArtifactUpdater {
-  void Function(String, Uri, Directory) onDownloadZipArchive;
-  void Function(String, Uri, Directory) onDownloadZipTarball;
+  void Function(String, Uri, Directory)? onDownloadZipArchive;
+  void Function(String, Uri, Directory)? onDownloadZipTarball;
 
   @override
   Future<void> downloadZippedTarball(String message, Uri url, Directory location) async {
