@@ -497,6 +497,7 @@ keep this 3
       late FakeIosProject project;
       late File xcodeProjectInfoFile;
       late File appFrameworkInfoPlist;
+      late File podfile;
 
       setUp(() {
         memoryFileSystem = MemoryFileSystem();
@@ -507,6 +508,9 @@ keep this 3
 
         appFrameworkInfoPlist = memoryFileSystem.file('AppFrameworkInfo.plist');
         project.appFrameworkInfoPlist = appFrameworkInfoPlist;
+
+        podfile = memoryFileSystem.file('Podfile');
+        project.podfile = podfile;
       });
 
       testWithoutContext('skipped if files are missing', () {
@@ -517,24 +521,30 @@ keep this 3
         expect(iosProjectMigration.migrate(), isTrue);
         expect(xcodeProjectInfoFile.existsSync(), isFalse);
         expect(appFrameworkInfoPlist.existsSync(), isFalse);
+        expect(podfile.existsSync(), isFalse);
 
         expect(testLogger.traceText, contains('Xcode project not found, skipping iOS deployment target version migration'));
         expect(testLogger.traceText, contains('AppFrameworkInfo.plist not found, skipping minimum OS version migration'));
+        expect(testLogger.traceText, contains('Podfile not found, skipping global platform version migration'));
         expect(testLogger.statusText, isEmpty);
       });
 
       testWithoutContext('skipped if nothing to upgrade', () {
-        const String xcodeProjectInfoFileContents = 'IPHONEOS_DEPLOYMENT_TARGET = 9.0;';
+        const String xcodeProjectInfoFileContents = 'IPHONEOS_DEPLOYMENT_TARGET = 11.0;';
         xcodeProjectInfoFile.writeAsStringSync(xcodeProjectInfoFileContents);
 
         const String appFrameworkInfoPlistContents = '''
   <key>MinimumOSVersion</key>
-  <string>9.0</string>
+  <string>11.0</string>
 ''';
         appFrameworkInfoPlist.writeAsStringSync(appFrameworkInfoPlistContents);
 
         final DateTime projectLastModified = xcodeProjectInfoFile.lastModifiedSync();
 
+        const String podfileFileContents = "# platform :ios, '11.0'";
+        podfile.writeAsStringSync(podfileFileContents);
+        final DateTime podfileLastModified = podfile.lastModifiedSync();
+
         final DeploymentTargetMigration iosProjectMigration = DeploymentTargetMigration(
           project,
           testLogger,
@@ -544,11 +554,13 @@ keep this 3
         expect(xcodeProjectInfoFile.lastModifiedSync(), projectLastModified);
         expect(xcodeProjectInfoFile.readAsStringSync(), xcodeProjectInfoFileContents);
         expect(appFrameworkInfoPlist.readAsStringSync(), appFrameworkInfoPlistContents);
+        expect(podfile.lastModifiedSync(), podfileLastModified);
+        expect(podfile.readAsStringSync(), podfileFileContents);
 
         expect(testLogger.statusText, isEmpty);
       });
 
-      testWithoutContext('Xcode project is migrated to minimum version 8.0', () {
+      testWithoutContext('Xcode project is migrated to 11', () {
         xcodeProjectInfoFile.writeAsStringSync('''
 				GCC_WARN_UNUSED_VARIABLE = YES;
 				IPHONEOS_DEPLOYMENT_TARGET = 8.0;
@@ -556,6 +568,7 @@ keep this 3
 				ONLY_ACTIVE_ARCH = YES;
 
 				IPHONEOS_DEPLOYMENT_TARGET = 8.0;
+				IPHONEOS_DEPLOYMENT_TARGET = 11.0;
 ''');
 
         appFrameworkInfoPlist.writeAsStringSync('''
@@ -567,8 +580,15 @@ keep this 3
   <string>1.0</string>
   <key>MinimumOSVersion</key>
   <string>8.0</string>
+  <key>MinimumOSVersion</key>
+  <string>11.0</string>
 </dict>
 </plist>
+''');
+
+        podfile.writeAsStringSync('''
+# platform :ios, '9.0'
+platform :ios, '9.0'
 ''');
 
         final DeploymentTargetMigration iosProjectMigration = DeploymentTargetMigration(
@@ -579,11 +599,12 @@ keep this 3
 
         expect(xcodeProjectInfoFile.readAsStringSync(), '''
 				GCC_WARN_UNUSED_VARIABLE = YES;
-				IPHONEOS_DEPLOYMENT_TARGET = 9.0;
+				IPHONEOS_DEPLOYMENT_TARGET = 11.0;
 				MTL_ENABLE_DEBUG_INFO = YES;
 				ONLY_ACTIVE_ARCH = YES;
 
-				IPHONEOS_DEPLOYMENT_TARGET = 9.0;
+				IPHONEOS_DEPLOYMENT_TARGET = 11.0;
+				IPHONEOS_DEPLOYMENT_TARGET = 11.0;
 ''');
 
         expect(appFrameworkInfoPlist.readAsStringSync(), '''
@@ -594,12 +615,19 @@ keep this 3
   <key>CFBundleVersion</key>
   <string>1.0</string>
   <key>MinimumOSVersion</key>
-  <string>9.0</string>
+  <string>11.0</string>
+  <key>MinimumOSVersion</key>
+  <string>11.0</string>
 </dict>
 </plist>
+''');
+
+        expect(podfile.readAsStringSync(), '''
+# platform :ios, '11.0'
+platform :ios, '11.0'
 ''');
         // Only print once even though 2 lines were changed.
-        expect('Updating minimum iOS deployment target from 8.0 to 9.0'.allMatches(testLogger.statusText).length, 1);
+        expect('Updating minimum iOS deployment target to 11.0'.allMatches(testLogger.statusText).length, 1);
       });
     });
 
@@ -809,6 +837,9 @@ class FakeIosProject extends Fake implements IosProject {
 
   @override
   File defaultHostInfoPlist = MemoryFileSystem.test().file('defaultHostInfoPlist');
+
+  @override
+  File podfile = MemoryFileSystem.test().file('Podfile');
 }
 
 class FakeIOSMigrator extends ProjectMigrator {
