@@ -4,10 +4,13 @@
 
 // @dart = 2.8
 
+// ignore_for_file: avoid_redundant_argument_values
+
 import 'dart:io' hide Directory, File;
 
 import 'package:flutter_tools/src/artifacts.dart';
 import 'package:flutter_tools/src/base/file_system.dart';
+import 'package:flutter_tools/src/base/logger.dart';
 import 'package:flutter_tools/src/base/platform.dart';
 import 'package:flutter_tools/src/build_info.dart';
 import 'package:flutter_tools/src/build_system/targets/web.dart';
@@ -16,6 +19,7 @@ import 'package:flutter_tools/src/convert.dart';
 import 'package:flutter_tools/src/globals.dart' as globals;
 import 'package:flutter_tools/src/isolated/devfs_web.dart';
 import 'package:flutter_tools/src/web/compile.dart';
+import 'package:logging/logging.dart' as logging;
 import 'package:package_config/package_config.dart';
 import 'package:shelf/shelf.dart';
 import 'package:test/fake.dart';
@@ -39,10 +43,11 @@ void main() {
   PackageConfig packages;
   Platform windows;
   FakeHttpServer httpServer;
+  BufferLogger logger;
 
   setUpAll(() async {
     packages = PackageConfig(<Package>[
-      Package('flutter_tools', Uri.file('/flutter_tools/lib/').normalizePath())
+      Package('flutter_tools', Uri.file('/flutter_tools/lib/').normalizePath()),
     ]);
   });
 
@@ -50,6 +55,7 @@ void main() {
     httpServer = FakeHttpServer();
     linux = FakePlatform(environment: <String, String>{});
     windows = FakePlatform(operatingSystem: 'windows', environment: <String, String>{});
+    logger = BufferLogger.test();
     testbed = Testbed(setup: () {
       webAssetServer = WebAssetServer(
         httpServer,
@@ -67,9 +73,33 @@ void main() {
         webBuildDirectory: null,
         basePath: null,
       );
+    }, overrides: <Type, Generator>{
+      Logger: () => logger,
     });
   });
 
+  test('.log() reports warnings', () => testbed.run(() {
+    const String unresolvedUriMessage = 'Unresolved uri:';
+    const String otherMessage = 'Something bad happened';
+
+    final List<logging.LogRecord> events = <logging.LogRecord>[
+      logging.LogRecord(
+        logging.Level.WARNING,
+        unresolvedUriMessage,
+        'DartUri',
+      ),
+      logging.LogRecord(
+        logging.Level.WARNING,
+        otherMessage,
+        'DartUri',
+      ),
+    ];
+
+    events.forEach(log);
+    expect(logger.warningText, contains(unresolvedUriMessage));
+    expect(logger.warningText, contains(otherMessage));
+  }));
+
   test('Handles against malformed manifest', () => testbed.run(() async {
     final File source = globals.fs.file('source')
       ..writeAsStringSync('main() {}');
@@ -80,17 +110,21 @@ void main() {
 
     // Missing ending offset.
     final File manifestMissingOffset = globals.fs.file('manifestA')
-      ..writeAsStringSync(json.encode(<String, Object>{'/foo.js': <String, Object>{
-        'code': <int>[0],
-        'sourcemap': <int>[0],
-        'metadata': <int>[0],
-      }}));
+      ..writeAsStringSync(json.encode(<String, Object>{
+        '/foo.js': <String, Object>{
+          'code': <int>[0],
+          'sourcemap': <int>[0],
+          'metadata': <int>[0],
+        },
+      }));
     final File manifestOutOfBounds = globals.fs.file('manifest')
-      ..writeAsStringSync(json.encode(<String, Object>{'/foo.js': <String, Object>{
-        'code': <int>[0, 100],
-        'sourcemap': <int>[0],
-        'metadata': <int>[0],
-      }}));
+      ..writeAsStringSync(json.encode(<String, Object>{
+        '/foo.js': <String, Object>{
+          'code': <int>[0, 100],
+          'sourcemap': <int>[0],
+          'metadata': <int>[0],
+        },
+      }));
 
     expect(webAssetServer.write(source, manifestMissingOffset, sourcemap, metadata), isEmpty);
     expect(webAssetServer.write(source, manifestOutOfBounds, sourcemap, metadata), isEmpty);
@@ -104,11 +138,13 @@ void main() {
     final File metadata = globals.fs.file('metadata')
       ..writeAsStringSync('{}');
     final File manifest = globals.fs.file('manifest')
-      ..writeAsStringSync(json.encode(<String, Object>{'/foo.js': <String, Object>{
-        'code': <int>[0, source.lengthSync()],
-        'sourcemap': <int>[0, 2],
-        'metadata':  <int>[0, 2],
-      }}));
+      ..writeAsStringSync(json.encode(<String, Object>{
+        '/foo.js': <String, Object>{
+          'code': <int>[0, source.lengthSync()],
+          'sourcemap': <int>[0, 2],
+          'metadata':  <int>[0, 2],
+        },
+      }));
     webAssetServer.write(source, manifest, sourcemap, metadata);
 
     final Response response = await webAssetServer
@@ -117,7 +153,7 @@ void main() {
     expect(response.headers, allOf(<Matcher>[
       containsPair(HttpHeaders.contentLengthHeader, source.lengthSync().toString()),
       containsPair(HttpHeaders.contentTypeHeader, 'application/javascript'),
-      containsPair(HttpHeaders.etagHeader, isNotNull)
+      containsPair(HttpHeaders.etagHeader, isNotNull),
     ]));
     expect((await response.read().toList()).first, source.readAsBytesSync());
   }, overrides: <Type, Generator>{
@@ -133,11 +169,13 @@ void main() {
     final File metadata = globals.fs.file('metadata')
       ..writeAsStringSync(metadataContents);
     final File manifest = globals.fs.file('manifest')
-      ..writeAsStringSync(json.encode(<String, Object>{'/foo.js': <String, Object>{
-        'code': <int>[0, source.lengthSync()],
-        'sourcemap': <int>[0, sourcemap.lengthSync()],
-        'metadata':  <int>[0, metadata.lengthSync()],
-      }}));
+      ..writeAsStringSync(json.encode(<String, Object>{
+        '/foo.js': <String, Object>{
+          'code': <int>[0, source.lengthSync()],
+          'sourcemap': <int>[0, sourcemap.lengthSync()],
+          'metadata':  <int>[0, metadata.lengthSync()],
+        },
+      }));
     webAssetServer.write(source, manifest, sourcemap, metadata);
 
     final String merged = await webAssetServer.metadataContents('main_module.ddc_merged_metadata');
@@ -165,7 +203,7 @@ void main() {
       containsPair(HttpHeaders.contentLengthHeader, source.lengthSync().toString()),
       containsPair(HttpHeaders.contentTypeHeader, 'image/png'),
       containsPair(HttpHeaders.etagHeader, isNotNull),
-      containsPair(HttpHeaders.cacheControlHeader, 'max-age=0, must-revalidate')
+      containsPair(HttpHeaders.cacheControlHeader, 'max-age=0, must-revalidate'),
     ]));
     expect((await response.read().toList()).first, source.readAsBytesSync());
   }));
@@ -189,7 +227,7 @@ void main() {
       containsPair(HttpHeaders.contentLengthHeader, source.lengthSync().toString()),
       containsPair(HttpHeaders.contentTypeHeader, 'image/png'),
       containsPair(HttpHeaders.etagHeader, isNotNull),
-      containsPair(HttpHeaders.cacheControlHeader, 'max-age=0, must-revalidate')
+      containsPair(HttpHeaders.cacheControlHeader, 'max-age=0, must-revalidate'),
     ]));
     expect((await response.read().toList()).first, source.readAsBytesSync());
   }));
@@ -327,7 +365,7 @@ void main() {
       containsPair(HttpHeaders.contentLengthHeader, '9'),
       containsPair(HttpHeaders.contentTypeHeader, 'application/javascript'),
       containsPair(HttpHeaders.etagHeader, isNotNull),
-      containsPair(HttpHeaders.cacheControlHeader, 'max-age=0, must-revalidate')
+      containsPair(HttpHeaders.cacheControlHeader, 'max-age=0, must-revalidate'),
     ]));
     expect((await response.read().toList()).first, utf8.encode('main() {}'));
   }));
@@ -341,7 +379,7 @@ void main() {
 
     final Response cachedResponse = await webAssetServer
       .handleRequest(Request('GET', Uri.parse('http://foobar/foo.js'), headers: <String, String>{
-        HttpHeaders.ifNoneMatchHeader: etag
+        HttpHeaders.ifNoneMatchHeader: etag,
       }));
 
     expect(cachedResponse.statusCode, HttpStatus.notModified);
@@ -420,11 +458,13 @@ void main() {
     final File metadata = globals.fs.file('metadata')
       ..writeAsStringSync('{}');
     final File manifest = globals.fs.file('manifest')
-      ..writeAsStringSync(json.encode(<String, Object>{'/foo.dart.lib.js': <String, Object>{
-        'code': <int>[0, source.lengthSync()],
-        'sourcemap': <int>[0, 2],
-        'metadata': <int>[0, 2],
-      }}));
+      ..writeAsStringSync(json.encode(<String, Object>{
+        '/foo.dart.lib.js': <String, Object>{
+          'code': <int>[0, source.lengthSync()],
+          'sourcemap': <int>[0, 2],
+          'metadata': <int>[0, 2],
+        },
+      }));
     webAssetServer.write(source, manifest, sourcemap, metadata);
 
     final Response response = await webAssetServer
@@ -441,11 +481,13 @@ void main() {
     final File metadata = globals.fs.file('metadata')
       ..writeAsStringSync('{}');
     final File manifest = globals.fs.file('manifest')
-      ..writeAsStringSync(json.encode(<String, Object>{'/foo.js': <String, Object>{
-        'code': <int>[0, source.lengthSync()],
-        'sourcemap': <int>[0, 2],
-        'metadata': <int>[0, 2],
-      }}));
+      ..writeAsStringSync(json.encode(<String, Object>{
+        '/foo.js': <String, Object>{
+          'code': <int>[0, source.lengthSync()],
+          'sourcemap': <int>[0, 2],
+          'metadata': <int>[0, 2],
+        },
+      }));
     webAssetServer.write(source, manifest, sourcemap, metadata);
     final Response response = await webAssetServer
       .handleRequest(Request('GET', Uri.parse('http://localhost/foo.js')));
@@ -454,7 +496,7 @@ void main() {
       containsPair(HttpHeaders.contentLengthHeader, source.lengthSync().toString()),
       containsPair(HttpHeaders.contentTypeHeader, 'application/javascript'),
       containsPair(HttpHeaders.etagHeader, isNotNull),
-      containsPair(HttpHeaders.cacheControlHeader, 'max-age=0, must-revalidate')
+      containsPair(HttpHeaders.cacheControlHeader, 'max-age=0, must-revalidate'),
     ]));
     expect((await response.read().toList()).first, source.readAsBytesSync());
   }, overrides: <Type, Generator>{
@@ -472,7 +514,7 @@ void main() {
       containsPair(HttpHeaders.contentLengthHeader, source.lengthSync().toString()),
       containsPair(HttpHeaders.contentTypeHeader, 'image/png'),
       containsPair(HttpHeaders.etagHeader, isNotNull),
-      containsPair(HttpHeaders.cacheControlHeader, 'max-age=0, must-revalidate')
+      containsPair(HttpHeaders.cacheControlHeader, 'max-age=0, must-revalidate'),
     ]));
     expect((await response.read().toList()).first, source.readAsBytesSync());
   }));
@@ -487,7 +529,7 @@ void main() {
       containsPair(HttpHeaders.contentLengthHeader, source.lengthSync().toString()),
       containsPair(HttpHeaders.contentTypeHeader, 'image/png'),
       containsPair(HttpHeaders.etagHeader, isNotNull),
-      containsPair(HttpHeaders.cacheControlHeader, 'max-age=0, must-revalidate')
+      containsPair(HttpHeaders.cacheControlHeader, 'max-age=0, must-revalidate'),
     ]));
     expect((await response.read().toList()).first, source.readAsBytesSync());
   }));
@@ -503,7 +545,7 @@ void main() {
       containsPair(HttpHeaders.contentLengthHeader, source.lengthSync().toString()),
       containsPair(HttpHeaders.contentTypeHeader, 'image/png'),
       containsPair(HttpHeaders.etagHeader, isNotNull),
-      containsPair(HttpHeaders.cacheControlHeader, 'max-age=0, must-revalidate')
+      containsPair(HttpHeaders.cacheControlHeader, 'max-age=0, must-revalidate'),
     ]));
     expect((await response.read().toList()).first, source.readAsBytesSync());
   }, overrides: <Type,  Generator>{
