@@ -10,7 +10,7 @@ class CompileErrorProject extends Project {
   final String pubspec = '''
   name: test
   environment:
-    sdk: ">=2.12.0-0 <3.0.0"
+    sdk: '>=2.12.0-0 <3.0.0'
 
   dependencies:
     flutter:
